@@ -219,8 +219,10 @@ IMPLEMENT_DYNAMIC_CLASS(wxVTKRenderWindowInteractor, wxWindow)
 	EVT_MOTION      (wxVTKRenderWindowInteractor::OnMotion)
 
 	//Bind the events to the event converters
-	EVT_LEFT_DOWN   (wxVTKRenderWindowInteractor::OnButtonDown)
 	EVT_LEFT_DCLICK (wxVTKRenderWindowInteractor::OnMouseDoubleClick)
+	EVT_MIDDLE_DCLICK (wxVTKRenderWindowInteractor::OnMouseDoubleClick)
+	EVT_RIGHT_DCLICK (wxVTKRenderWindowInteractor::OnMouseDoubleClick)
+	EVT_LEFT_DOWN   (wxVTKRenderWindowInteractor::OnButtonDown)
 	EVT_MIDDLE_DOWN (wxVTKRenderWindowInteractor::OnButtonDown)
 	EVT_RIGHT_DOWN  (wxVTKRenderWindowInteractor::OnButtonDown)
 	EVT_LEFT_UP     (wxVTKRenderWindowInteractor::OnButtonUp)
@@ -1467,7 +1469,8 @@ void wxVTKRenderWindowInteractor::OnActivar()
 
 void wxVTKRenderWindowInteractor::DisplayToWorld(double displayPos[3], double worldPos[4])
 {
-	if (!Enabled || !Initialized) {
+/*THIS FUNCTION IS NOT RELIABLE!!
+if (!Enabled || !Initialized) {
 		return;
 	}
 	vtkRenderer* pRenderer = FindPokedRenderer(0,0);
@@ -1477,6 +1480,35 @@ void wxVTKRenderWindowInteractor::DisplayToWorld(double displayPos[3], double wo
 	}
 
 	vtkInteractorObserver::ComputeDisplayToWorld(pRenderer, displayPos[0], displayPos[1], displayPos[2], worldPos);
+	*/
+	worldPos[0] = worldPos[1] = worldPos[2] = worldPos[3] = 0.0;
+	if (m_pPicker != NULL && m_pImageViewer != NULL) {
+		int x = displayPos[0];
+		int y = displayPos[1];
+		vtkRenderer* ren = FindPokedRenderer(x, y);
+
+		if (ren != NULL) {
+			vtkCamera* cam = ren->GetActiveCamera();
+			if (cam != NULL) {
+				double pt[3]  = { x, y, 0.0f };
+				double world[4] = {0.0f, 0.0f, 0.0f, 0.0f};
+				m_pPicker->Pick(pt, ren);
+				m_pPicker->GetPickPosition(world);
+
+				double cpos[3];
+				double cdir[3];
+				cam->GetPosition(cpos);
+				cam->GetDirectionOfProjection(cdir);
+				if (cam->GetParallelProjection()) {
+					this->m_pImageViewer->IntersectarRayo(world, cdir, worldPos);
+					worldPos[3] = 1.0;
+				}
+				else {
+					//std::cout << "Error: Reproyeccion en proyeccion perspectiva no soportado" << std::endl;
+				}
+			}
+		}
+	}
 
 }
 
