@@ -87,53 +87,7 @@ namespace GIL {
 		public:
 
 			virtual ~IPACSController();
-
-			virtual IModeloDicom* BuscarPaciente(
-				void* connectionKey,
-				const std::string& serverId,
-				const std::string& idPaciente,
-				const std::string& nombrePaciente,
-				const std::string& fechaNacimiento,
-				IModeloDicom* pModelo,
-				GNC::IProxyNotificadorProgreso* pNotificador
-				) = 0;
-
-			virtual IModeloDicom* BuscarEstudio(
-				void* connectionKey,
-				const std::string& serverId,
-				const std::string& idPaciente,
-				const std::string& nombrePaciente,
-				const std::string& idEstudio,
-				const std::string& AccNumber,
-				const std::string& modalidad,
-				const std::string& fechaDesde,
-				const std::string& fechaHasta,
-				const std::string& timeFrom,
-				const std::string& timeTo,
-				const std::string& descripcionEstudio,
-				const std::string& nombreEstacion,
-				IModeloDicom* pModelo,
-				GNC::IProxyNotificadorProgreso* pNotificador
-				) = 0;
-
-			virtual IModeloDicom* BuscarSeries(
-				void* connectionKey,
-				const std::string& serverId,
-				const std::string& idEstudio,
-				const std::string& idSerie,
-				IModeloDicom* pModelo,
-				GNC::IProxyNotificadorProgreso* pNotificador
-				) = 0;
-
-			virtual IModeloDicom* BuscarImagenes(
-				void* connectionKey,
-				const std::string& serverId,
-				const std::string& idSerie,
-				const std::string& idImagen,
-				IModeloDicom* pModelo,
-				GNC::IProxyNotificadorProgreso* pNotificador
-				) = 0;
-
+			
 			virtual bool QueryRetrieve(
 				void* connectionKey,
 				const std::string& serverId,
@@ -158,9 +112,7 @@ namespace GIL {
 			virtual bool Query(
 				void* connectionKey,
 				const std::string& abstractSyntax,
-				const std::list<std::string>& transferSyntaxes,
 				const GIL::DICOM::DicomDataset& query,
-				int maxResultTagLen,
 				std::list< GNC::GCS::Ptr<GIL::DICOM::DicomDataset> >& resultsWraper,
 				const std::string& serverId,
 				GNC::IProxyNotificadorProgreso* pNotificador
