@@ -65,7 +65,7 @@ namespace GNC {
 		/** Interface **/
 		virtual bool NotificarProgreso(float progresoNormalizado, const std::string& texto) = 0;
 
-	private:
+	protected:
 		std::string m_Texto;
 		float m_ProgresoNormalizado;
 	};
