@@ -17,6 +17,7 @@
 
 		#include <iostream>
 		#if defined(_WINDOWS)
+		#define _WINSOCKAPI_ 
 		#include <windows.h>
 		#endif
 		
@@ -39,24 +40,11 @@
 #if defined(__WXGTK__) || defined(__WXMAC__) || defined(__WXMSW__)
 
 #if defined (_WIN32)
-	#define TOPATH(stringwx) (stringwx.To8BitData()==NULL)?"":stringwx.To8BitData()
+	#define TOPATH(stringwx) std::string((stringwx.To8BitData().data()==NULL)?"":stringwx.To8BitData())
 	#define FROMPATH(stringstd) wxString::From8BitData(stringstd.c_str())
 #else
-	#define TOPATH(stringwx) stringwx.ToUTF8()
+	#define TOPATH(stringwx) std::string(stringwx.ToUTF8())
 	#define FROMPATH(stringstd) wxString::FromUTF8(stringstd.c_str())
 #endif
 
-#ifndef AUI_NAMESPACE
-//#define AUI_NAMESPACE TEST::
-#endif
-
-#ifndef AUI_NAMESPACE
-#define AUI_NAMESPACE
-#define GINKGO_AUI_DECLARE(clase) class clase;
-#define AUI_USE_NAMESPACE()
-#else
-#define GINKGO_AUI_DECLARE(clase) namespace AUI_NAMESPACE { class clase; }
-#define AUI_USE_NAMESPACE() using namespace AUI_NAMESPACE;
-#endif
-
 #endif
