@@ -46,16 +46,16 @@ namespace GNC
 				} TAlineamiento;
 
 				/* Calcula el bounding box del texto sobre cairo para la fuente seleccionada. Realiza word-wrapping. */
-				static TVector calcularBoundingBox(TContexto* c, const std::string& texto, float anchoMaximo = -1, TAlineamiento alineamiento = TA_Izquierda);
+				static TVector calcularBoundingBox(TContexto* c, const std::string& texto, bool withShadow, float anchoMaximo = -1, TAlineamiento alineamiento = TA_Izquierda);
 
 				/* Dibuja el texto en el contexto con fuente seleccionada. Realiza word-wrapping. */
-				static TVector dibujarTexto(TContexto* c, const std::string& texto, float anchoMaximo = -1, TAlineamiento alineamiento = TA_Izquierda);
+				static TVector dibujarTexto(TContexto* c, const std::string& texto, bool withShadow, float anchoMaximo = -1, TAlineamiento alineamiento = TA_Izquierda);
 
 				/* Dibuja el texto en el contexto con fuente seleccionada y color especificado. Realiza word-wrapping. */
-				static TVector dibujarTexto(TContexto* c, const std::string& texto, const TColor& col, float anchoMaximo = -1, TAlineamiento alineamiento = TA_Izquierda);
+				static TVector dibujarTexto(TContexto* c, const std::string& texto, const TColor& col, bool withShadow, float anchoMaximo = -1, TAlineamiento alineamiento = TA_Izquierda);
 
 				/* Realiza el procesamiento del texto. Calcular el Bounding Box y opcionalmente pintar */
-				static TVector procesarTexto(_cairo* cr, const std::string& texto, const TColor* col, float anchoMaximo = -1, TAlineamiento alineamiento = TA_Izquierda, bool dibujar = true);
+				static TVector procesarTexto(_cairo* cr, const std::string& texto, const TColor* col, bool withShadow, float anchoMaximo = -1, TAlineamiento alineamiento = TA_Izquierda, bool dibujar = true);
 			};
 		}
 	}
