@@ -31,6 +31,8 @@ namespace GNC {
 			/* special annotation values like ${NEWLINE}*/
 			virtual std::string GetAnnotationValue(GNC::GCS::Contexto3D* c, const std::string& key);
 
+			
+
 			/* tag syntax is the same as defined in api/dicom/dcmdictionary.h   gggg|eeee*/
 			virtual std::string GetTagValue(GNC::GCS::Contexto3D* c, const std::string& key, const std::string& defValue = "");
 
@@ -38,6 +40,10 @@ namespace GNC {
 			//si se desean pueden sobreescribirse
 			virtual std::string GetPositionAnnotation(GNC::GCS::Contexto3D* c, const GNC::GCS::Vector3D& wP);
 		protected:
+
+			std::string GetFloatingPointTagWithPrecision(const std::string& key, const std::string& defValue, int precision);
+			bool ContainsTag(const std::string& key);
+
 			GNC::GCS::IVista* m_pView;
 		};
 	}
