@@ -489,9 +489,7 @@ GNC::GCS::Events::EventoTeclado::EventoTeclado(wxKeyEvent* evt, Contexto3D* pCon
 	m_shiftDown = false;
 	m_altDown = false;
 	m_metaDown = false;
-
-	m_scanCode = false;
-
+	
 	m_uniChar = L'\0';
 
 	m_rawCode = 0;
@@ -570,7 +568,7 @@ void GNC::GCS::Events::EventoTeclado::ParseWXEvent(wxKeyEvent* evt)
 	m_shiftDown   = evt->m_shiftDown;
 	m_altDown     = evt->m_altDown;
 	m_metaDown    = evt->m_metaDown;
-	m_scanCode    = evt->m_scanCode;
+	
 	m_rawCode     = evt->m_rawCode;
 	m_rawFlags    = evt->m_rawFlags;
 	m_uniChar     = evt->m_uniChar;
