@@ -20,7 +20,7 @@
 #include <wx/bitmap.h>
 
 class wxWindow;
-class wxAuiToolBar;
+class wxGinkgoToolBar;
 class wxEvtHandler;
 class wxMenu;
 
@@ -49,7 +49,7 @@ namespace GNC {
 
 			virtual ~IHistoryTool();
 
-			virtual void AppendToolIn(wxAuiToolBar* pParent, bool big = false);
+			virtual void AppendToolIn(wxGinkgoToolBar* pParent, bool big = false);
 			virtual void AppendToolIn(wxEvtHandler* pParent, wxMenu* pMenu);
 
 			virtual void Execute() = 0;
