@@ -14,13 +14,11 @@
 
 #include <api/math/geometry.h>
 
+class vtkGinkgoImageViewer;
 namespace GNC {
 	namespace GCS {
-		class Contexto3D;
-		
 		namespace Widgets {
 			class IWidget;
-			class IWidgetBuilder;
 		}
 	}
 }
@@ -33,8 +31,7 @@ namespace GNC {
 		public:
 			virtual ~IImpresorOverlay() {}
 
-			virtual void ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Contexto3D* c , GNC::GCS::Vector& boundingBox) = 0;
-			virtual void ImprimirOverlay(GNC::GCS::Widgets::IWidgetBuilder* wb, GNC::GCS::Contexto3D* c, GNC::GCS::Vector& boundingBox) = 0;
+			virtual std::string ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, vtkGinkgoImageViewer* pViewer) = 0;
 		};
 		
 	}
