@@ -189,7 +189,7 @@ void GNC::GCS::IStudyContext::SetActiveIndex(int indice)
 	}
 }
 
-void GNC::GCS::IStudyContext::InitializeContext(std::list<std::string>& rutas)
+void GNC::GCS::IStudyContext::DoInitiallizeContext(const std::list<std::string>& rutas)
 {
 	ActiveFileIndex = 0;
 	Viewer=NULL;
@@ -342,6 +342,20 @@ bool GNC::GCS::IStudyContext::GetSpacing(const int indice, double& x, double& y,
 			}
 			hasSpacing = true;
 		}
+		else if(tagsImage->getTag("0018|1164",spacing)) {
+			char c;
+			std::istringstream issl(spacing);
+			issl >> x;
+			if(!issl.eof()){
+				issl>>c;//la barra
+				issl>>y;
+			}
+			if(!issl.eof()){
+				issl>>c;//la barra
+				issl>>z;
+			}
+			hasSpacing = true;
+		}
 	}
 	if (x < std::numeric_limits<double>::epsilon()) {
 		x = 1.0f;
@@ -447,6 +461,13 @@ int GNC::GCS::IStudyContext::GetTSizeActive()
 	return dimensions[2];
 }
 
+std::string GNC::GCS::IStudyContext::GetTagActiveImage(const std::string& tag)
+{
+	std::string tagVal;
+	GetTagActiveImage(tag, tagVal);
+	return tagVal;
+}
+
 bool GNC::GCS::IStudyContext::GetTagActiveImage(const std::string& tag, std::string& valor)
 {
 	GNC::GCS::Ptr<GIL::DICOM::DicomDataset> pointer = GetTagsActiveImage();
