@@ -115,8 +115,7 @@ namespace GNC {
 			void SetViewer(const vtkSmartPointer<vtkGinkgoImageViewer>& viewer);
 
 			virtual void SetActiveIndex(int indice);
-
-			virtual void InitializeContext(std::list<std::string>& rutas);
+			
 			std::list<std::string> GetImagePaths();
 
 			const std::string& GetPathActiveImage();
@@ -153,6 +152,7 @@ namespace GNC {
 
 			int GetPathIndex(const std::string& path);
 
+			std::string GetTagActiveImage(const std::string& tag);
 			bool GetTagActiveImage(const std::string& tag, std::string& valor);
 
 			bool IsKeyImageActive();
@@ -161,6 +161,8 @@ namespace GNC {
 			void CreateLoader();
 
 		protected:
+			void DoInitiallizeContext(const std::list<std::string>& rutas);
+
 			void LoadMetaInfo(const int indice);
 			void LoadImageTags(const int indice);
 		public:
