@@ -215,6 +215,12 @@ namespace GNC {
 				long m_GID; // Group ID de los widgets construidos
 				GNC::GCS::TriggerButton m_ButtonMask;
 
+				// Default (common) properties
+				float m_FontSizeProp;
+				float m_MaxTextWidthProp;
+				float m_LineWidthProp;
+				float m_DraggingLineWidthProp;
+
 			public:
 				//existen builders que no necesitan activarse, como la rejilla
 				IWidgetBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask, long gid = 0, bool activar = true);
@@ -514,6 +520,12 @@ namespace GNC {
 			protected:
 				std::string PuntoToStringMundo(const GNC::GCS::Vector& valor);
 				ListaObservadores   m_Observadores;   // Lista de observadores
+
+				// Default (common) properties
+				float m_LineWidthProp;
+				float m_FontSizeProp;
+				float m_MaxTextWidthProp;
+				float m_DraggingLineWidthProp;
 			};
 		}
 	}
