@@ -18,13 +18,45 @@ m_pRendererActivo(NULL),
 m_Modified(false),
 m_pView(pView),
 m_Enabled(true),
-m_cursor(GNC::GCS::Widgets::CUR_FLECHA)
+m_cursor(GNC::GCS::Widgets::CUR_FLECHA),
+m_pDefaultEventListenerDelegate(NULL)
 { }
 
 GNC::GCS::IWidgetsManager::~IWidgetsManager() {
 	m_pView = NULL;
 }
 
+GNC::GCS::IVista* GNC::GCS::IWidgetsManager::GetVista(){
+	return m_pView;
+}
+
+void GNC::GCS::IWidgetsManager::MarcarModificado(bool modificado) {
+	m_Modified = modificado;
+}
+
+bool GNC::GCS::IWidgetsManager::EstaModificado() {
+	return m_Modified;
+}
+
+void GNC::GCS::IWidgetsManager::SetDefaultEventListenerDelegate(GNC::GCS::Events::ISubscriptorEventos* pDelegate) {
+	this->m_pDefaultEventListenerDelegate = pDelegate;
+}
+
+void GNC::GCS::IWidgetsManager::RegisterBuilder(GNC::GCS::Widgets::IWidgetBuilder* pBuilder)
+{
+	m_pBuilders.push_back(pBuilder);
+}
+
+void GNC::GCS::IWidgetsManager::UnRegisterBuilder(GNC::GCS::Widgets::IWidgetBuilder* pBuilder)
+{
+	for (ListaBuilders::iterator it = m_pBuilders.begin(); it != m_pBuilders.end(); ++it) {
+		if ( (*it) == pBuilder) {
+			m_pBuilders.erase(it);
+			break;
+		}
+	}
+}
+
 void GNC::GCS::IWidgetsManager::Enable(bool enabled)
 {
 	m_Enabled = enabled;
