@@ -43,20 +43,6 @@ void GNC::GCS::IWidgetsRenderer::SetIOverlay(IImpresorOverlay* pOverlay) {
 	m_pIOverlay = pOverlay;
 }
 
-void GNC::GCS::IWidgetsRenderer::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Contexto3D* c, GNC::GCS::Vector& boundingBox)
-{
-	if (m_pIOverlay != NULL) {
-		m_pIOverlay->ImprimirOverlay(w, c, boundingBox);
-	}
-}
-
-void GNC::GCS::IWidgetsRenderer::ImprimirOverlay(GNC::GCS::Widgets::IWidgetBuilder* wb, GNC::GCS::Contexto3D* c, GNC::GCS::Vector& boundingBox)
-{
-	if (m_pIOverlay != NULL) {
-		m_pIOverlay->ImprimirOverlay(wb, c, boundingBox);
-	}
-}
-
 //endregion
 
 
