@@ -452,7 +452,11 @@ namespace GNC {
 			//----------------------------------------------
 
 			inline bool EsNulo() const {
+				#if defined(EXACT_COMPARISON)
 				return x == 0.0f && y == 0.0f;
+				#else
+				return ((*this) - Zero()).ValorAbsoluto().NearlyEqual(Zero());
+				#endif
 			}
 
 			inline bool EsInvalido() const {
@@ -1262,7 +1266,33 @@ namespace GNC {
 			}
 
 			inline bool operator==(const Vector& otro) const {
-				return x == (TComp) otro.x && y == (TComp) otro.y;
+				#if defined EXACT_COMPARION
+				return ( x == (TComp) otro.x ) && ( y == (TComp) otro.y );
+				#else
+				return this->NearlyEqual(otro);
+				#endif
+				
+			}
+
+			inline bool NearlyEqual(const Vector& otro) const {
+				return (*this - otro).ValorAbsoluto() < Vector(EpsilonDeComponentes(), EpsilonDeComponentes());
+			}
+
+			inline bool NearlyNotEqual(const Vector& otro) const {
+				return !NearlyEqual(otro);
+			}
+
+			inline bool operator<(const Vector& otro) const {
+				return ( (x < otro.x) && (y < otro.y));
+			}
+			inline bool operator<=(const Vector& otro) const {
+				return (*this < otro) || this->NearlyEqual(otro);
+			}
+			inline bool operator>(const Vector& otro) const {
+				return ( (x > otro.x) && (y > otro.y));
+			}
+			inline bool operator>=(const Vector& otro) const {
+				return (*this > otro) || this->NearlyEqual(otro);
 			}
 
 			inline bool operator!=(const Vector& otro) const {
