@@ -309,7 +309,11 @@ namespace GNC {
 			//----------------------------------------------
 
 			inline bool EsNulo() const {
+				#if defined(EXACT_COMPARISON)
 				return x == 0.0 && y == 0.0 && z == 0.0;
+				#else
+				return ((*this) - Zero()).ValorAbsoluto().NearlyEqual(Zero());
+				#endif
 			}
 
 			inline bool EsInvalido() const {
@@ -647,8 +651,20 @@ namespace GNC {
 				return *this;
 			}
 
-			inline bool operator==(const Vector3D& otro) const {
-				return x == (TComp) otro.x && y == (TComp) otro.y && z == (TComp) otro.z;
+			inline bool operator==(const Vector3D& otro) const {				
+				#if defined(EXACT_COMPARION)
+				return ( x == (TComp) otro.x ) && ( y == (TComp) otro.y ) && ( z == (TComp) otro.z );
+				#else
+				return this->NearlyEqual(otro);
+				#endif
+			}
+
+			inline bool NearlyEqual(const Vector3D& otro) const {
+				return (*this - otro).ValorAbsoluto() < Vector3D(EpsilonDeComponentes(), EpsilonDeComponentes(), EpsilonDeComponentes());
+			}
+
+			inline bool NearlyNotEqual(const Vector3D& otro) const {
+				return !NearlyEqual(otro);
 			}
 
 			inline bool operator!=(const Vector3D& otro) const {
@@ -757,6 +773,19 @@ namespace GNC {
 				return *this;
 			}
 
+			inline bool operator<(const Vector3D& otro) const {
+				return ( (x < otro.x) && (y < otro.y) && (z < otro.z) );
+			}
+			inline bool operator<=(const Vector3D& otro) const {
+				return ( (*this) < otro ) || this->NearlyEqual(otro);
+			}
+			inline bool operator>(const Vector3D& otro) const {
+				return ( (x > otro.x) && (y > otro.y) && (z > otro.z) );
+			}
+			inline bool operator>=(const Vector3D& otro) const {
+				return ( (*this) < otro ) || this->NearlyEqual(otro);
+			}
+
 			inline operator TComp *() {
 				return v;
 			}
