@@ -95,7 +95,7 @@ GNC::GCS::IToolController* GNC::GCS::ITool::GetToolBar()
 	return m_pParent;	
 }
 
-void GNC::GCS::ITool::ConnectKeyEvents(wxWindow* pParent)
+void GNC::GCS::ITool::ConnectKeyEvents(wxWindow* /*pParent*/)
 {
 	//implement in child
 }
