@@ -13,21 +13,18 @@
 
 #include <iostream>
 
-
-#include <wx/aui/aui.h>
-#include <wx/panel.h>
-#include <wx/sizer.h>
-
 #include "iwidgettool.h"
 #include "itoolcontroller.h"
 #include <api/controllers/icontroladorlog.h>
 
+#include <wx/panel.h>
+#include <wx/sizer.h>
+#include <wx/wxginkgotoolbar.h>
 
 GNC::GCS::IWidgetTool::IWidgetTool(const ITool::UID& uid, const ITool::TToolFamily& uidFamilia, const std::string& nombre, const wxBitmap& icon, const int subFamilia, const int& prioridad): GNC::GCS::ITool(uid, uidFamilia, nombre, icon, subFamilia, prioridad)
 {
 }
 
-
 GNC::GCS::IWidgetTool::~IWidgetTool()
 {
 }
@@ -39,11 +36,11 @@ bool GNC::GCS::IWidgetTool::ExecuteAction()
 	return false;
 }
 
-void GNC::GCS::IWidgetTool::AppendToolIn(wxAuiToolBar* pParent)
+void GNC::GCS::IWidgetTool::AppendToolIn(wxGinkgoToolBar* pParent)
 {
 	if (AppendsInToolBar()) {
-		pParent->AddTool(this->ID, wxString::FromUTF8(Name.c_str()), Icon, wxString::FromUTF8(Name.c_str()), wxITEM_CHECK);
-		pParent->SetToolDropDown(this->ID, HasDropDownMenu());
+		pParent->AddTool(this->ID, wxString::FromUTF8(Name.c_str()), Icon, wxString::FromUTF8(Name.c_str()), wxITEM_NORMAL);
+		pParent->ForceSetToolDropDown(this->ID, HasDropDownMenu());
 		pParent->EnableTool(this->ID, IsEnabled());
 	}
 }
