@@ -10,7 +10,9 @@
  *  See License.txt for details
  *
  */
-
+#if defined(__DEPRECATED)
+#undef __DEPRECATED
+#endif
 #include "iginkgomatrix4x4.h"
 #include <main/utils/ginkgomatrix4x4.h>
 
