@@ -37,6 +37,12 @@ typedef struct TWidgetColor
 #define ConsumirEvento() evento.Skip(false)
 #define EventoConsumido() !evento.GetSkipped()
 
+#define WIDGETS_TEXT_FONT_FAMILY "Arial"
+
+#define ANNOTATOR_TEXT_COLOR        0.0f, 0.90f, 0.90f, 1.0f
+#define DEFAULT_TEXT_COLOR          0.0f, 0.75f, 0.75f, 1.0f
+#define DEFAULT_TEXT_COLOR_INVERTED 0.0f, 0.0f, 0.0f, 1.0f
+
 static TWidgetColor wColorNormal(0.0f, 1.0f, 0.0f, 1.0f); // glColor4f(0.0f, 1.0f, 0.0f, 0.75f);
 static TWidgetColor wColorNormalSuave(0.0f, 0.5f, 0.0f, 0.5f); // glColor4f(0.0f, 1.0f, 0.0f, 0.75f);
 static TWidgetColor wColorIluminado(1.0f, 1.0f, 0.0f, 1.0f); // glColor4f(1.0f, 1.0f, 0.0f, 1.0f);
@@ -47,11 +53,7 @@ static TWidgetColor wColorSeleccionadoIluminado(1.0f, 0.5f, 0.0f, 1.0f);
 static TWidgetColor wColorSombra(0.0f, 0.0f, 0.0f, 0.2f);
 static TWidgetColor wColorLineaArrastre(1.0f, 0.0f, 0.0f, 1.0f);
 
-#define WIDGET_GROSOR_LINEA				2.0f
-#define WIDGET_GROSOR_LINEA_ARRASTRE	1.0f
-
 #define WIDGET_SIZE_PUNTO 8.0f
-#define WIDGET_SIZE_FUENTE 12.0f
 
 static GNC::GCS::Vector wRadioPuntoIluminado(15.0f, 15.0f);
 
@@ -61,14 +63,17 @@ static TWidgetColor wColorPuntoIluminadoExterior(1.0f, 1.0f, 0.0f, 0.0f);
 static TWidgetColor wColorAngulo(1.0f, 0.0f, 0.0f, 0.8f);
 static TWidgetColor wColorAnguloInterior(1.0f, 0.0f, 0.0f, 0.25f);
 
-#define WIDGET_OFFSET_X_SOMBRA					3.0f
-#define WIDGET_OFFSET_Y_SOMBRA					2.0f
+#define WIDGET_OFFSET_X_SOMBRA					1.0f
+#define WIDGET_OFFSET_Y_SOMBRA					1.0f
 
-#define WIDGET_OFFSET_X_SOMBRA_SELECCIONADO		5.0f
-#define WIDGET_OFFSET_Y_SOMBRA_SELECCIONADO		4.0f
+#define WIDGET_OFFSET_X_SOMBRA_SELECCIONADO		2.0f
+#define WIDGET_OFFSET_Y_SOMBRA_SELECCIONADO		2.0f
 
 #define WIDGET_INCREMENTO_DETALLE_SELECCIONADO	1.15f
 
+#define ANNOTATION_FP_PRECISION 2
+#define ANNOTATION_TEXT_WITH_SHADOW true
+
 // -- Comportamiento --------------------------------------------------------------------------------
 
 inline void wAplicarColor(bool iluminado, bool moviendose, bool seleccionado)
@@ -325,6 +330,49 @@ inline void wDibujarBordeTexto2D(GNC::GCS::Contexto3D* c, GNC::GCS::TexturaCairo
 	glMatrixMode(GL_MODELVIEW);
 }
 
+inline void wDibujarFondoTexto2D(GNC::GCS::Contexto3D* c, GNC::GCS::TexturaCairo& tc, const GNC::GCS::Vector& rasterPos) {
+	/*
+	 * Posicion del Quad
+	 *  q3   q2
+	 *  q0   q1
+	 * */
+
+	glMatrixMode(GL_PROJECTION);
+	glPushMatrix();
+	glLoadIdentity();
+
+	glOrtho(0, c->ancho, 0, c->alto, -1, 1);
+	glMatrixMode(GL_MODELVIEW);
+	glPushMatrix();
+	glLoadIdentity();
+
+	GNC::GCS::Vector quad[4];
+
+	quad[0].x = rasterPos.x;
+	quad[0].y = rasterPos.y;
+	
+	quad[2].x = quad[0].x + (double)tc.ancho;
+	quad[2].y = quad[0].y - (double)tc.alto;
+
+	quad[1].x = quad[2].x;
+	quad[1].y = quad[0].y;
+
+	quad[3].x = quad[0].x;
+	quad[3].y = quad[2].y;
+
+	glBegin(GL_QUADS);
+	for (int i = 0; i < 4; ++i)
+	{
+		glVertex2dv(quad[i].v);
+	}
+	glEnd();
+
+	glPopMatrix();
+	glMatrixMode(GL_PROJECTION);
+	glPopMatrix();
+	glMatrixMode(GL_MODELVIEW);
+}
+
 inline void AjustarAPixelsPantalla(GNC::GCS::Contexto3D* c, GNC::GCS::Vector* v, int numVectores)
 {
 	if (numVectores < 1) {
