@@ -74,18 +74,18 @@ void GNC::GCS::Widgets::IWidgetSerializable::SerializarMetadatos(wxXmlNode* nodo
 	{
 		std::ostringstream ostr;
 		ostr << m_timestampCreacion;
-		nodo->AddProperty(wxT("creacion"),wxString::FromUTF8(ostr.str().c_str()));
+		nodo->AddAttribute(wxT("creacion"),wxString::FromUTF8(ostr.str().c_str()));
 	}
 	{
 		std::ostringstream ostr;
 		ostr << m_timestampModificacion;
-		nodo->AddProperty(wxT("modificacion"),wxString::FromUTF8(ostr.str().c_str()));
+		nodo->AddAttribute(wxT("modificacion"),wxString::FromUTF8(ostr.str().c_str()));
 	}
 	if(m_modificado) {
-		nodo->AddProperty(wxT("medico"),wxString::FromUTF8(nombreMedico.c_str()));
+		nodo->AddAttribute(wxT("medico"),wxString::FromUTF8(nombreMedico.c_str()));
 		m_nombreMedico = nombreMedico;
 	} else {
-		nodo->AddProperty(wxT("medico"),wxString::FromUTF8(m_nombreMedico.c_str()));
+		nodo->AddAttribute(wxT("medico"),wxString::FromUTF8(m_nombreMedico.c_str()));
 	}
 	m_modificado = false;
 }
@@ -94,7 +94,7 @@ void GNC::GCS::Widgets::IWidgetSerializable::LeerMetadatos(wxXmlNode* nodo)
 {
 	wxString valor;
 	
-	if(nodo->GetPropVal(wxT("creacion"),&valor)) {
+	if(nodo->GetAttribute(wxT("creacion"),&valor)) {
 		#if defined(__WXOSX__) || defined(__WXGTK__)
 		if(!valor.ToLong(&m_timestampCreacion)) {
 		#else
@@ -107,7 +107,7 @@ void GNC::GCS::Widgets::IWidgetSerializable::LeerMetadatos(wxXmlNode* nodo)
 		m_timestampCreacion = 0;
 	}
 		
-	if(nodo->GetPropVal(wxT("modificacion"),&valor)){
+	if(nodo->GetAttribute(wxT("modificacion"),&valor)){
 		#if defined(__WXOSX__) || defined(__WXGTK__)
 		if(!valor.ToLong(&m_timestampModificacion)) {
 		#else
@@ -122,7 +122,7 @@ void GNC::GCS::Widgets::IWidgetSerializable::LeerMetadatos(wxXmlNode* nodo)
 	}
 	
 	wxString wxStr;
-	if(nodo->GetPropVal(wxT("medico"),&wxStr)) {
+	if(nodo->GetAttribute(wxT("medico"),&wxStr)) {
 		//si se carga del xml no esta modificado
 		m_nombreMedico = wxStr.ToUTF8();
 		m_modificado = false;
