@@ -19,7 +19,7 @@ namespace GNC {
 		class IVista;
 	}
 }
-class wxHTTPBuilder;
+
 namespace GNC {
 	class ComandoComprobarActualizaciones;
 
@@ -31,7 +31,6 @@ namespace GNC {
 
 		std::string                     m_URL;
 		bool                            m_Informar;
-		wxHTTPBuilder*				    m_pBuilder;
 
 	};
 
@@ -49,7 +48,6 @@ namespace GNC {
 
 		virtual void Execute();
 		virtual void Update();
-		virtual void OnAbort();
 
 	protected:
 
