@@ -69,9 +69,6 @@ namespace GADAPI {
 
 	ComandoExportacionParams::~ComandoExportacionParams()
 	{
-	/*	if (m_pDatosPersistentes->m_target != GNC::GUI::TipoWizardExportacion::EXTERNAL_FOLDER) {
-			GNC::Entorno::Instance()->RemoveDirRecursive(m_tempDir);
-		}*/
 	}
 
 	ComandoExportacion::ComandoExportacion(ComandoExportacionParams* pParams): GNC::GCS::IComando(pParams,"Exportacion")
@@ -83,12 +80,8 @@ namespace GADAPI {
 	{
 		if (!NotificarProgreso(0.0, _Std("Exporting files...")) )
 			return;
-		if(m_pExportacionParams->m_pDatosPersistentes->m_formatoDestino == GNC::GUI::DICOM){
-			ExportarDICOM();
-		}
-		else{
-			ExportarImagenes();
-		}
+		
+		ExportarDICOM();		
 
 		if (m_pExportacionParams->m_pDatosPersistentes->m_target == GNC::GUI::TipoWizardExportacion::OVERWRITE) {
 			GNC::GCS::HistoryController::FileModelList fileModelList;
@@ -139,20 +132,14 @@ namespace GADAPI {
 		std::list<std::string> resultado;
 		std::list<std::string> listaPaths;
 
-		if (pDatosPersistentes->m_pExportDelegate.IsValid()) {
-			if (pDatosPersistentes->m_ficheroActual) {
-				listaPaths.push_back(pDatosPersistentes->m_pExportDelegate->GetPathActiveDICOM());
-			}
-			else
-			{
-				listaPaths = pDatosPersistentes->m_pExportDelegate->GetPathAllDICOMs();
-			}
-		} else if (!pDatosPersistentes->ListOfSeriesPks.empty()) {
+		if (!pDatosPersistentes->ListOfSeriesPks.empty()) {
 			for (std::list<long>::iterator itUIDs = pDatosPersistentes->ListOfSeriesPks.begin(); itUIDs != pDatosPersistentes->ListOfSeriesPks.end(); ++itUIDs)
 			{
 				GNC::GCS::HistoryController::StringList pathsSerie = GNC::GCS::HistoryController::Instance()->GetSeriesSortedPaths((*itUIDs));
 				listaPaths.insert(listaPaths.begin(), pathsSerie.begin(), pathsSerie.end());
 			}
+		} else if (!pDatosPersistentes->ListOfDICOMPaths.empty()) {
+			listaPaths.insert(listaPaths.end(), pDatosPersistentes->ListOfDICOMPaths.begin(), pDatosPersistentes->ListOfDICOMPaths.end());
 		}
 
 		GIL::DICOM::IDICOMManager*	pDICOMManager;
@@ -229,106 +216,6 @@ namespace GADAPI {
 	}
 
 
-	void ComandoExportacion::ExportarImagenes()
-	{
- 		GNC::GCS::Ptr<GNC::GUI::TipoWizardExportacion> pDatosPersistentes = m_pExportacionParams->m_pDatosPersistentes;
-
-		if(!pDatosPersistentes->m_pExportDelegate.IsValid()){
-			//error!!!! no deberia llegar porque en el paso uno no le deberia haber dejado seleccionar otra cosa que un dicom
-			m_pExportacionParams->m_Error = _Std("Unexpected Error exporting, the view is not allowed to export to the format selected");
-			m_pExportacionParams->m_hasError = true;
-			return ;
-		}
-
-		std::list<std::string> listaPaths;
-		GNC::GCS::IImageExportDelegate::ImageType::Pointer img;
-		try{
-			if(pDatosPersistentes->m_ficheroActual){
-				wxString cadena = wxString::Format(_("Exporting file %d of %d"), 1, 1);
-				if (!NotificarProgreso(0.2, std::string(cadena.ToUTF8())))
-					return;
-
-				pDatosPersistentes->m_pExportDelegate->GetCurrentImage(img, pDatosPersistentes->m_mapasValoracion, pDatosPersistentes->m_incluirWidgets, GNC::GCS::Vector::NaN());
-				wxString res=ExportarImage(img);
-				if(res!=wxEmptyString){
-					std::string strTmp(TOPATH(res));
-					m_pExportacionParams->m_outputPaths.push_back(strTmp);
-				}
-			}
-			else
-			{
-				int size = pDatosPersistentes->m_pExportDelegate->GetNumberOfSlices();
-				for(std::string::size_type i = 0; (int)i < size; i++){
-					wxString cadena = wxString::Format(_("Exporting file %d of %d"), (int)(i+1), (int)size);
-					if (!NotificarProgreso((float)i/size, std::string(cadena.ToUTF8())))
-						return;
-
-					pDatosPersistentes->m_pExportDelegate->GetImage(img, i, pDatosPersistentes->m_mapasValoracion, pDatosPersistentes->m_incluirWidgets, GNC::GCS::Vector::NaN());
-					wxString res = ExportarImage(img);
-					if(res != wxEmptyString){
-						std::string strTmp(TOPATH(res));
-						m_pExportacionParams->m_outputPaths.push_back(strTmp);
-					}
-				}
-			}
-		}
-		catch(itk::ExceptionObject&) {
-
-			m_pExportacionParams->m_Error = _Std("Failed to store the file, check permissions on the directory");
-			m_pExportacionParams->m_hasError = true;
-		}
-	}
-
-	wxString ComandoExportacion::ExportarImage(GNC::GCS::IImageExportDelegate::ImageType::Pointer img)
-	{
-		GNC::GCS::Ptr<GNC::GUI::TipoWizardExportacion> pDatosPersistentes = m_pExportacionParams->m_pDatosPersistentes;
-		if(img.IsNull()){
-			m_pExportacionParams->m_Error = _Std("The key files will not be exported");
-			m_pExportacionParams->m_hasError = true;
-			return wxEmptyString;
-		}
-
-		wxString destino = wxEmptyString;
-
-		typedef itk::ImageFileWriter<GNC::GCS::IImageExportDelegate::ImageType> TipoWriter;
-		TipoWriter::Pointer writer = TipoWriter::New();
-		writer->SetInput(img);
-
-
-		switch(pDatosPersistentes->m_formatoDestino) {
-			case GNC::GUI::BMP:
-				{
-					destino = GetFichero(wxT("bmp"));
-					std::string strTmp (TOPATH(destino));
-					writer->SetFileName(strTmp.c_str());
-				}
-				break;
-			case GNC::GUI::JPEG:
-				{
-					destino = GetFichero(wxT("jpg"));
-					std::string strTmp (TOPATH(destino));
-					writer->SetFileName(strTmp.c_str());
-					itk::JPEGImageIO::Pointer imageIO = itk::JPEGImageIO::New();
-					writer->SetImageIO(imageIO);
-					imageIO->SetUseCompression(true);
-					imageIO->SetQuality(pDatosPersistentes->m_jpegCalidad);
-				}
-				break;
-			case GNC::GUI::PNG:
-				{
-					destino = GetFichero(wxT("png"));
-					std::string strTmp (TOPATH(destino));
-					writer->SetFileName(strTmp.c_str());
-				}
-				break;
-			case GNC::GUI::DICOM:
-				break;
-		}
-
-		writer->Update();
-		return destino;
-	}
-
 	wxString ComandoExportacion::GetFichero(const wxString& extension) {
 		wxString dir;
 		if (m_pExportacionParams->m_pDatosPersistentes->m_target == GNC::GUI::TipoWizardExportacion::EXTERNAL_FOLDER) {
@@ -336,18 +223,25 @@ namespace GADAPI {
 		} else {
 			dir = FROMPATH(m_pExportacionParams->m_tempDir);
 		}
-		wxString destino(wxEmptyString);
-		std::string nombre (wxDateTime::Now().Format(_("image_%m-%d-%Y_")).ToUTF8());
-		std::string stdDir(TOPATH(dir));
-		std::string stdExtension(TOPATH(extension));
-		int indice=0;
-		//yy-mm-dd_imagen_indice
-		do {
-			std::ostringstream ostr;
-			ostr << stdDir << (char)wxFileName::GetPathSeparator() << nombre << indice++ << "." << stdExtension;
-			destino = FROMPATH(ostr.str());
-		} while(wxFile::Exists(destino));
-		return destino;
+
+		//if pathDestino is a file.. then return
+		if (!wxDirExists(dir))
+		{
+			return dir;
+		} else {
+			wxString destino(wxEmptyString);
+			std::string nombre (wxDateTime::Now().Format(_("image_%m-%d-%Y_")).ToUTF8());
+			std::string stdDir(TOPATH(dir));
+			std::string stdExtension(TOPATH(extension));
+			int indice=0;
+			//yy-mm-dd_imagen_indice
+			do {
+				std::ostringstream ostr;
+				ostr << stdDir << (char)wxFileName::GetPathSeparator() << nombre << indice++ << "." << stdExtension;
+				destino = FROMPATH(ostr.str());
+			} while(wxFile::Exists(destino));
+			return destino;
+		}
 	}
 };
 
