@@ -51,8 +51,6 @@ namespace GADAPI {
 
 	protected:
 		void ExportarDICOM();
-		void ExportarImagenes();
-		wxString ExportarImage(GNC::GCS::IImageExportDelegate::ImageType::Pointer img);
 		wxString GetFichero(const wxString& extension);
 
 		ComandoExportacionParams* m_pExportacionParams;
