@@ -258,7 +258,7 @@ void GADAPI::ExportToDicomDirCommand::Execute()
 	{
 		for (ExportToDicomDirCommandParams::TListOfPks::const_iterator itUids = m_pExportacionParams->m_seriesList.begin(); itUids != m_pExportacionParams->m_seriesList.end(); ++itUids)
 		{
-			wxString cadena = wxString::Format(_("Exporting series %d of %d"), actualSerie++, numberOfSeries);
+			wxString cadena = wxString::Format(_("Exporting series %d of %d"), (int)(actualSerie++), (int)(numberOfSeries));
 			if (!NotificarProgreso((float)actualSerie/numberOfSeries, std::string(cadena.ToUTF8())))
 				return;
 			//find source paths and series model
@@ -335,7 +335,7 @@ void GADAPI::ExportToDicomDirCommand::Execute()
 	{
 		for (ExportToDicomDirCommandParams::TListOfPks::const_iterator itUids = m_pExportacionParams->m_seriesList.begin(); itUids != m_pExportacionParams->m_seriesList.end(); ++itUids)
 		{
-			wxString cadena = wxString::Format(_("Exporting series %d of %d"), actualSerie++, numberOfSeries);
+			wxString cadena = wxString::Format(_("Exporting series %d of %d"), (int)(actualSerie++), (int)(numberOfSeries));
 			if (!NotificarProgreso((float)actualSerie/numberOfSeries, std::string(cadena.ToUTF8())))
 				return;
 			//find source paths and series model
@@ -349,9 +349,9 @@ void GADAPI::ExportToDicomDirCommand::Execute()
 				if (!m_pExportacionParams->m_includeGinkgoTags) {
 					manager.AnonimizarTagsPrivados();
 				}
-				wxString targetFile = FROMPATH(m_TmpDir) + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d"), rand());
+				wxString targetFile = FROMPATH(m_TmpDir) + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d"), (int)(rand()));
 				while (wxFileExists(targetFile)) {
-					targetFile = FROMPATH(m_TmpDir) + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d"), rand());
+					targetFile = FROMPATH(m_TmpDir) + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d"), (int)(rand()));
 				}
 				std::string targetFileStd(TOPATH(targetFile));
 				if (!manager.AlmacenarFichero(targetFileStd)) {
