@@ -118,7 +118,7 @@ namespace GADAPI {
 			message += _("Image acquisition finished.");
 			message += wxT("\n");
 			if (m_pLinkParams->m_ErrorList.size() > 0)
-				message += wxString::Format(_("\nThere are %d errors (see log for more detailed description)"), m_pLinkParams->m_ErrorList.size());
+				message += wxString::Format(_("\nThere are %d errors (see log for more detailed description)"), (int)(m_pLinkParams->m_ErrorList.size()));
 
 			//log
 			{
