@@ -34,12 +34,13 @@ namespace GADAPI {
 
 	public:
 		//download only specifying 
-		PACSDownloadCommandParams(const std::string& serverSeleccionado, const GIL::DICOM::DicomDataset& base, bool link = false);
+		PACSDownloadCommandParams(const std::string& serverSeleccionado, const GIL::DICOM::DicomDataset& base, bool link = false, bool silent = false);
 		virtual ~PACSDownloadCommandParams();
 
 	public:
 		std::string              m_serverSeleccionado;
 		bool					 m_link;
+		bool					 m_silent;
 		std::string              m_error;
 		GNC::GCS::Ptr<IModeloDicom> m_pModelo;
 		GIL::DICOM::DicomDataset m_base;
