@@ -78,7 +78,7 @@ namespace GADAPI {
 
 			std::string stdFilePath;
 			if (calculatePaths) {
-				wxString fpath = wxPathDirectorioTemporal + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d.pdf"),i);
+				wxString fpath = wxPathDirectorioTemporal + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d.pdf"), (int)(i) );
 				stdFilePath = std::string( TOPATH(fpath) );
 			}
 			else {
