@@ -24,9 +24,8 @@ namespace GIL{
 }
 
 namespace GADAPI {
-	class EXTAPI SendPACSCommand : public GNC::GCS::IPersistentCommand {
+	class EXTAPI SendPACSCommand : public GNC::GCS::IComando {
 	public:
-		SendPACSCommand(long idBBDD, const std::list<long> seriesId);
 		SendPACSCommand(const std::string& selectedServer, const std::string& hl7Message, const std::list<long> seriesId);
 		
 		SendPACSCommand( const SendPACSCommand& o);
@@ -51,6 +50,8 @@ namespace GADAPI {
 		void LiberarRecursos();
 
 		std::string m_selectedServer;
+		std::list<long> m_seriesId;
 		std::string m_hl7Message;
+		std::string m_error;
 	};
 }
