@@ -88,7 +88,7 @@ namespace GADAPI
 					for (GNC::GCS::IHistoryController::LightFileModelList::iterator itFiles = listOfFiles.begin(); itFiles != listOfFiles.end(); ++itFiles)
 					{
 						{
-							if (!NotificarProgreso(0.05, std::string(wxString::Format(_("Downloading file %d"), fileNum++).ToUTF8()))) {
+							if (!NotificarProgreso(0.05, std::string(wxString::Format(_("Downloading file %d"), (int)(fileNum++) ).ToUTF8()))) {
 								return;
 							}
 						}
