@@ -18,4 +18,12 @@ GNC::GCS::ISliderContract::ISliderContract()
 
 GNC::GCS::ISliderContract::~ISliderContract()
 {
-}
\ No newline at end of file
+}
+
+void GNC::GCS::ISliderContract::GoToNextSeries() const
+{
+}
+
+void GNC::GCS::ISliderContract::GoToPrevSeries() const
+{
+}
