@@ -32,6 +32,9 @@ namespace GNC {
 			virtual void SetSlice(int slicenum) = 0;
 			virtual int GetSlice() const = 0;
 			virtual int GetNumberOfSlices() const = 0;
+
+			virtual void GoToNextSeries() const;
+			virtual void GoToPrevSeries() const;
 		};		
 	}
 }
