@@ -53,4 +53,17 @@ std::string GNC::GCS::IWidgetsContract::GetTagValue(GNC::GCS::Contexto3D* /*c*/,
 		}
 	} 
 	return "";
-}
\ No newline at end of file
+}
+
+vtkGinkgoImageViewer* GNC::GCS::IWidgetsContract::GetViewerActivo()
+{
+	GNC::GCS::IWidgetsManager* pManager = GetManager();
+	if (pManager != NULL) 
+	{
+		return pManager->GetRendererActivo()->m_pImageViewer;
+	}
+	else
+	{
+		return NULL;
+	}
+}
