@@ -13,13 +13,13 @@
 */
 #ifndef IIMAGEEXPORTTOOL_H
 #define IIMAGEEXPORTTOOL_H
-#include <export/contracts/iimageexportcontractable.h>
+#include <export/contracts/iwidgetscontractable.h>
 #include <api/toolsystem/itool.h>
 #include "iherramientascore.h"
 
 namespace GNC {
 	namespace GCS {
-		class EXTAPI IImageExportTool:  public ITool, public GNC::GCS::IImageExportContractable
+		class EXTAPI IImageExportTool:  public ITool, public GNC::GCS::IWidgetsContractable
 		{
 		public:
 			static GNC::GCS::ITool::UID ID;
