@@ -17,6 +17,6 @@
 
 GNC::GCS::ITool::UID GNC::GCS::IPixelsBluringTool::ID = HCore_PixelsBluring;
 
-GNC::GCS::IPixelsBluringTool::IPixelsBluringTool() : ITool(ID, TSeriesMenu,  _Std("Pixels blurring"), GinkgoResourcesManager::ToolIcons::GetIcoDesencajar(),2)
+GNC::GCS::IPixelsBluringTool::IPixelsBluringTool() : ITool(ID, TSeriesMenu,  _Std("Pixels blurring"), wxNullBitmap,2)
 {
 }
