@@ -15,6 +15,7 @@
 
 #include <deque>
 #include <set>
+#include <complex>
 
 #include <api/globals.h>
 #include <api/threads/thread.h>
@@ -369,25 +370,24 @@ void GNC::CommandLauncher::DoTerminar()
 
 bool GNC::CommandLauncher::NotificarProgreso(float progresoNormalizado, const std::string& texto)
 {
-	//GNC::GCS::ILocker pLocker(GNC::CommandController::Instance());
 	if(m_Abortar){
-		//std::cout << "Comando abortado: No se notificara el progreso" << std::endl;
 		return false;
 	}
-	//GTRACE(">> CommandLauncher::NotificarProgreso(): " << m_idThreadGinkgo);
+	//this protect system to overflow event message queue
+	bool sendEvent = false;
+	const float newProgress = std::max<float>(0, std::min<float>(progresoNormalizado,1.0f));
 	LockProgreso();
-	SetProgresoNormalizado(std::max<float>(0, std::min<float>(progresoNormalizado,1.0f)));
+	sendEvent = (std::abs<float>(m_ProgresoNormalizado - newProgress) > 0.01);
+	SetProgresoNormalizado(newProgress);
+	sendEvent = sendEvent || (texto != m_Texto);
 	SetTextoProgreso(texto);
 	UnLockProgreso();
-
-
+	
 	wxWindow* w = GNC::GCS::IEntorno::Instance()->GetVentanaPrincipal();
-	if(w!=NULL) {
-		EventoProgreso ce(EventoProgreso::ComandoEjecutando, m_idThreadGinkgo);
-		//std::cout << "AddPendingEvent EventoProgreso::ComandoEjecutando " << m_idThreadGinkgo << std::endl;
-		w->GetEventHandler()->AddPendingEvent(ce);
+	if(sendEvent && w!=NULL) {
+		EventoProgreso* ce = new EventoProgreso(EventoProgreso::ComandoEjecutando, m_idThreadGinkgo);
+		wxQueueEvent(w->GetEventHandler(), ce);
 	}
-	//GTRACE("<< CommandLauncher::NotificarProgreso(): " << m_idThreadGinkgo);
 	return true;
 
 }
