@@ -26,13 +26,22 @@
 #include <wx/msw/private.h>     // includes <windows.h>
 #endif
 
-
-
 namespace GNC {
 	namespace GCS {
+		ProxySettings::ProxySettings()
+		{
+			useProxy = false;
+		}
+		ProxySettings::~ProxySettings()
+		{
+		}
+
+
 		ConfigurationController* ConfigurationController::m_pInstance = NULL;
 		wxCriticalSection ConfigurationController::m_criticalSection;
 
+		wxString ConfigurationController::m_PreferredGeneralConfigPath;
+
 		ConfigurationController* ConfigurationController::Instance() {
 			if (m_pInstance == NULL) {
 				wxCriticalSectionLocker locker(m_criticalSection);
@@ -49,6 +58,10 @@ namespace GNC {
 			}			
 		}
 
+		void ConfigurationController::SetPreferredConfigFile(const std::string& path) {
+			m_PreferredGeneralConfigPath = wxString(FROMPATH(path));
+		}
+
 		void ConfigurationController::Flush()
 		{
 			wxFileName user(m_pathUserConfig);
@@ -196,16 +209,53 @@ namespace GNC {
 			return true;
 		}
 
+		//proxy settings..
+		ProxySettings ConfigurationController::GetProxySettings()
+		{
+			ProxySettings settings;
+			readStringUser("/GinkgoCore/Station/Proxy", "Hostname", settings.hostName);
+			readStringUser("/GinkgoCore/Station/Proxy", "Username", settings.userName);
+			readStringUser("/GinkgoCore/Station/Proxy", "Password", settings.password);
+			readStringUser("/GinkgoCore/Station/Proxy", "Exceptions", settings.exceptions);
+			readIntUser("/GinkgoCore/Station/Proxy", "Port", settings.port);
+			readBoolUser("/GinkgoCore/Station/Proxy", "UseProxy", settings.useProxy, false);
+			readBoolUser("/GinkgoCore/Station/Proxy", "RequiresAuth", settings.requiresAuth, false);
+
+			return settings;
+		}
+
+		void ConfigurationController::SetProxySettings(const ProxySettings& settings)
+		{
+			writeStringUser("/GinkgoCore/Station/Proxy", "Hostname", settings.hostName);
+			writeStringUser("/GinkgoCore/Station/Proxy", "Username", settings.userName);
+			writeStringUser("/GinkgoCore/Station/Proxy", "Password", settings.password);
+			writeStringUser("/GinkgoCore/Station/Proxy", "Exceptions", settings.exceptions);
+			writeIntUser("/GinkgoCore/Station/Proxy", "Port", settings.port);
+			writeBoolUser("/GinkgoCore/Station/Proxy", "UseProxy", settings.useProxy);
+			writeBoolUser("/GinkgoCore/Station/Proxy", "RequiresAuth", settings.requiresAuth);
+		}
+		//
+
 		bool ConfigurationController::saveGlobalConfigurationFile(const std::string& path)
 		{
 			wxString pathWx = FROMPATH(path);
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxFileOutputStream ostream(pathWx);
+
+			if (m_pPreferredGeneralConfig != NULL) {
+				return false;
+			}
+
 			return m_pGeneralConfig->Save(ostream);	
 		}
 
 		bool ConfigurationController::loadGlobalConfigurationFile(const std::string& path)
-		{
+		{			
+
+			if (m_pPreferredGeneralConfig != NULL) {
+				return false;
+			}
+
 			wxString pathWx = FROMPATH(path);
 			wxCriticalSectionLocker locker(m_criticalSection);
 			delete m_pGeneralConfig;
@@ -219,6 +269,11 @@ namespace GNC {
 
 		bool ConfigurationController::deleteEntry(TConfig type, const std::string& scope, const std::string&key)
 		{
+
+			if (m_pPreferredGeneralConfig != NULL) {
+				return false;
+			}
+
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			if (type==TC_General) {
@@ -248,7 +303,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = NULL;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -273,7 +333,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = m_pPreferredGeneralConfig;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -298,7 +363,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = NULL;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -323,7 +393,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = m_pPreferredGeneralConfig;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -348,7 +423,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = m_pPreferredGeneralConfig;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -373,7 +453,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = NULL;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -398,7 +483,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = m_pPreferredGeneralConfig;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -423,7 +513,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = NULL;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -448,7 +543,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = NULL;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -481,7 +581,12 @@ namespace GNC {
 				break;
 			case TC_General:
 			default:
-				config = m_pGeneralConfig;
+				if (m_pPreferredGeneralConfig != NULL) {
+					config = m_pPreferredGeneralConfig;
+				}
+				else {
+					config = m_pGeneralConfig;
+				}
 			}
 			if (config == NULL) {
 				return false;
@@ -589,7 +694,7 @@ namespace GNC {
 			else // fall back to the program directory
 			{
 				// extract the directory component of the program file name
-				wxSplitPath(wxGetFullModuleName(), &strDir, NULL, NULL);
+				wxFileName::SplitPath(wxGetFullModuleName(), &strDir, NULL, NULL);
 			}
 #else 
 			strDir.clear();
@@ -705,13 +810,18 @@ namespace GNC {
 			return str;
 		}
 
-
 		ConfigurationController::ConfigurationController() 
 		{			
-			wxString localFileconfig = GetLocalFileName(wxT("GinkgoUser"));
-			m_pUserConfig = new wxFileConfig(wxT("GinkgoUser"), wxT("Metaemotion"), localFileconfig,wxEmptyString,wxCONFIG_USE_LOCAL_FILE );
-			m_pathUserConfig = m_pGeneralConfig->GetLocalFileName(wxT("GinkgoUser"));
 
+			if (!m_PreferredGeneralConfigPath.IsEmpty()) {
+				m_pPreferredGeneralConfig = new wxFileConfig(wxEmptyString, wxEmptyString, m_PreferredGeneralConfigPath, wxEmptyString, wxCONFIG_USE_LOCAL_FILE);
+			}
+			else {
+				m_pPreferredGeneralConfig = NULL;
+			}
+			wxString localFileconfig = GetLocalFileName(wxT("GinkgoUser"));
+			m_pUserConfig = new wxFileConfig(wxT("GinkgoUser"), wxT("Metaemotion"), localFileconfig, wxEmptyString, wxCONFIG_USE_LOCAL_FILE );
+			
 			wxString pathEjecutable = wxStandardPaths::Get().GetExecutablePath();
 			wxFileName fileName(pathEjecutable);
 			//= than execute
@@ -735,6 +845,7 @@ namespace GNC {
 					}
 				}
 			}
+			m_pathUserConfig = m_pGeneralConfig->GetLocalFileName(wxT("GinkgoUser"));
 
 			wxString pathMachineConfig = fileName.GetPath(true) +  wxT("GinkgoMachine.ini");
 			if(wxFileExists(pathMachineConfig)) {
