@@ -66,13 +66,13 @@ namespace GNC {
 			ostr << "GinkgoLog.log";
 			log4cplus::SharedAppenderPtr append_0(gnkLog4cplus::GUIAppender::Instance());
 			append_0->setName(LOG4CPLUS_TEXT("AppenderGUI"));
-			append_0->setLayout( OFauto_ptr<log4cplus::Layout>(new log4cplus::PatternLayout(_Std("%d{%Y/%m/%d %H:%M:%S.%q} [%t] %-5p %c %x - %m%n").c_str())) );
+			append_0->setLayout( OFauto_ptr<log4cplus::Layout>(new log4cplus::PatternLayout("%D{%Y/%m/%d %H:%M:%S.%q} [%t] %-5p %c %x - %m%n")) );
 			log4cplus::Logger::getRoot().addAppender(append_0);
 			
 			OFString tmpStr(ostr.str().c_str());
 			log4cplus::SharedAppenderPtr append_1(new log4cplus::RollingFileAppender(tmpStr, 5*1024*1024, 5,true));
 			append_1->setName(LOG4CPLUS_TEXT("AppenderFichero"));
-			append_1->setLayout( OFauto_ptr<log4cplus::Layout>(new log4cplus::PatternLayout(_Std("%d{%Y/%m/%d %H:%M:%S.%q} [%t] %-5p %c %x - %m%n").c_str())) );
+			append_1->setLayout( OFauto_ptr<log4cplus::Layout>(new log4cplus::PatternLayout("%D{%Y/%m/%d %H:%M:%S.%q} [%t] %-5p %c %x - %m%n")) );
 			log4cplus::Logger::getRoot().addAppender(append_1);
 			
 			int logLevel;
