@@ -84,20 +84,22 @@ namespace GNC {
 		for(wxXmlNode* permiso = doc.GetRoot()->GetChildren(); permiso != NULL; permiso = permiso->GetNext()) {
 			if(permiso->GetName() == wxT("permiso")) {
 				if(
-					permiso->GetPropVal(wxT("namespace"), &wxNamespace) &&
-					permiso->GetPropVal(wxT("id"), &wxId) &&
-					permiso->GetPropVal(wxT("accion"), &wxAccion) &&
-					permiso->GetPropVal(wxT("activopordefecto"), &wxActivoPorDefecto) )
+					permiso->GetAttribute(wxT("namespace"), &wxNamespace) &&
+					permiso->GetAttribute(wxT("id"), &wxId) &&
+					permiso->GetAttribute(wxT("accion"), &wxAccion) &&
+					permiso->GetAttribute(wxT("activopordefecto"), &wxActivoPorDefecto) )
 				{
-					if (!permiso->GetPropVal(wxT("valorpordefecto"), &wxValorPorDefecto) || !permiso->GetPropVal(wxT("valor"), &wxValor) ) {
+					if (!permiso->GetAttribute(wxT("valorpordefecto"), &wxValorPorDefecto) || !permiso->GetAttribute(wxT("valor"), &wxValor) ) {
 						for (wxXmlNode* child = permiso->GetChildren(); child != NULL; child = child->GetNext()) {
 							if (child->GetChildren() == NULL) {
 								continue;
 							}
 							if (child->GetName() == wxT("default_value")) {
-								wxValorPorDefecto = child->GetChildren()->GetContent().Trim();
+								wxValorPorDefecto = child->GetChildren()->GetContent();
+								wxValorPorDefecto.Trim();
 							} else if (child->GetName() == wxT("value")) {
-								wxValor = child->GetChildren()->GetContent().Trim();
+								wxValor = child->GetChildren()->GetContent();
+								wxValor.Trim();
 							}
 						}							
 					}	
@@ -247,20 +249,22 @@ namespace GNC {
 		for(wxXmlNode* permiso = doc.GetRoot()->GetChildren(); permiso != NULL; permiso = permiso->GetNext()) {
 			if(permiso->GetName() == wxT("permiso")) {
 				if(
-					permiso->GetPropVal(wxT("namespace"), &wxNamespace) &&
-					permiso->GetPropVal(wxT("id"), &wxId) &&
-					permiso->GetPropVal(wxT("accion"), &wxAccion) &&
-					permiso->GetPropVal(wxT("activopordefecto"), &wxActivoPorDefecto) )
+					permiso->GetAttribute(wxT("namespace"), &wxNamespace) &&
+					permiso->GetAttribute(wxT("id"), &wxId) &&
+					permiso->GetAttribute(wxT("accion"), &wxAccion) &&
+					permiso->GetAttribute(wxT("activopordefecto"), &wxActivoPorDefecto) )
 				{
-					if (!permiso->GetPropVal(wxT("valorpordefecto"), &wxValorPorDefecto) || !permiso->GetPropVal(wxT("valor"), &wxValor) ) {
+					if (!permiso->GetAttribute(wxT("valorpordefecto"), &wxValorPorDefecto) || !permiso->GetAttribute(wxT("valor"), &wxValor) ) {
 						for (wxXmlNode* child = permiso->GetChildren(); child != NULL; child = child->GetNext()) {
 							if (child->GetChildren() == NULL) {
 								continue;
 							}
 							if (child->GetName() == wxT("default_value")) {
-								wxValorPorDefecto = child->GetChildren()->GetContent().Trim();
+								wxValorPorDefecto = child->GetChildren()->GetContent();
+								wxValorPorDefecto.Trim();
 							} else if (child->GetName() == wxT("value")) {
-								wxValor = child->GetChildren()->GetContent().Trim();
+								wxValor = child->GetChildren()->GetContent();
+								wxValor.Trim();
 							}
 						}							
 					}						
