@@ -13,7 +13,7 @@
  *
  */
 #include <api/controllers/icontroladorlog.h>
-#include <main/controllers/controladorlog.h>
+#include <api/controllers/icontroladorpermisos.h>
 #include "dicomfindassociation.h"
 #include <wx/string.h>
 #include <wx/intl.h>
@@ -38,7 +38,13 @@
 
 FindAssociation::FindAssociation(const std::string& ambitolog) : Association(ambitolog), pResultsWrapper(NULL) {
 	SetFindRootQueryRetrieveInformationModel(FRQRIM_Study);
-	maxResults = 400;
+	GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::IControladorPermisos::Instance()->Get("core.pacs.limits", "find_rsp_max_results");
+	if (estado) {
+		maxResults = estado.ObtenerValor<int>();
+	}
+	else {
+		maxResults = -1;
+	}
 	bPushResults = true;
 }
 
@@ -115,8 +121,8 @@ CONDITION FindAssociation::findSCU(T_ASC_Association *assoc, DcmDataset *query)
 void FindAssociation::findCallback(void* callbackData, T_DIMSE_C_FindRQ* /*rq*/, int responseCount, T_DIMSE_C_FindRSP* rsp, DcmDataset *responseIdentifiers) {
 	FindCallbackInfo* pCallback = (FindCallbackInfo*) callbackData;
 	
-	if (pCallback->pCaller->maxResults > 0 && responseCount > pCallback->pCaller->maxResults) {
-		LOG_DEBUG(pCallback->pCaller->ambitolog, "findCallback(): Ignoring response num " << responseCount << ". The maximum number of responses was " << pCallback->pCaller->maxResults);
+	if (pCallback->pCaller->GetMaxResults() > 0 && responseCount > pCallback->pCaller->GetMaxResults()) {
+		LOG_DEBUG(pCallback->pCaller->ambitolog, "findCallback(): Ignoring response num " << responseCount << ". The maximum number of responses was " << pCallback->pCaller->GetMaxResults());
 		rsp->DimseStatus = STATUS_FIND_Cancel_MatchingTerminatedDueToCancelRequest;
 		pCallback->pCaller->Stop();
 		ASC_releaseAssociation(pCallback->assoc);
