@@ -444,7 +444,7 @@ void GetAssociation::subOpCallback(void *pCaller, T_ASC_Network *aNet, T_ASC_Ass
 		return;
 	}
 	
-	wxString msg = wxString::Format(_("Downloading file %d"), ++caller->m_numeroImagenes);
+	wxString msg = wxString::Format(_("Downloading file %d"), (int)(++caller->m_numeroImagenes));
 	caller->m_mensaje = std::string(msg.ToUTF8());
 	LOG_DEBUG(caller->ambitolog, caller->m_mensaje);
 	caller->NotificarProgreso((float)caller->m_numeroImagenes/100,caller->m_mensaje);
@@ -574,10 +574,10 @@ void GetAssociation::storeSCPCallback(void *callbackData, T_DIMSE_StoreProgress
 	if (progress->state == DIMSE_StoreBegin) {
 		wxString msg;
 		if (caller->m_wellKnownNumResults > 0) {
-			msg = wxString::Format(_("Downloading file %d/%d"), caller->m_numeroImagenes + 1, caller->m_wellKnownNumResults );
+			msg = wxString::Format(_("Downloading file %d/%d"), (int)(caller->m_numeroImagenes + 1), (int)(caller->m_wellKnownNumResults) );
 		}
 		else {
-			msg = wxString::Format(_("Downloading file %d"), caller->m_numeroImagenes + 1 );
+			msg = wxString::Format(_("Downloading file %d"), (int)(caller->m_numeroImagenes + 1) );
 		}
 		caller->m_mensaje = std::string(msg.ToUTF8());
 		LOG_DEBUG(caller->ambitolog, caller->m_mensaje);
@@ -790,12 +790,18 @@ void GetAssociation::OnFileReceived(const std::string& fileName, DcmDataset* dse
 			std::string UIDImagen;
 			OFString OFInstanceNumber;
 			std::string InstanceNumber;
-			if (dset->findAndGetOFString(DCM_SOPInstanceUID, OFUIDImagen).good() && dset->findAndGetOFString(DCM_InstanceNumber, OFInstanceNumber).good()) {
+			if (dset->findAndGetOFString(DCM_SOPInstanceUID, OFUIDImagen).good()) {
 				UIDImagen.assign(OFUIDImagen.c_str());
-				InstanceNumber.assign(OFInstanceNumber.c_str());
+				 if (dset->findAndGetOFString(DCM_InstanceNumber, OFInstanceNumber).good()) {
+					InstanceNumber.assign(OFInstanceNumber.c_str());
+				 }
+				 else {
+					 LOG_WARN(ambitolog, "InstanceNumber not found. Setting to default");
+					 InstanceNumber.assign("1");
+				 }
 				m_pModelo->InsertarImagen(SerieUID,UIDImagen, InstanceNumber, fileName);
 			} else {
-				LOG_ERROR("DCMGET", "InstanceUID or InstanceNumber not found");
+				LOG_ERROR("DCMGET", "InstanceUID not found");
 			}
 		}
 	}
