@@ -41,10 +41,6 @@ namespace GNC{
 #endif
 
 typedef enum CallbackType {
-	CT_FindPacientes,
-	CT_FindEstudios,
-	CT_FindSeries,
-	CT_FindImagenes,
 	CT_MoveEstudio,
 	CT_MoveSerie,
 	CT_MoveImagen,
@@ -119,6 +115,59 @@ public:
 		return true;
 	}
 
+	bool QueryServer(DcmDataset* query, const GNC::GCS::Ptr<DicomServer>& server, std::list< GNC::GCS::Ptr<GIL::DICOM::DicomDataset> >& resultsWrapper, const std::string& local_aet) {
+		if (!server.IsValid()) {
+			return false;
+		}
+
+		if (!Net->Initiallized()) {
+		
+			Net->InitializeNetwork(T::GetTimeout(), T::GetRole(), T::GetAcceptorPort());
+		}
+
+		T::Create(
+			server->AET,
+			server->HostName,
+			server->Port,
+			local_aet
+		);
+
+		T::SetNotificadorProgreso(m_pNotificadorProgreso);
+
+		T::SetCallbackInfo(&resultsWrapper, server);
+
+		LOG_INFO(ambitolog, "Connecting: AET = " << server->AET << ", Host = " << server->HostName << ", Puerto = " << server->Port << ", Local AET = " << local_aet << ", PDU = " << server->PDU);
+		CONDITION r = T::Connect(Net, server->PDU);
+
+		CONDITION c = ECC_Normal;
+
+		if (r.good() == true) {
+			LOG_DEBUG(ambitolog, "Requesting object:" << std::endl << DumpDataset(query));
+			c = T::SendObject(query);
+		}
+		else {
+			LOG_DEBUG(ambitolog, "Error connecting:" << r.text());
+			T::Drop();
+			T::Destroy();
+			LOG_INFO(ambitolog, "Disconnected");
+			throw GIL::DICOM::PACSException(r.text());
+		}
+
+		if (!c.good()) {
+			LOG_DEBUG(ambitolog, "Error requesting object: " << c.text());
+			T::Drop();
+			T::Destroy();
+			LOG_INFO(ambitolog, "Disconnected");
+			throw GIL::DICOM::PACSException(c.text());
+		}
+
+		LOG_INFO(ambitolog, "Disconnected");
+		T::Drop();
+		
+		return r.good();
+	}
+
+	///DEPRECATED! IModeloDICOM has to be replaced by results wrapper
 	bool QueryServer(DcmDataset* query, const GNC::GCS::Ptr<DicomServer>& server, IModeloDicom* pModelo, const std::string& local_aet, CallbackType callbackType) {
 		if (pModelo == NULL && callbackType != CT_None)  {
 			return false;
@@ -173,18 +222,6 @@ public:
 			for (unsigned long i = 0; i < result->card(); ++i) {
 				DcmDataset* dset = new DcmDataset( *(static_cast<DcmDataset*>(result->elem(i))) );
 				switch (callbackType) {
-					case CT_FindPacientes:
-						OnBuscarPacientes(query, dset, server, pModelo);
-						break;
-					case CT_FindEstudios:
-						OnBuscarEstudios(query, dset, server, pModelo);
-						break;
-					case CT_FindSeries:
-						OnBuscarSeries(query, dset, server, pModelo);
-						break;
-					case CT_FindImagenes:
-						OnBuscarImagenes(query,dset, server, pModelo);
-						break;
 					case CT_MoveEstudio:
 						OnMoverEstudio(dset, pModelo);
 						break;
@@ -378,13 +415,16 @@ public:
     	OFString OFSerieUID;
     	OFString OFImagenUID;
 		OFString OFInstanceNumber;
-		if (dset->findAndGetOFString(DCM_SeriesInstanceUID, OFSerieUID).bad() || dset->findAndGetOFString(DCM_SOPInstanceUID, OFImagenUID).bad()
-			|| dset->findAndGetOFString(DCM_InstanceNumber, OFInstanceNumber).bad()) {
+		if (dset->findAndGetOFString(DCM_SeriesInstanceUID, OFSerieUID).bad() || dset->findAndGetOFString(DCM_SOPInstanceUID, OFImagenUID).bad()) {
 			if (!dset->isEmpty()) {
 				LOG_ERROR(ambitolog, "El PACS no devolvió el SeriesInstanceUID o el SOPInstanceUID de la imagen. Entrada ignorada.");
 			}
 			return;
 		}
+		if (OFInstanceNumber.empty()) {
+			LOG_WARN(ambitolog, "InstanceNumber not found. Setting to default");
+			OFInstanceNumber = "1";
+		}
 
 		std::string SerieUID;
 		std::string ImagenUID;
