@@ -1282,7 +1282,7 @@ namespace GIL {
 			ResetearMedida(true);
 			while ((iter != enditer) && (cond == EC_Normal) && !_shouldAbort) // compare with EC_Normal since DUL_PEERREQUESTEDRELEASE is also good()
 			{
-				wxString msg = wxString::Format(_("Uploading file %d of %d"),(_numberSent+1), listaFicheros.size());
+				wxString msg = wxString::Format(_("Uploading file %d of %d"), (int)(_numberSent+1), (int)(listaFicheros.size()) );
 				m_mensaje = std::string(msg.ToUTF8());
 				pNotificador->NotificarProgreso(0.0f, m_mensaje);
 
