@@ -105,7 +105,10 @@ namespace GIL
 			{
 				std::ostringstream ostr;
 				ostr << tempDir;
-				ostr << wxFileName::GetPathSeparator();
+				char c;
+				if (wxFileName::GetPathSeparator().GetAsChar(&c)) {
+					ostr << c;
+				}
 				ostr << "1.dcm";
 				tempFile = ostr.str();
 			}
@@ -975,7 +978,13 @@ namespace GIL
 							ov = wxString(v.c_str(), *m_pConv).ToUTF8();
 						} 
 						if (ov.size() == 0 && v.size() != ov.size()) {
-							ov = wxString::FromAscii(v.c_str()).ToUTF8();
+							//workarround try iso...
+							wxCSConv tryIso(wxFONTENCODING_ISO8859_1);
+							ov = wxString(v.c_str(), tryIso).ToUTF8();
+							//last chance... try ascii
+							if (ov.size() == 0 && v.size() != ov.size()) {
+								ov = wxString::FromAscii(v.c_str()).ToUTF8();
+							}
 						}
 
 						cbase->tags[tag] = ov;
