@@ -288,8 +288,8 @@ bool GNC::GCS::Layout::isACell()
 wxXmlNode* GNC::GCS::Layout::serialize()
 {
 	wxXmlNode* layoutNode = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, LO_ROOT);
-	layoutNode->AddAttribute(LO_ATT_ROWS, wxString::Format(wxT("%d"), this->rows));
-	layoutNode->AddAttribute(LO_ATT_COLUMNS, wxString::Format(wxT("%d"), this->columns));
+	layoutNode->AddAttribute(LO_ATT_ROWS, wxString::Format(wxT("%d"), (int)(this->rows)));
+	layoutNode->AddAttribute(LO_ATT_COLUMNS, wxString::Format(wxT("%d"), (int)(this->columns)));
 	for (std::list<GNC::GCS::Ptr<Layout> >::const_iterator it = this->cellList.begin(); it != this->cellList.end(); ++it)
 	{
 		if ((*it).IsValid()) {
@@ -313,10 +313,10 @@ wxXmlNode* GNC::GCS::Layout::serialize()
 		if (isMaximized) {
 			layoutNode->AddAttribute(LO_ATT_MAXIMIZED, wxEmptyString);
 		}
-		layoutNode->AddAttribute(LO_ATT_X_POS, wxString::Format(wxT("%d"), this->xPos));
-		layoutNode->AddAttribute(LO_ATT_Y_POS, wxString::Format(wxT("%d"), this->yPos));
-		layoutNode->AddAttribute(LO_ATT_WIDTH, wxString::Format(wxT("%d"), this->width));
-		layoutNode->AddAttribute(LO_ATT_HEIGHT, wxString::Format(wxT("%d"), this->height));
+		layoutNode->AddAttribute(LO_ATT_X_POS, wxString::Format(wxT("%d"), (int)(this->xPos)));
+		layoutNode->AddAttribute(LO_ATT_Y_POS, wxString::Format(wxT("%d"), (int)(this->yPos)));
+		layoutNode->AddAttribute(LO_ATT_WIDTH, wxString::Format(wxT("%d"), (int)(this->width)));
+		layoutNode->AddAttribute(LO_ATT_HEIGHT, wxString::Format(wxT("%d"), (int)(this->height)));
 	}
 
 	return layoutNode;
@@ -661,7 +661,7 @@ wxXmlNode* GNC::GCS::HangingProtocol::serialize()
 	hangingNode->AddAttribute(HP_ATT_NAME, wxString::FromUTF8(this->name.c_str()));
 	hangingNode->AddAttribute(HP_ATT_DESCRIPTION, wxString::FromUTF8(this->description.c_str()));
 	hangingNode->AddAttribute(HP_ATT_MODULE_SID, wxString::FromUTF8(this->moduleSid.c_str()));
-	hangingNode->AddAttribute(HP_ATT_MODE_ID, wxString::Format(wxT("%d"), this->openingMode));
+	hangingNode->AddAttribute(HP_ATT_MODE_ID, wxString::Format(wxT("%d"), (int) this->openingMode));
 	hangingNode->AddAttribute(HP_ATT_ACTIVE, active?wxT("true"):wxT("false"));
 
 	wxXmlNode* layoutsNode = new wxXmlNode(hangingNode, wxXML_ELEMENT_NODE, LOS_ROOT);
