@@ -1782,6 +1782,28 @@ GNC::GCS::HistoryController::StringList GNC::GCS::HistoryController::GetSeriesSo
 	return result;
 }
 
+GNC::GCS::HistoryController::StringList GNC::GCS::HistoryController::GetSeriesSopClasses(long series_pk)
+{
+	GNC::GCS::HistoryController::StringList result;
+	try {
+		wxSQLite3StatementBuffer bufSQL;
+		bufSQL.Format("SELECT distinct sopcuid  "
+			"FROM File WHERE "
+			"File.series_fk='%ld' "
+			,series_pk);
+		wxSQLite3ResultSet resultados = m_pConexion->ExecuteQuery(bufSQL);
+		while (resultados.NextRow()) {
+			std::string sopCuid(resultados.GetAsString(wxT("sopcuid")).ToUTF8());
+			result.push_back( sopCuid );
+		}
+	}catch (wxSQLite3Exception& ex) {
+		LOG_ERROR("BBDD", "GetSeriesSopClasses "<<ex.GetMessage().ToUTF8())
+			wxMessageBox(_("Error reading history: \n")+ex.GetMessage(), _("Info"),
+			wxOK | wxICON_WARNING);
+	}
+	return result;
+}
+
 char GNC::GCS::HistoryController::GetSeriesOrientation(long series_pk)
 {
 	char orientacion = '?';
@@ -2129,7 +2151,9 @@ bool GNC::GCS::HistoryController::ReadFile(DICOMFileModel& modeloDCM, const std:
 	if (base.getTag(GKDCM_PixelSpacing, tag)) {
 		modeloDCM.file.spacing = tag;
 	}
-
+	else if (base.getTag(GKDCM_ImagerPixelSpacing, tag)) {
+		modeloDCM.file.spacing = tag;
+	}
 	
 	std::string tagOrientation;
 	//GKDCM_ImageOrientationPatient its longer than info tags...
