@@ -12,15 +12,15 @@
 *
 */
 
+#include "historytoolscontroller.h"
+#include <main/controllers/controladorlog.h>
+#include <main/gui/history3/historypanel3.h>
+
 #include <wx/event.h>
 #include <wx/menu.h>
 #include <wx/sizer.h>
 #include <wx/dc.h>
-#include <wx/aui/auibar.h>
-
-#include "historytoolscontroller.h"
-#include <main/controllers/controladorlog.h>
-#include <main/gui/history3/historypanel3.h>
+#include <wx/wxginkgotoolbar.h>
 
 GNC::HistoryToolsController::HistoryToolsController()
 {
@@ -150,7 +150,7 @@ void GNC::HistoryToolsController::AppendsToolInMenu(wxEvtHandler* pParent, wxMen
 
 }
 
-void GNC::HistoryToolsController::AppendsToolInToolBar(wxAuiToolBar* pParent, GNC::GCS::IHistoryTool::TToolFamily family)
+void GNC::HistoryToolsController::AppendsToolInToolBar(wxGinkgoToolBar* pParent, GNC::GCS::IHistoryTool::TToolFamily family)
 {
 	GNC::HistoryToolsController::ToolList list = GetTools(family);
 	for (GNC::HistoryToolsController::ToolList::const_iterator it = list.begin(); it != list.end(); ++it) {
@@ -160,7 +160,7 @@ void GNC::HistoryToolsController::AppendsToolInToolBar(wxAuiToolBar* pParent, GN
 	}
 }
 
-void GNC::HistoryToolsController::AppendsBigToolsInToolBar(wxAuiToolBar* pParent)
+void GNC::HistoryToolsController::AppendsBigToolsInToolBar(wxGinkgoToolBar* pParent)
 {
 	for(ToolMap::iterator it = m_tools.begin(); it!= m_tools.end(); ++it){
 		if ((*it).second->Enabled()) {
