@@ -18,7 +18,7 @@
 #include <api/api.h>
 #include <api/ihistorytool.h>
 
-class wxAuiToolBar;
+class wxGinkgoToolBar;
 class wxWindow;
 class wxBitmap;
 class wxEvtHandler;
@@ -74,8 +74,8 @@ namespace GNC {
 		ToolList GetTools(GNC::GCS::IHistoryTool::TToolFamily family);
 
 		void AppendsToolInMenu(wxEvtHandler* pParent, wxMenu* pMenu, GNC::GCS::IHistoryTool::TToolFamily family);
-		void AppendsToolInToolBar(wxAuiToolBar* pParent, GNC::GCS::IHistoryTool::TToolFamily family);
-		void AppendsBigToolsInToolBar(wxAuiToolBar* pParent);
+		void AppendsToolInToolBar(wxGinkgoToolBar* pParent, GNC::GCS::IHistoryTool::TToolFamily family);
+		void AppendsBigToolsInToolBar(wxGinkgoToolBar* pParent);
 
 		GNC::GCS::IHistoryTool* GetTool(GNC::GCS::IHistoryTool::UID id);
 
