@@ -14,6 +14,7 @@
 #include <set>
 #include <ctime>
 
+#include <wx/checkbox.h>
 #include <wx/statbmp.h>
 #include <wx/bmpbuttn.h>
 #include <wx/uri.h>
@@ -133,12 +134,10 @@ bool GIL::IntegrationController::Process(GIL::IntegrationModelList& models)
 					throw GIL::IntegrationException("No existe el modulo asociado", "Modelo", true);
 				}
 			}
-			bool noerror = false;
 
 			try{
 				GNC::GUI::wxWizardImportacionGinkgo ib(NULL, modelo, uidModulo);
 				ib.ShowModal();
-				noerror = ib.IsOK();
 			}
 			catch(GIL::DICOM::I2DException& i){
 				LOG_ERROR("GIL/WF/Importar", (const std::string)i);
@@ -150,10 +149,8 @@ bool GIL::IntegrationController::Process(GIL::IntegrationModelList& models)
 			{
 				LOG_ERROR("GIL/WF/Importar", std::string("Error al importar: Error interno"));
 			}
-			if (noerror) {
-				GNC::Entorno::Instance()->GetVentanaPrincipal()->MostrarVentana();
-				numProcessed++;
-			}
+			GNC::Entorno::Instance()->GetVentanaPrincipal()->MostrarVentana();
+			numProcessed++;
 		}
 		else if(modelo->accion == GIL::IModeloIntegracion::TA_Obtener) 
 		{
@@ -731,18 +728,18 @@ std::string GIL::IntegrationController::ParsesModelFromURL(const wxString& url)
 			if (pacsParameter.StartsWith(wxT("dicom://"))) {
 				wxXmlNode* pacsNode = new wxXmlNode(doc.GetRoot(), wxXML_ELEMENT_NODE, wxT("pacs"));
 				//randomSid
-				pacsSid =  wxString::Format(wxT("temppacs%d"), rand());
-				pacsNode->AddProperty(wxT("sid"),pacsSid);
+				pacsSid =  wxString::Format(wxT("temppacs%d"), (int) rand());
+				pacsNode->AddAttribute(wxT("sid"),pacsSid);
 				//parse url...
 				wxURI pacsUri(pacsParameter);
 
 				if (pacsUri.GetUserInfo().IsEmpty() || pacsUri.GetServer().IsEmpty()) {
 					throw IntegrationException("Error in pacs url format: dicom://AET@host:port", "URLPARSER");
 				}
-				pacsNode->AddProperty(wxT("aet"), pacsUri.GetUserInfo());
-				pacsNode->AddProperty(wxT("hostname"), pacsUri.GetServer());
+				pacsNode->AddAttribute(wxT("aet"), pacsUri.GetUserInfo());
+				pacsNode->AddAttribute(wxT("hostname"), pacsUri.GetServer());
 				if (!pacsUri.GetPort().IsEmpty()) {
-					pacsNode->AddProperty(wxT("port"), pacsUri.GetPort());
+					pacsNode->AddAttribute(wxT("port"), pacsUri.GetPort());
 				}
 
 				//tokenize query &
@@ -751,15 +748,15 @@ std::string GIL::IntegrationController::ParsesModelFromURL(const wxString& url)
 					wxString token = dicomTknzr.GetNextToken();
 					if (token.StartsWith(wxT("method="))) {
 						int pos = token.Find(wxT("="));
-						pacsNode->AddProperty(wxT("retrieve-method"),wxURI::Unescape(token.SubString(pos+1, token.size() - 1)));
+						pacsNode->AddAttribute(wxT("retrieve-method"),wxURI::Unescape(token.SubString(pos+1, token.size() - 1)));
 					}
 					if (token.StartsWith(wxT("mode="))) {
 						int pos = token.Find(wxT("="));
-						pacsNode->AddProperty(wxT("retrieve-mode"),wxURI::Unescape(token.SubString(pos+1, token.size() - 1)));
+						pacsNode->AddAttribute(wxT("retrieve-mode"),wxURI::Unescape(token.SubString(pos+1, token.size() - 1)));
 					}
 					if (token.StartsWith(wxT("wadourl="))) {
 						int pos = token.Find(wxT("="));
-						pacsNode->AddProperty(wxT("wado-url"),wxURI::Unescape(token.SubString(pos+1, token.size() - 1)));
+						pacsNode->AddAttribute(wxT("wado-url"),wxURI::Unescape(token.SubString(pos+1, token.size() - 1)));
 					}
 				}				
 			} else {
@@ -774,20 +771,20 @@ std::string GIL::IntegrationController::ParsesModelFromURL(const wxString& url)
 			{
 				//retrieve
 				//action=retrieve&aid=JIMENA&query=group|element:value
-				workFlowNode->AddProperty(wxT("action"), wxT("retrieve"));
+				workFlowNode->AddAttribute(wxT("action"), wxT("retrieve"));
 				if (!pacsSid.IsEmpty()) {
-					workFlowNode->AddProperty(wxT("pacs-retrieve-sid"), pacsSid);
+					workFlowNode->AddAttribute(wxT("pacs-retrieve-sid"), pacsSid);
 				}
 				//retrieve..
 				//parse level and query...
 				if (parameters.find("level") != parameters.end()) {
 					wxXmlNode* qrLevel = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("query-retrieve-level"));
-					qrLevel->AddProperty(wxT("value"), wxString::FromUTF8(parameters["level"].c_str()));
+					qrLevel->AddAttribute(wxT("value"), wxString::FromUTF8(parameters["level"].c_str()));
 				}
 				//aid
 				if (parameters.find("aid") != parameters.end()) {
 					wxXmlNode* qrLevel = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("hce"));
-					qrLevel->AddProperty(wxT("aid"), wxString::FromUTF8(parameters["aid"].c_str()));
+					qrLevel->AddAttribute(wxT("aid"), wxString::FromUTF8(parameters["aid"].c_str()));
 				}
 				//parse query...
 				//query=0020|000D:1.2.3.4.5.6
@@ -799,33 +796,33 @@ std::string GIL::IntegrationController::ParsesModelFromURL(const wxString& url)
 						throw IntegrationException("Malformated query string: group|element:value", "URLPARSER");
 					}
 					wxXmlNode* queryNode = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("metadata"));
-					queryNode->AddProperty(wxT("code"), wxT("DICOM"));
-					queryNode->AddProperty(wxT("key"), queryString.SubString(0, colonPosition-1));
-					queryNode->AddProperty(wxT("value"), queryString.SubString(colonPosition+1, queryString.size() - 1));
+					queryNode->AddAttribute(wxT("code"), wxT("DICOM"));
+					queryNode->AddAttribute(wxT("key"), queryString.SubString(0, colonPosition-1));
+					queryNode->AddAttribute(wxT("value"), queryString.SubString(colonPosition+1, queryString.size() - 1));
 				}
 			} else if(parameters["action"] == "dicomize") {
 				//dicomize... 
 				//action=dicomize&petition-id=asdf&scope=AA&patient-id=234234&episode-number=asewr&query...
 				//action
-				workFlowNode->AddProperty(wxT("action"), wxT("dicomize"));
+				workFlowNode->AddAttribute(wxT("action"), wxT("dicomize"));
 				//pacs
 				if (!pacsSid.IsEmpty()) {
-					workFlowNode->AddProperty(wxT("pacs-store-sid"), pacsSid);
+					workFlowNode->AddAttribute(wxT("pacs-store-sid"), pacsSid);
 				}
 				//petition-id
 				if (parameters.find("petition-id") != parameters.end()) {
-					workFlowNode->AddProperty(wxT("petition-id"), wxString::FromUTF8(parameters["petition-id"].c_str()));
+					workFlowNode->AddAttribute(wxT("petition-id"), wxString::FromUTF8(parameters["petition-id"].c_str()));
 				}
 				//scope
 				if (parameters.find("scope") != parameters.end()) {
-					workFlowNode->AddProperty(wxT("scope"), wxString::FromUTF8(parameters["scope"].c_str()));
+					workFlowNode->AddAttribute(wxT("scope"), wxString::FromUTF8(parameters["scope"].c_str()));
 				}
 				//patient...
 				if (parameters.find("patient-id") != parameters.end()) {
 					wxXmlNode* patientNode = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("patient"));
 					wxXmlNode* idNode = new wxXmlNode(patientNode, wxXML_ELEMENT_NODE, wxT("id"));
-					idNode->AddProperty(wxT("code"),wxT("PI"));
-					idNode->AddProperty(wxT("value"), wxString::FromUTF8(parameters["patient-id"].c_str()));
+					idNode->AddAttribute(wxT("code"),wxT("PI"));
+					idNode->AddAttribute(wxT("value"), wxString::FromUTF8(parameters["patient-id"].c_str()));
 					//episode-number
 					if (parameters.find("episode-number") != parameters.end()) {
 						wxXmlNode* episodeNumberNode = new wxXmlNode(patientNode, wxXML_ELEMENT_NODE, wxT("episode-number"));
@@ -844,9 +841,9 @@ std::string GIL::IntegrationController::ParsesModelFromURL(const wxString& url)
 						throw IntegrationException("Malformated query string: group|element:value", "URLPARSER");
 					}
 					wxXmlNode* queryNode = new wxXmlNode(workFlowNode, wxXML_ELEMENT_NODE, wxT("metadata"));
-					queryNode->AddProperty(wxT("code"), wxT("DICOM"));
-					queryNode->AddProperty(wxT("key"), queryString.SubString(0, colonPosition-1));
-					queryNode->AddProperty(wxT("value"), queryString.SubString(colonPosition+1, queryString.size() - 1));
+					queryNode->AddAttribute(wxT("code"), wxT("DICOM"));
+					queryNode->AddAttribute(wxT("key"), queryString.SubString(0, colonPosition-1));
+					queryNode->AddAttribute(wxT("value"), queryString.SubString(colonPosition+1, queryString.size() - 1));
 				}
 			} else {
 				throw IntegrationException("Unsupported action parameter", "URLPARSER");
