@@ -78,12 +78,12 @@ GNC::GCS::AnnotationSettings::AnnotationSettings()
 		${0010|0040:?} ${0010|0030} ${0010,1010} // {Sex} {BirthDate} {PatientAge}
 		${0010|1030:?} Kg ${0010|1020:?} m.      // {PatientWeight} {PatientSize}
 		${0008|1030}                             // {Study Description}
-		${0008|0020} {0008|0030}                 // {StudyDate} {StudyTime}
+		${0008|0020} ${0008|0030}                 // {StudyDate} {StudyTime}
 		${0008|103E}                             // {SeriesDescription}
 		Modalidad: ${0008|0060}                  // {Modality}
 		*/
 		std::ostringstream ostr;
-		ostr << "${0010|0040:?} ${0010|0030} ${0010,1010}${NEWLINE}${0010|1030:?} Kg ${0010|1020:?} m.${NEWLINE}${0008|1030}${NEWLINE}${0008|0020} {0008|0030}${NEWLINE}${0008|103E}${NEWLINE}" << _Std("Modality") << ": ${0008|0060}";
+		ostr << "${0010|0040:?} ${0010|0030} ${0010,1010}${NEWLINE}${0010|1030:?} Kg ${0010|1020:?} m.${NEWLINE}${0008|1030}${NEWLINE}${0008|0020} ${0008|0030}${NEWLINE}${0008|103E}${NEWLINE}" << _Std("Modality") << ": ${0008|0060}";
 		annotation[TP_TopRight] = ostr.str();
 	}
 	{
