@@ -548,7 +548,6 @@ namespace GIL {
 				std::list<std::string> listOfModalities;
 				{
 					NetClient<FindAssociation> f(connectionKey, "C-GET/FIND", pNotificador);
-					f.SetMaxResults(-1);
 
 					std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
@@ -651,7 +650,6 @@ namespace GIL {
 				}
 
 				NetClient<FindAssociation> f(connectionKey, "C-GET/FIND", pNotificador);
-				f.SetMaxResults(-1);
 
 				std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
@@ -759,7 +757,6 @@ namespace GIL {
 				}
 
 				NetClient<FindAssociation> f(connectionKey, "C-GET/FIND", pNotificador);
-				f.SetMaxResults(-1);
 
 				std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
@@ -807,7 +804,6 @@ namespace GIL {
 
 			//association to make finds...
 			NetClient<FindAssociation> f(connectionKey, "C-GET/FIND", pNotificador);
-			f.SetMaxResults(-1);
 
 			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
@@ -1014,7 +1010,6 @@ namespace GIL {
 					}
 
 					NetClient<GetAssociation> a(connectionKey, "C-GET", pNotificador);
-					a.SetMaxResults(-1);
 					a.SetWellKnownNumResults(numResults);
 					a.SetStorageSOPClasses(GIL::DICOM::Conformance::GetModalities().GetSupportedSOPClassUIDs(modality));
 					a.SetModelo(pModelo);
@@ -1133,7 +1128,6 @@ namespace GIL {
 
 					//association to make finds...
 					NetClient<FindAssociation> f(connectionKey, "WADO/FIND", pNotificador);
-					f.SetMaxResults(-1);
 
 					std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
