@@ -89,7 +89,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 			if (nodo->GetName().CmpNoCase(wxT("pacs")) == 0) { // Configuracion de PACS
 				GIL::IModeloPACSServer pacsServer;
 
-				propVal = nodo->GetPropVal(wxT("sid"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("sid"), wxEmptyString);
 				if( !propVal.empty() ) {
 					pacsServer.sid = propVal.ToUTF8();
 				}
@@ -97,7 +97,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					throw IntegrationException(_Std("Omitted Identificator"), xpp, "CONF/pacs");
 				}
 
-				propVal = nodo->GetPropVal(wxT("aet"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("aet"), wxEmptyString);
 				if( !propVal.empty() ) {
 					pacsServer.AET = propVal.ToUTF8();
 				}
@@ -105,7 +105,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					throw IntegrationException(_Std("Omitted AET"), xpp, "CONF/pacs");
 				}
 
-				propVal = nodo->GetPropVal(wxT("hostname"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("hostname"), wxEmptyString);
 				if( !propVal.empty() ) {
 					pacsServer.hostname = propVal.ToUTF8();
 				}
@@ -113,7 +113,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					throw IntegrationException(_Std("Hostname missing"), xpp, "CONF/pacs");
 				}
 
-				propVal = nodo->GetPropVal(wxT("port"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("port"), wxEmptyString);
 				if( !propVal.empty() ) {
 					pacsServer.puerto = propVal.ToUTF8();
 				}
@@ -121,7 +121,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					throw IntegrationException(_Std("Omitted port"), xpp, "CONF/pacs");
 				}
 				
-				propVal = nodo->GetPropVal(wxT("tls"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("tls"), wxEmptyString);
 				if( propVal.CmpNoCase(wxT("yes")) == 0 || propVal.CmpNoCase(wxT("true")) == 0 || propVal.CmpNoCase(wxT("si")) == 0 || propVal.CmpNoCase(wxT("1")) == 0 ) {
 					pacsServer.tls = true;
 				}
@@ -129,22 +129,22 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.tls = false;
 				}
 
-				propVal = nodo->GetPropVal(wxT("pacs-user"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("pacs-user"), wxEmptyString);
 				if( !propVal.empty()) {
 					pacsServer.user = propVal.ToUTF8();
 				}
 
-				propVal = nodo->GetPropVal(wxT("pacs-password"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("pacs-password"), wxEmptyString);
 				if( !propVal.empty()) {
 					pacsServer.password = propVal.ToUTF8();
 				}
 
-				propVal = nodo->GetPropVal(wxT("wado-url"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("wado-url"), wxEmptyString);
 				if( !propVal.empty()) {
 					pacsServer.wadoURI = propVal.ToUTF8();
 				}
 
-				propVal = nodo->GetPropVal(wxT("verify-credentials"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("verify-credentials"), wxEmptyString);
 				if( propVal.CmpNoCase(wxT("yes")) == 0 || propVal.CmpNoCase(wxT("true")) == 0 || propVal.CmpNoCase(wxT("si")) == 0 || propVal.CmpNoCase(wxT("1")) == 0 ) {
 					pacsServer.verify = true;
 				}
@@ -152,7 +152,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.verify = false;
 				}
 
-				propVal = nodo->GetPropVal(wxT("retrieve-method"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("retrieve-method"), wxEmptyString);
 				if( propVal.CmpNoCase(wxT("get")) == 0 ) {
 					pacsServer.metodo = GIL::IModeloPACSServer::IMPS_GET;
 				}
@@ -162,7 +162,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.metodo = GIL::IModeloPACSServer::IMPS_MOVE;
 				}
 				
-				propVal = nodo->GetPropVal(wxT("pdu"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("pdu"), wxEmptyString);
 				if( propVal.empty()) {
 					pacsServer.pdu = "16384";
 				}
@@ -170,7 +170,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.pdu = propVal.ToUTF8();
 				}
 
-				propVal = nodo->GetPropVal(wxT("retrieve-level"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("retrieve-level"), wxEmptyString);
 				if( propVal.empty()) {
 					pacsServer.retrieveLevel = "SERIES";
 				}
@@ -178,7 +178,7 @@ void GIL::ParserXMLEnglish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.retrieveLevel = propVal.ToUTF8();
 				}
 
-				propVal = nodo->GetPropVal(wxT("charset"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("charset"), wxEmptyString);
 				if( !propVal.empty() ) {
 					pacsServer.defaultCharset = propVal.ToUTF8();
 				}
@@ -282,14 +282,14 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 	}
 	//
 
-	propVal = nodo->GetPropVal(wxT("tid"), wxEmptyString);
+	propVal = nodo->GetAttribute(wxT("tid"), wxEmptyString);
 	if( !propVal.empty() ) {
 		modelo->idPlantilla = propVal.ToUTF8();
 	} else {
 		modelo->idPlantilla = "";
 	}
 
-	propVal = nodo->GetPropVal(wxT("action"), wxEmptyString).Lower();
+	propVal = nodo->GetAttribute(wxT("action"), wxEmptyString).Lower();
 	if ( !propVal.empty() ) {
 
 		if (propVal.CmpNoCase(wxT("retrieve")) == 0){
@@ -312,18 +312,18 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 		throw IntegrationException(_Std("\"action\" attribute expected at \"gnkworkflow\" scope"), xpp, "CONF/template");
 	}
 
-	propVal = nodo->GetPropVal(wxT("petition-id"), wxEmptyString);
+	propVal = nodo->GetAttribute(wxT("petition-id"), wxEmptyString);
 	if( !propVal.empty() ) {
 		modelo->GlobalVariables.InsertVariable(GKDI_HCE_PETITION_ID, std::string(propVal.ToUTF8()));
 	}
 
-	propVal = nodo->GetPropVal(wxT("scope"), wxEmptyString);
+	propVal = nodo->GetAttribute(wxT("scope"), wxEmptyString);
 	if( !propVal.empty() ) {
 		modelo->GlobalVariables.InsertVariable(GKDI_JIMENA_AMBITO_PETICION,std::string(propVal.ToUTF8()));
 	}
 
-	if( nodo->HasProp(wxT("pacs-retrieve-sid")) ) {
-		propVal = nodo->GetPropVal(wxT("pacs-retrieve-sid"), wxEmptyString);
+	if( nodo->HasAttribute(wxT("pacs-retrieve-sid")) ) {
+		propVal = nodo->GetAttribute(wxT("pacs-retrieve-sid"), wxEmptyString);
 		if (!propVal.IsEmpty()) {
 			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_RETRIEVE_SID, std::string(propVal.ToUTF8()));
 		}	
@@ -332,8 +332,8 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 		}		
 	}
 
-	if( nodo->HasProp(wxT("pacs-store-sid")) ) {
-		propVal = nodo->GetPropVal(wxT("pacs-store-sid"), wxEmptyString);
+	if( nodo->HasAttribute(wxT("pacs-store-sid")) ) {
+		propVal = nodo->GetAttribute(wxT("pacs-store-sid"), wxEmptyString);
 		if (!propVal.IsEmpty()) {
 			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_STORE_SID, std::string(propVal.ToUTF8()));
 		}	
@@ -352,7 +352,7 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 		}
 		//parseamos los campos dimse
 		if(hijo->GetName().CmpNoCase(wxT("query-retrieve-level")) == 0){
-			propVal = hijo->GetPropVal(wxT("value"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("value"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				modelo->TagsDICOMOverwrite.tags["0008|0052"] = std::string(propVal.Upper().ToUTF8());
 			}
@@ -383,14 +383,14 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 				}else if(hijosPaciente->GetName().CmpNoCase(wxT("id")) == 0) {
 					std::string codigo(propVal.ToUTF8());
 					std::string valor(propVal.ToUTF8());
-					propVal = hijosPaciente->GetPropVal(wxT("code"), wxEmptyString);
+					propVal = hijosPaciente->GetAttribute(wxT("code"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						codigo =  propVal.ToUTF8();
 					}
 					else {
 						throw IntegrationException(_Std("\"code\" attribute expected at \"patient\" scope"), xpp, "CONF/template");
 					}
-					propVal = hijosPaciente->GetPropVal(wxT("value"), wxEmptyString);
+					propVal = hijosPaciente->GetAttribute(wxT("value"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						valor =  propVal.ToUTF8();
 						if (!modelo->GlobalVariables.Contains(GKDI_PATIENT_ID)) {
@@ -419,14 +419,14 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("id")) == 0) {
 					std::string codigo(propVal.ToUTF8());
 					std::string valor(propVal.ToUTF8());
-					propVal = hijosMedico->GetPropVal(wxT("code"), wxEmptyString);
+					propVal = hijosMedico->GetAttribute(wxT("code"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						codigo =  propVal.ToUTF8();
 					}
 					else {
 						throw IntegrationException(_Std("\"code\" attribute expected at \"physician\" scope"), xpp, "CONF/template");
 					}
-					propVal = hijosMedico->GetPropVal(wxT("value"), wxEmptyString);
+					propVal = hijosMedico->GetAttribute(wxT("value"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						valor =  propVal.ToUTF8();
 					}
@@ -437,7 +437,7 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_ID, valor);
 					}
 				} else if(hijosMedico->GetName() == wxT("institution")) {
-					propVal = hijosMedico->GetPropVal(wxT("iid"), wxEmptyString);
+					propVal = hijosMedico->GetAttribute(wxT("iid"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_INSTITUTION_ID, std::string(propVal.ToUTF8()));
 					}
@@ -453,7 +453,7 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 		}//fin medico
 
 		if(hijo->GetName().CmpNoCase(wxT("hce")) == 0) {
-			propVal = hijo->GetPropVal(wxT("aid"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("aid"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, std::string(propVal.ToUTF8()));
 			}
@@ -469,26 +469,26 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 			std::string valor;
 			std::string descripcion;
 
-			propVal = hijo->GetPropVal(wxT("code"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("code"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				codigo = propVal.Upper().ToUTF8();
 			}else {
 				throw IntegrationException(_Std("\"code\" attribute expected at \"metadata\" scope"), xpp, "CONF/template");
 			}
 
-			propVal = hijo->GetPropVal(wxT("key"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("key"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				clave = propVal.Lower().ToUTF8();
 			}else {
 				throw IntegrationException(_Std("\"key\" attribute expected at \"metadata\" scope"), xpp, "CONF/template");
 			}
 
-			propVal = hijo->GetPropVal(wxT("value"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("value"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				valor = propVal.ToUTF8();
 			}
 
-			propVal = hijo->GetPropVal(wxT("description"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("description"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				descripcion = propVal.ToUTF8();
 			}
