@@ -86,7 +86,7 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 			if (nodo->GetName().CmpNoCase(wxT("pacs")) == 0) { // Configuracion de PACS
 				GIL::IModeloPACSServer pacsServer;
 
-				propVal = nodo->GetPropVal(wxT("sid"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("sid"), wxEmptyString);
 				if( !propVal.empty() ) {
 					pacsServer.sid = propVal.ToUTF8();
 				}
@@ -94,7 +94,7 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					throw IntegrationException(_Std("Omitted Identificator"), xpp, "CONF/pacs");
 				}
 
-				propVal = nodo->GetPropVal(wxT("aet"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("aet"), wxEmptyString);
 				if( !propVal.empty() ) {
 					pacsServer.AET = propVal.ToUTF8();
 				}
@@ -102,7 +102,7 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					throw IntegrationException(_Std("Omitted AET"), xpp, "CONF/pacs");
 				}
 
-				propVal = nodo->GetPropVal(wxT("hostname"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("hostname"), wxEmptyString);
 				if( !propVal.empty() ) {
 					pacsServer.hostname = propVal.ToUTF8();
 				}
@@ -110,7 +110,7 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					throw IntegrationException(_Std("Hostname missing"), xpp, "CONF/pacs");
 				}
 
-				propVal = nodo->GetPropVal(wxT("puerto"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("puerto"), wxEmptyString);
 				if( !propVal.empty() ) {
 					pacsServer.puerto = propVal.ToUTF8();
 				}
@@ -118,7 +118,7 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					throw IntegrationException(_Std("Omitted port"), xpp, "CONF/pacs");
 				}
 				
-				propVal = nodo->GetPropVal(wxT("tls"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("tls"), wxEmptyString);
 				if( propVal.CmpNoCase(wxT("yes")) == 0 || propVal.CmpNoCase(wxT("true")) == 0 || propVal.CmpNoCase(wxT("si")) == 0 || propVal.CmpNoCase(wxT("1")) == 0 ) {
 					pacsServer.tls = true;
 				}
@@ -126,17 +126,17 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.tls = false;
 				}
 
-				propVal = nodo->GetPropVal(wxT("usuario-pacs"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("usuario-pacs"), wxEmptyString);
 				if( !propVal.empty()) {
 					pacsServer.user = propVal.ToUTF8();
 				}
 
-				propVal = nodo->GetPropVal(wxT("password-pacs"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("password-pacs"), wxEmptyString);
 				if( !propVal.empty()) {
 					pacsServer.password = propVal.ToUTF8();
 				}
 
-				propVal = nodo->GetPropVal(wxT("verify-credentials"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("verify-credentials"), wxEmptyString);
 				if( propVal.CmpNoCase(wxT("yes")) == 0 || propVal.CmpNoCase(wxT("true")) == 0 || propVal.CmpNoCase(wxT("si")) == 0 || propVal.CmpNoCase(wxT("1")) == 0 ) {
 					pacsServer.verify = true;
 				}
@@ -144,7 +144,7 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.verify = false;
 				}
 
-				propVal = nodo->GetPropVal(wxT("metodo"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("metodo"), wxEmptyString);
 				if( propVal.CmpNoCase(wxT("get")) == 0 ) {
 					pacsServer.metodo = GIL::IModeloPACSServer::IMPS_GET;
 				}
@@ -152,7 +152,7 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.metodo = GIL::IModeloPACSServer::IMPS_MOVE;
 				}
 				
-				propVal = nodo->GetPropVal(wxT("pdu"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("pdu"), wxEmptyString);
 				if( propVal.empty()) {
 					pacsServer.pdu = "16384";
 				}
@@ -160,7 +160,7 @@ void GIL::ParserXMLSpanish::ParseIntegrationXML(GIL::IntegrationModelList& model
 					pacsServer.pdu = propVal.ToUTF8();
 				}
 
-				propVal = nodo->GetPropVal(wxT("nivel-recuperacion"), wxEmptyString);
+				propVal = nodo->GetAttribute(wxT("nivel-recuperacion"), wxEmptyString);
 				if( propVal.empty()) {
 					pacsServer.retrieveLevel = "SERIES";
 				}
@@ -267,14 +267,14 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 	}
 	//
 
-	propVal = nodo->GetPropVal(wxT("pid"), wxEmptyString);
+	propVal = nodo->GetAttribute(wxT("pid"), wxEmptyString);
 	if( !propVal.empty() ) {
 		modelo->idPlantilla = propVal.ToUTF8();
 	} else {
 		modelo->idPlantilla = "";
 	}
 
-	propVal = nodo->GetPropVal(wxT("accion"), wxEmptyString).Lower();
+	propVal = nodo->GetAttribute(wxT("accion"), wxEmptyString).Lower();
 	if ( !propVal.empty() ) {
 
 		if (propVal.CmpNoCase(wxT("obtener")) == 0){
@@ -294,18 +294,18 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 		throw IntegrationException(_Std("\"accion\" attribute expected at \"plantilla\" scope"), xpp, "CONF/template");
 	}
 
-	propVal = nodo->GetPropVal(wxT("id_peticion"), wxEmptyString);
+	propVal = nodo->GetAttribute(wxT("id_peticion"), wxEmptyString);
 	if( !propVal.empty() ) {
 		modelo->GlobalVariables.InsertVariable(GKDI_HCE_PETITION_ID, std::string(propVal.ToUTF8()), "Id de peticion");
 	}
 
-	propVal = nodo->GetPropVal(wxT("ambito"), wxEmptyString);
+	propVal = nodo->GetAttribute(wxT("ambito"), wxEmptyString);
 	if( !propVal.empty() ) {
 		modelo->GlobalVariables.InsertVariable(GKDI_JIMENA_AMBITO_PETICION, std::string(propVal.ToUTF8()), "Ambito de la peticion");		
 	}
 
-	if( nodo->HasProp(wxT("pacs_retrieve_sid")) ) {
-		propVal = nodo->GetPropVal(wxT("pacs_retrieve_sid"), wxEmptyString);
+	if( nodo->HasAttribute(wxT("pacs_retrieve_sid")) ) {
+		propVal = nodo->GetAttribute(wxT("pacs_retrieve_sid"), wxEmptyString);
 		if (!propVal.IsEmpty()) {
 			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_RETRIEVE_SID, std::string(propVal.ToUTF8()), "String Id del pacs de obtencion");
 		}
@@ -314,8 +314,8 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 		}					
 	}
 
-	if( nodo->HasProp(wxT("pacs_store_sid")) ) {
-		propVal = nodo->GetPropVal(wxT("pacs_store_sid"), wxEmptyString);
+	if( nodo->HasAttribute(wxT("pacs_store_sid")) ) {
+		propVal = nodo->GetAttribute(wxT("pacs_store_sid"), wxEmptyString);
 		if (!propVal.IsEmpty()) {
 			modelo->GlobalVariables.InsertVariable(GKDI_GLOBAL_PACS_STORE_SID, std::string(propVal.ToUTF8()), "String Id del pacs de almacenamiento");
 		}
@@ -330,7 +330,7 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 		if(hijo->GetName().CmpNoCase(wxT("dimse")) == 0){
 			//parseamos los campos dimse
 			std::string uid;
-			propVal = hijo->GetPropVal(wxT("uid"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("uid"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				uid =  propVal.ToUTF8();
 			}
@@ -341,7 +341,7 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 				}
 			}
 
-			propVal = hijo->GetPropVal(wxT("ambito"), wxEmptyString).Lower();
+			propVal = hijo->GetAttribute(wxT("ambito"), wxEmptyString).Lower();
 			if ( !propVal.empty() ) {
 				if (propVal.CmpNoCase(wxT("study")) == 0){
 					modelo->TagsDICOMOverwrite.tags["0008|0052"] = "STUDY";
@@ -394,14 +394,14 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 				}else if(hijosPaciente->GetName().CmpNoCase(wxT("id")) == 0) {
 					std::string codigo(propVal.ToUTF8());
 					std::string valor(propVal.ToUTF8());
-					propVal = hijosPaciente->GetPropVal(wxT("codigo"), wxEmptyString);
+					propVal = hijosPaciente->GetAttribute(wxT("codigo"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						codigo =  propVal.ToUTF8();
 					}
 					else {
 						throw IntegrationException(_Std("\"codigo\" attribute expected at \"paciente\" scope"), xpp, "CONF/template");
 					}
-					propVal = hijosPaciente->GetPropVal(wxT("valor"), wxEmptyString);
+					propVal = hijosPaciente->GetAttribute(wxT("valor"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						valor =  propVal.ToUTF8();
 						if (!modelo->GlobalVariables.Contains(GKDI_PATIENT_ID) || codigo=="PI") {
@@ -430,14 +430,14 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("id")) == 0) {
 					std::string codigo(propVal.ToUTF8());
 					std::string valor(propVal.ToUTF8());
-					propVal = hijosMedico->GetPropVal(wxT("codigo"), wxEmptyString);
+					propVal = hijosMedico->GetAttribute(wxT("codigo"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						codigo =  propVal.ToUTF8();
 					}
 					else {
 						throw IntegrationException(_Std("\"codigo\" attribute expected at \"medico\" scope"), xpp, "CONF/template");
 					}
-					propVal = hijosMedico->GetPropVal(wxT("valor"), wxEmptyString);					
+					propVal = hijosMedico->GetAttribute(wxT("valor"), wxEmptyString);					
 					if ( !propVal.empty() ) {
 						valor =  propVal.ToUTF8();
 					}
@@ -448,7 +448,7 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_ID,  valor, "Referring Physician Id");
 					}
 				} else if(hijosMedico->GetName().CmpNoCase(wxT("centro")) == 0) {
-					propVal = hijosMedico->GetPropVal(wxT("cid"), wxEmptyString);
+					propVal = hijosMedico->GetAttribute(wxT("cid"), wxEmptyString);
 					if ( !propVal.empty() ) {
 						modelo->GlobalVariables.InsertVariable(GKDI_REFERRING_PHISICIAN_INSTITUTION_ID, std::string(propVal.ToUTF8()));
 					}
@@ -464,7 +464,7 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 		}//fin medico
 
 		if(hijo->GetName().CmpNoCase(wxT("hce")) == 0) {
-			propVal = hijo->GetPropVal(wxT("aid"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("aid"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, std::string(propVal.ToUTF8()));
 			}
@@ -479,27 +479,27 @@ GIL::IModeloIntegracion* GIL::ParserXMLSpanish::ParsePlantilla(wxXmlNode* nodo,
 			std::string valor;
 			std::string descripcion;
 
-			propVal = hijo->GetPropVal(wxT("codigo"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("codigo"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				codigo = propVal.Upper().ToUTF8();
 			}else {
 				throw IntegrationException(_Std("\"codigo\" attribute expected at \"metadato\" scope"), xpp, "CONF/template");
 			}
 
-			propVal = hijo->GetPropVal(wxT("clave"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("clave"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				clave = propVal.Lower().ToUTF8();
 			}else {
 				throw IntegrationException(_Std("\"clave\" attribute expected at \"metadato\" scope"), xpp, "CONF/template");
 			}
 
-			propVal = hijo->GetPropVal(wxT("valor"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("valor"), wxEmptyString);
 
 			if ( !propVal.empty() ) {
 				valor = propVal.ToUTF8();
 			}
 
-			propVal = hijo->GetPropVal(wxT("descripcion"), wxEmptyString);
+			propVal = hijo->GetAttribute(wxT("descripcion"), wxEmptyString);
 			if ( !propVal.empty() ) {
 				descripcion = propVal.ToUTF8();
 			}
