@@ -590,7 +590,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 		//TODO: Mantener esta lectura del dataset.
 		GIL::DICOM::PACSController::Instance()->LiberarInstanciaDeDICOMManager(m);
 
-		if (modality == "ECG" || modality == "HD")
+		if (modality == "ECG" || modality == "EC" || modality == "HD")
 		{
 			DirectionCosines->Identity();
 			RecomponerPipeline();
