@@ -22,6 +22,85 @@
 #include <main/controllers/commandcontroller.h>
 #include <main/controllers/historycontroller.h>
 #include <commands/comandoexportacion.h>
+#include <wx/ginkgostyle/ginkgostyle.h>
+/**dcmtk dictionary...*/
+#include <dcmtk/config/osconfig.h>
+#include <dcmtk/dcmdata/dcdict.h>
+#include <dcmtk/dcmdata/dcdicent.h>
+
+#include <wx/msgdlg.h>
+
+/**/
+namespace GNC
+{
+	namespace GUI 
+	{
+		class AnonymizeAddTagDialog: public AnonymizeAddTagDialogBase
+		{
+		public:
+			AnonymizeAddTagDialog(wxWindow* pParent): AnonymizeAddTagDialogBase(pParent)
+			{
+				DcmDataDictionary& globalDataDict = dcmDataDict.wrlock();
+				
+				wxArrayString listOfStrings;
+				for (DcmHashDictIterator it = globalDataDict.normalBegin(); it != globalDataDict.normalEnd(); ++it) 
+				{
+					DcmDictEntry entry(*(*it));
+					listOfStrings.push_back(wxString::FromUTF8(entry.getTagName()));
+				}
+				dcmDataDict.unlock();
+
+				listOfStrings.Sort();
+				m_pTag->Append(listOfStrings);
+
+				m_pBody->Layout();
+				Layout();
+			}
+
+			virtual void OnTagSelection(wxCommandEvent& /*evt*/)
+			{
+				if (m_pTag->GetSelection() != 0) {
+					wxString tagName = m_pTag->GetStringSelection();
+					const DcmDataDictionary& globalDataDict = dcmDataDict.rdlock();
+					const DcmDictEntry* entry = globalDataDict.findEntry(tagName.ToUTF8());
+					dcmDataDict.unlock();
+					if (entry != NULL) {
+						m_pTextGroup->SetValue(wxString::Format(wxT("%04x"),entry->getGroup()));
+						m_pTextElement->SetValue(wxString::Format(wxT("%04x"),entry->getElement()));
+					}
+				}
+			}
+
+			std::string getKey()
+			{
+				wxString key;
+				long group,element;
+				if (m_pTextGroup->GetValue().ToLong(&group, 16) && m_pTextElement->GetValue().ToLong(&element, 16) && group >= 0 && group < 0xffff && element >= 0 && element < 0xffff) {
+					key = wxString::Format(wxT("%04x|%04x"), group, element);
+				}
+				return std::string(key.ToUTF8());
+			}
+
+			std::string getValue()
+			{
+				return std::string(m_pTextValue->GetValue().ToUTF8());
+			}
+
+			virtual void OnOkClick(wxCommandEvent &evt)
+			{
+				long group,element;
+				if (m_pTextGroup->GetValue().ToLong(&group, 16) && m_pTextElement->GetValue().ToLong(&element, 16) && group >= 0 && group < 0xffff && element >= 0 && element < 0xffff) {
+					evt.Skip(true);
+				} else {
+					wxMessageBox(_("Element field or group field have invalid values"),_("Info"),wxOK | wxICON_INFORMATION, this);
+					evt.Skip(false);
+				}
+			}
+		};
+	}
+}
+
+/**********************************************************/
 
 GNC::GUI::AnonymizePanel::AnonymizePanel(wxWindow* pParent): GNC::GUI::AnonymizePanelBase(pParent)
 {
@@ -65,7 +144,7 @@ void GNC::GUI::AnonymizePanel::InitSeries(long pkSeries)
 	for (GNC::GCS::IConfigurationController::TListGroups::iterator it = groups.begin(); it != groups.end(); ++it)
 	{
 		if ((*it).find("tag") != (*it).end() && (*it).find("value") != (*it).end()) {
-			Anonymize((*it)["tag"], true, (*it)["value"]);
+			Anonymize((*it)["tag"], true, (*it)["value"], false);
 		}
 	}
 
@@ -73,7 +152,7 @@ void GNC::GUI::AnonymizePanel::InitSeries(long pkSeries)
 	m_pTagsList->Connect(wxEVT_PG_DOUBLE_CLICK,wxPropertyGridEventHandler(AnonymizePanel::OnPropertyDobleClick),NULL,this);
 }
 
-void GNC::GUI::AnonymizePanel::SetTags(GIL::DICOM::DicomDataset & base,wxPGPropArg idPadre,GIL::DICOM::IDICOMManager*	pDICOMManager) 
+void GNC::GUI::AnonymizePanel::SetTags(GIL::DICOM::DicomDataset & base,wxPGProperty* idPadre,GIL::DICOM::IDICOMManager*	pDICOMManager) 
 {
 	for(GIL::DICOM::ListaTags::iterator it = base.tags.begin(); it!= base.tags.end(); ++it){
 		wxString helpString = wxString::FromUTF8(pDICOMManager->GetDescription((*it).first).c_str());
@@ -112,12 +191,12 @@ void GNC::GUI::AnonymizePanel::SetTags(GIL::DICOM::DicomDataset & base,wxPGPropA
 		if(m_pTagsList->GetProperty(prop->GetName()) != NULL) {
 			////////////////////////////////////std::cout<<"hasdfasdf";
 		}
-		wxPGId pIdSequencia = m_pTagsList->AppendIn(idPadre,prop);
+		wxPGProperty* pIdSequencia = m_pTagsList->AppendIn(idPadre,prop);
 
 		//recursion
 		int i=0;
 		for(GIL::DICOM::DicomDataset::DatasetList::iterator it2 = (*it).items.begin(); it2!= (*it).items.end(); ++it2, ++i) {
-			wxPGPropArg pIdItem = m_pTagsList->AppendIn(pIdSequencia,new wxStringProperty(wxString::Format(wxT("Item %d"),i),wxPG_LABEL,wxEmptyString));
+			wxPGProperty* pIdItem = m_pTagsList->AppendIn(pIdSequencia,new wxStringProperty(wxString::Format(wxT("Item %d"),i),wxPG_LABEL,wxEmptyString));
 			SetTags((*it2),pIdItem,pDICOMManager);
 		}
 	}
@@ -171,6 +250,14 @@ void GNC::GUI::AnonymizePanel::OnCheckComentarios( wxCommandEvent& /*event*/ )
 	}
 }
 
+void GNC::GUI::AnonymizePanel::OnAddNewTag( wxCommandEvent &)
+{
+	AnonymizeAddTagDialog dlg(this);
+	if (dlg.ShowModal() == wxID_OK) {
+		Anonymize(dlg.getKey(), true, dlg.getValue());
+	}
+}
+
 void GNC::GUI::AnonymizePanel::Anonymize(const std::string& clave, bool anonimizar)
 {
 	wxString value = wxEmptyString;
@@ -185,35 +272,63 @@ void GNC::GUI::AnonymizePanel::Anonymize(const std::string& clave, bool anonimiz
 	Anonymize(clave, anonimizar, std::string(value.ToUTF8()));
 }
 
-void GNC::GUI::AnonymizePanel::Anonymize(const std::string& clave, bool anonimizar, const std::string& value)
+void GNC::GUI::AnonymizePanel::Anonymize(const std::string& clave, bool anonimizar, const std::string& value, bool anonymizeIfNotExists )
 {
 	if (MapOfCheck.find(clave) != MapOfCheck.end()) {
 		MapOfCheck[clave]->SetValue(anonimizar);
 	}
 	wxString valueWx = wxString::FromUTF8(value.c_str());
-	for(wxPGProperty* it=m_pTagsList->GetFirst();it!=NULL;it=m_pTagsList->GetNextSiblingProperty(it)){
-		if(it->GetHelpString() == wxString::FromUTF8(clave.c_str())){
-			it->SetValueFromString(valueWx);
+	for (wxPropertyGridIterator it = m_pTagsList->GetIterator(); ! it.AtEnd(); ++it) {
+		wxPGProperty* prop = it.GetProperty();
+		if(prop->GetHelpString() == wxString::FromUTF8(clave.c_str())){
+			prop->SetValueFromString(valueWx);
 			if(anonimizar){
-				m_pTagsList->SetPropertyCell(it->GetId(),0,it->GetLabel(),wxNullBitmap,*wxWHITE,*wxRED);
-				m_pTagsList->SetPropertyCell(it->GetId(),1,it->GetValue(),wxNullBitmap,*wxWHITE,*wxRED);
+				m_pTagsList->SetPropertyCell(prop,0,prop->GetLabel(),wxNullBitmap,*wxWHITE,*wxRED);
+				m_pTagsList->SetPropertyCell(prop,1,prop->GetValue(),wxNullBitmap,*wxWHITE,*wxRED);
 			}else{
-				m_pTagsList->SetPropertyCell(it->GetId(),0,it->GetLabel());
-				m_pTagsList->SetPropertyCell(it->GetId(),1,it->GetValue());
+				m_pTagsList->SetPropertyCell(prop,0,prop->GetLabel(), wxNullBitmap, *wxBLACK, *wxWHITE);
+				m_pTagsList->SetPropertyCell(prop,1,prop->GetValue(), wxNullBitmap, *wxBLACK, *wxWHITE);
 			}
-			it->ChangeFlag(wxPG_PROP_MODIFIED,anonimizar);
-			m_pTagsList->RefreshProperty(it);
+			prop->ChangeFlag(wxPG_PROP_MODIFIED,anonimizar);
+			m_pTagsList->RefreshProperty(prop);
+			m_pTagsList->SelectProperty(prop, true);
 			return;
 		}
 	}
+	if (anonymizeIfNotExists) {
+		//key not found... add it to property grid
+		wxStringProperty* prop = NULL;
+		GIL::DICOM::IDICOMManager*	pDICOMManager = GNC::GCS::IEntorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
+		wxString helpString = wxString::FromUTF8(pDICOMManager->GetDescription(clave).c_str());
+		if(helpString.size()>0) {
+			helpString = wxT("(") + wxString::FromUTF8(clave.c_str()) + wxT(") ") + helpString;
+			prop = new wxStringProperty(helpString,
+				wxPG_LABEL,wxEmptyString);
+		}else{
+			prop = new wxStringProperty(wxString::FromUTF8(clave.c_str()),
+				wxPG_LABEL,wxEmptyString);
+		}
+		prop->SetHelpString(wxString::FromUTF8(clave.c_str()));
+		GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+
+		prop->SetValue(wxString::FromUTF8(value.c_str()));
+		prop->ChangeFlag(wxPG_PROP_MODIFIED,anonimizar);
+		if(anonimizar){
+			m_pTagsList->SetPropertyCell(prop,0,prop->GetLabel(),wxNullBitmap,*wxWHITE,*wxRED);
+			m_pTagsList->SetPropertyCell(prop,1,prop->GetValue(),wxNullBitmap,*wxWHITE,*wxRED);
+		}
+		m_pTagsList->AppendIn(m_pTagsList->GetRoot(), prop);
+		m_pTagsList->SelectProperty(prop, true);
+	}
 }
 
 
 void GNC::GUI::AnonymizePanel::RemoveFromTable(const std::string& clave)
 {
-	for(wxPGProperty* it=m_pTagsList->GetFirst();it!=NULL;it=m_pTagsList->GetNextSiblingProperty(it)){
-		if(it->GetHelpString() == wxString::FromUTF8(clave.c_str())){
-			m_pTagsList->DeleteProperty(it->GetId());
+	for (wxPropertyGridIterator it = m_pTagsList->GetIterator(); ! it.AtEnd(); ++it) {
+		wxPGProperty* prop = it.GetProperty();
+		if(prop->GetHelpString() == wxString::FromUTF8(clave.c_str())){
+			m_pTagsList->DeleteProperty(prop);
 			break;
 		}
 	}
@@ -223,10 +338,11 @@ void GNC::GUI::AnonymizePanel::GetTagsAnonymized(GIL::DICOM::DicomDataset & base
 {
 	base.tags.clear();
 	GNC::GCS::IConfigurationController::TListGroups configGroups;
-	for(wxPGProperty* it=m_pTagsList->GetFirst();it!=NULL;it=m_pTagsList->GetNextSiblingProperty(it)){
-		if(it->IsFlagSet(wxPG_PROP_MODIFIED)){
-			std::string clave(it->GetHelpString().ToUTF8());
-			std::string valor(it->GetValueAsString().ToUTF8());
+	for (wxPropertyGridIterator it = m_pTagsList->GetIterator(); ! it.AtEnd(); ++it) {
+		wxPGProperty* prop = it.GetProperty();
+		if(prop->GetFlags() & wxPG_PROP_MODIFIED){
+			std::string clave(prop->GetHelpString().ToUTF8());
+			std::string valor(prop->GetValueAsString().ToUTF8());
 			base.tags[clave] = valor;
 
 			GNC::GCS::IConfigurationController::TMapValues group;
@@ -236,7 +352,6 @@ void GNC::GUI::AnonymizePanel::GetTagsAnonymized(GIL::DICOM::DicomDataset & base
 		}
 	}
 	GNC::GCS::IConfigurationController::Instance()->writeGroupUser("/Core/AnonymizationSelection", configGroups);
-	
 }
 
 bool GNC::GUI::AnonymizePanel::AnonymizePrivateTags()
@@ -247,14 +362,15 @@ bool GNC::GUI::AnonymizePanel::AnonymizePrivateTags()
 void GNC::GUI::AnonymizePanel::OnPropertyChanged(wxPropertyGridEvent& event)
 {
 	wxPGProperty* selected= event.GetProperty();
-	m_pTagsList->SetPropertyCell(selected->GetId(),0,selected->GetLabel(),wxNullBitmap,*wxWHITE,*wxRED);
-	m_pTagsList->SetPropertyCell(selected->GetId(),1,selected->GetValue(),wxNullBitmap,*wxWHITE,*wxRED);
+	m_pTagsList->SetPropertyCell(selected,0,selected->GetLabel(),wxNullBitmap,*wxWHITE,*wxRED);
+	m_pTagsList->SetPropertyCell(selected,1,selected->GetValue(),wxNullBitmap,*wxWHITE,*wxRED);
 }
 
 void GNC::GUI::AnonymizePanel::OnPropertyDobleClick(wxPropertyGridEvent& event)
 {
 	std::string clave(event.GetProperty()->GetHelpString().ToUTF8());
-	Anonymize(clave,!event.GetProperty()->IsFlagSet(wxPG_PROP_MODIFIED));
+	bool isModified = (event.GetProperty()->GetFlags() & wxPG_PROP_MODIFIED);
+	Anonymize(clave,!isModified);
 }
 
 
