@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionpermisos.h $
+ *  $Id: defaultmodalitysettingsconfigurationpanel.h $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
@@ -39,17 +39,16 @@ namespace GNC {
 
 				bool Guardar();
 				//endregion
-
 				
 				virtual void OnPropiedadCambiada();
-			protected:
-				virtual void OnNavigationChanged(wxTreeEvent &);
-				void LoadCurrent();
 
+			protected:
+				virtual void OnTreeSelChanged(wxTreeEvent &);
+				void LoadCurrent();
 
 				void OnSize(wxSizeEvent &);
 
-				typedef std::map<wxTreeItemIdValue ,ModalityPanel*> TModalityMap;
+				typedef std::map<wxTreeItemId, ModalityPanel*> TModalityMap;
 				TModalityMap modalityBrowser;
 				ModalityPanel* m_currentModality;
 
