@@ -33,6 +33,7 @@
 #include "panelconfiguraciongeneral.h"
 #include "panelconfigurationanonymization.h"
 #include "hangingprotocolconfigurationpanel.h"
+#include "smartretrieveconfigurationpanel.h"
 #include "localdatabaseconfigurationpanel.h"
 #include "defaultmodalitysettingsconfigurationpanel.h"
 
@@ -53,7 +54,7 @@ namespace GNC {
 
 		DialogoConfiguracion::DialogoConfiguracion(wxWindow* pParent):DialogoConfiguracionBase(pParent)
 		{
-			wxTreeItemId raiz = m_pTreeNavegacion->AddRoot(wxT("raiz"));
+			wxTreeItemId raiz = m_pTreeNavegacion->AddRoot(wxT("root"));
 			wxTreeItemId ginkgo = m_pTreeNavegacion->AppendItem(raiz,wxString::FromUTF8(GNC::Entorno::Instance()->GetApplicationName().c_str()));
 
 			SetTitle(wxString::FromUTF8(GNC::Entorno::Instance()->GetApplicationName().c_str()) + wxT(" ") + _("settings"));
@@ -67,60 +68,65 @@ namespace GNC {
 
 			primerId = id;
 
-			pPaso = new PanelConfiguracionEstacion(m_pPanelConfig,this);
+			pPaso = new PanelConfiguracionEstacion(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 
-			pPaso = new LocalDatabaseConfigurationPanel(m_pPanelConfig,this);
+			pPaso = new LocalDatabaseConfigurationPanel(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 
-			pPaso = new PanelConfiguracionHCE(m_pPanelConfig,this);
+			pPaso = new PanelConfiguracionHCE(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 
-			pPaso = new PanelConfiguracionPACS(m_pPanelConfig,this);
+			pPaso = new PanelConfiguracionPACS(m_pPanelConfig, this);
+			pPaso->GetPanel()->Hide();
+			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
+			m_MapaPasos[id.m_pItem] = pPaso;
+
+			pPaso = new SmartRetrieveConfigurationPanel(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 /*
-			pPaso = new PanelConfiguracionExtensiones(m_pPanelConfig,this);
+			pPaso = new PanelConfiguracionExtensiones(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 */
-			pPaso = new PanelConfiguracionPermisos(m_pPanelConfig,this);
+			pPaso = new PanelConfiguracionPermisos(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 
-			pPaso = new DefaultModalitySettingsConfigurationPanel(m_pPanelConfig,this);
+			pPaso = new DefaultModalitySettingsConfigurationPanel(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 
-			pPaso = new HangingProtocolConfigurationPanel(m_pPanelConfig,this);
+			pPaso = new HangingProtocolConfigurationPanel(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 
 			if (GNC::GCS::IControladorPermisos::Instance()->Get("core.seguridad","setup_security"))
 			{
-				pPaso = new PanelConfiguracionSeguridad(m_pPanelConfig,this);
+				pPaso = new PanelConfiguracionSeguridad(m_pPanelConfig, this);
 				pPaso->GetPanel()->Hide();
 				id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 				m_MapaPasos[id.m_pItem] = pPaso;
 			}
 
-			pPaso = new PanelConfiguracionUbicaciones(m_pPanelConfig,this);
+			pPaso = new PanelConfiguracionUbicaciones(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 
-/*			pPaso = new PanelConfigurationAnonymization(m_pPanelConfig,this);
+/*			pPaso = new PanelConfigurationAnonymization(m_pPanelConfig, this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
@@ -195,7 +201,7 @@ namespace GNC {
 
 		void DialogoConfiguracion::OnCancelarClick(wxCommandEvent &)
 		{
-			Close();
+			EndModal(wxID_CANCEL);
 		}
 
 		void DialogoConfiguracion::OnAceptarClick(wxCommandEvent &)
@@ -218,10 +224,10 @@ namespace GNC {
 						pC->PropagarConfiguracionCambiada();
 					}
 					m_pBAplicar->Disable();
-					Close();
+					EndModal(wxID_OK);
 				}
 			} else {
-				Close();
+				EndModal(wxID_OK);
 			}
 		}
 
