@@ -30,8 +30,8 @@ namespace GNC {
 				DialogoConfiguracion(wxWindow* pParent);
 				~DialogoConfiguracion();
 
+				virtual void OnCambioNodoNavegacion(wxTreeEvent &event);
 
-			protected:
 				void CargarCurrent();
 
 				void OnPropiedadCambiada();
@@ -42,8 +42,6 @@ namespace GNC {
 
 				void OnAplicarClick(wxCommandEvent &event);
 
-				void OnCambioNodoNavegacion(wxTreeEvent &event);
-
 				void OnExportarClick(wxCommandEvent &event);
 
 				void OnImportarClick(wxCommandEvent &event);
