@@ -29,34 +29,31 @@
 #include <wx/pen.h>
 #include <wx/sizer.h>
 #include <wx/msgdlg.h>
-#include <wx/aui/auibar.h>
 #include <wx/menu.h>
+#include <wx/wxginkgotoolbar.h>
 #include "hangingprotocolconfigurationpanel.h"
 #include <resources/ginkgoresourcesmanager.h>
 
-#define COL_CRITERIA_DESCRIPTION	0
-#define COL_CRITERIA_VALUE			1
-#define COL_CRITERIA_ID				2
-
 #define COL_LABEL_ID				0
 #define COL_WINDOW_ID				1
 #define COL_LEVEL_ID				2
 
+#define COL_HP_NAME					0
+#define COL_HP_ACTIVE				1
+#define COL_HP_CLIENT_DATA			2
+
 namespace GNC {
 	namespace GUI {
 		//////////////////////////////////////////
-		class HangingButtonsBar:public wxAuiToolBar{
+		class HangingButtonsBar : public wxAuiToolBar{
 		public:
-			HangingButtonsBar(wxWindow* pParent, const wxColour& color, const wxFont& fuente, int style): wxAuiToolBar(pParent,wxID_ANY, wxDefaultPosition, wxDefaultSize, style)
+			HangingButtonsBar(wxWindow* pParent, const wxColour& color, const wxFont& fuente, int style): wxAuiToolBar (pParent,wxID_ANY, wxDefaultPosition, wxDefaultSize, style)
 			{
 				SetToolBitmapSize(wxSize(16,16));
 
-				wxAuiDefaultToolBarArt* pToolArt= new wxAuiDefaultToolBarArt();
-#if defined(USE_PATCHED_LIBS) && !defined(__WXOSX__)
-				pToolArt->SetBaseColor(color);
-
+				wxGinkgoToolBarArt* pToolArt= new wxGinkgoToolBarArt();
+				pToolArt->SetCustomBaseColor(color);
 				pToolArt->SetFont(fuente);
-#endif
 				SetArtProvider(pToolArt);
 
 				Realize();
@@ -162,6 +159,11 @@ namespace GNC {
 		////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 		class EditCriteriaPanel: public EditCriteriaPanelBase
 		{
+			enum {
+				COL_DEESCRIPTION = 0,
+				COL_VALUE,
+				COL_UID
+			};
 		public:
 			EditCriteriaPanel(wxWindow* pParent, bool buttonsRight = true): EditCriteriaPanelBase(pParent)
 			{
@@ -169,22 +171,25 @@ namespace GNC {
 					m_pGeneralSizer->SetOrientation(wxVERTICAL);
 					m_pButtonSizer->SetOrientation(wxHORIZONTAL);
 					m_pButtonSizer->Insert(0, 0, 0, 1, wxEXPAND, 5 );
-					m_pTreeListCriteria->SetColumnWidth(0,100);
-					m_pTreeListCriteria->SetColumnWidth(1,200);
 				}
-				m_pTreeListCriteria->AddRoot(wxT("Root"));
-				m_pTreeListCriteria->Connect(wxEVT_COMMAND_TREE_SEL_CHANGED, wxTreeEventHandler( EditCriteriaPanel::OnCriteriaChangeSelection ), NULL, this );
+
+				m_pModel = new wxDataViewListStore();
+				m_pListCriteria->AssociateModel(m_pModel.get());
+
+				m_pListCriteria->AppendColumn( new wxDataViewColumn( _("Dicom tag"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), COL_HP_NAME, 200, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+				m_pListCriteria->AppendColumn( new wxDataViewColumn( _("Value"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_EDITABLE ), COL_HP_ACTIVE, 230, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+
+				m_pListCriteria->Connect(wxEVT_DATAVIEW_SELECTION_CHANGED, wxDataViewEventHandler( EditCriteriaPanel::OnCriteriaChangeSelection ), NULL, this );
 				Layout();
 			}
 			~EditCriteriaPanel()
 			{
-				m_pTreeListCriteria->Disconnect(wxEVT_COMMAND_TREE_SEL_CHANGED, wxTreeEventHandler( EditCriteriaPanel::OnCriteriaChangeSelection ), NULL, this );
+				m_pListCriteria->Disconnect(wxEVT_DATAVIEW_SELECTION_CHANGED, wxDataViewEventHandler( EditCriteriaPanel::OnCriteriaChangeSelection ), NULL, this );
 			}			
 
 			virtual void loadMatcher(const GNC::GCS::Ptr<GNC::GCS::Matcher>& matcher)
 			{
-				m_pTreeListCriteria->DeleteRoot();
-				m_pTreeListCriteria->AddRoot(wxT("Root"));
+				m_pListCriteria->DeleteAllItems();
 				if (matcher.IsValid()) {
 					for (std::map<std::string, std::string>::const_iterator it = matcher->getMatchingCriteria().begin(); it != matcher->getMatchingCriteria().end(); ++it)
 					{
@@ -197,12 +202,11 @@ namespace GNC {
 			{
 				if (matcher.IsValid()) {
 					matcher->getMatchingCriteria().clear();
-					wxTreeItemIdValue cookie;
-					wxTreeItemId itemActual = m_pTreeListCriteria->GetFirstChild(m_pTreeListCriteria->GetRootItem(), cookie);
-					while (itemActual.IsOk())
-					{
-						matcher->getMatchingCriteria()[std::string(m_pTreeListCriteria->GetItemText(itemActual, COL_CRITERIA_ID).ToUTF8())] = m_pTreeListCriteria->GetItemText(itemActual, COL_CRITERIA_VALUE).ToUTF8();	
-						itemActual = m_pTreeListCriteria->GetNextChild(m_pTreeListCriteria->GetRootItem(), cookie);
+					wxVariant tag,value;
+					for (int i = 0; i < m_pModel->GetCount(); ++i) {
+						m_pModel->GetValueByRow(tag, i, COL_UID);
+						m_pModel->GetValueByRow(value, i, COL_VALUE);
+						matcher->getMatchingCriteria()[std::string(tag.GetString().ToUTF8())] = value.GetString().ToUTF8();
 					}
 				}
 			}
@@ -211,9 +215,11 @@ namespace GNC {
 			{
 				GIL::DICOM::IDICOMManager*	pDICOMManager = GNC::GCS::IEntorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
 				std::string description = pDICOMManager->GetDescription(tagKey);
-				wxTreeItemId idItem = m_pTreeListCriteria->AppendItem(m_pTreeListCriteria->GetRootItem(),wxString::FromUTF8(description.c_str()));
-				m_pTreeListCriteria->SetItemText(idItem, COL_CRITERIA_VALUE, wxString::FromUTF8(value.c_str()));
-				m_pTreeListCriteria->SetItemText(idItem, COL_CRITERIA_ID, wxString::FromUTF8(tagKey.c_str()));
+				wxVector<wxVariant> data;
+				data.push_back(wxString::FromUTF8(description.c_str()));
+				data.push_back(wxString::FromUTF8(value.c_str()));
+				data.push_back(wxString::FromUTF8(tagKey.c_str()));
+				m_pModel->AppendItem(data);
 				GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 			}
 
@@ -223,38 +229,37 @@ namespace GNC {
 				AddTagDialog dlg(this);
 				if (dlg.ShowModal() == wxID_OK) {
 					std::pair<std::string, std::string> value = dlg.getTag();
-					wxTreeItemIdValue cookie;
-					wxTreeItemId itemActual = m_pTreeListCriteria->GetFirstChild(m_pTreeListCriteria->GetRootItem(), cookie);
-					bool exists = false;
-					while (itemActual.IsOk())
-					{
-						if (std::string(m_pTreeListCriteria->GetItemText(itemActual, COL_CRITERIA_ID).ToUTF8()) == value.first)
+					wxVariant val;
+					for (int i = 0; i < m_pModel->GetItemCount(); ++i) {
+						m_pModel->GetValueByRow(val, i, COL_UID);
+						if (val.GetString() == wxString::FromUTF8(value.first.c_str()))
 						{
-							m_pTreeListCriteria->SetItemText(itemActual, COL_CRITERIA_VALUE, wxString::FromUTF8(value.second.c_str()));
-							exists = true;
-							break;
+							m_pModel->SetValueByRow(wxString::FromUTF8(value.second.c_str()), i, COL_VALUE);
+							return;
 						}
-						itemActual = m_pTreeListCriteria->GetNextChild(m_pTreeListCriteria->GetRootItem(), cookie);
-					}
-					if (!exists) {
-						addTag(value.first, value.second);
 					}
+					
+					addTag(value.first, value.second);
 				}
 			}
 
 			virtual void OnDeleteClick(wxCommandEvent& )
 			{
-				wxTreeItemId item = m_pTreeListCriteria->GetSelection();
+				
+				wxDataViewItem item = m_pListCriteria->GetSelection();
 				if(item.IsOk()){
-					m_pTreeListCriteria->Delete(item);
+					m_pListCriteria->DeleteItem(m_pListCriteria->GetSelectedRow());
 				}
+				
 			}
 
-			virtual void OnCriteriaChangeSelection(wxTreeEvent& event)
+			virtual void OnCriteriaChangeSelection(wxDataViewEvent& event)
 			{
 				m_pBDelete->Enable(event.GetItem().IsOk());
 			}
 
+			
+			wxObjectDataPtr<wxDataViewListStore> m_pModel;
 		};
 
 		////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -265,7 +270,7 @@ namespace GNC {
 				class PreviewLayoutPanel: public wxPanel, public GNC::GCS::IHangingSeriesViewer
 				{
 				public:
-					PreviewLayoutPanel(StudyWindow* pSelectionManager, wxWindow* pParent, const GNC::GCS::Ptr<GNC::GCS::Matcher>& seriesMatcher = NULL): wxPanel(pParent, wxID_ANY, wxDefaultPosition, wxSize(100,100)),
+					PreviewLayoutPanel(StudyWindow* pSelectionManager, wxWindow* pParent, const GNC::GCS::Ptr<GNC::GCS::Matcher>& seriesMatcher = NULL): wxPanel(pParent, wxID_ANY, wxDefaultPosition, wxSize(-1,-1)),
 						isSelected(false),
 						pStudyWindow(pSelectionManager)
 					{
@@ -510,7 +515,7 @@ namespace GNC {
 						wxSizer* pSizerActive = (wxSizer*)selectedPreview->GetContainingSizer();
 						wxSizerItem* pItem = pSizerActive->GetItem(selectedPreview);
 
-						pItem->SetSizer(pNewSizer);
+						pItem->AssignSizer(pNewSizer);
 						pNewSizer->Add(selectedPreview, 1, wxEXPAND|wxALL);
 						std::map<std::string, std::string> prop;
 						pNewSizer->Add(createSeriesSlot(prop, -1, NULL), 1, wxEXPAND|wxALL);
@@ -570,6 +575,7 @@ namespace GNC {
 						//rebuild layout...
 						layout->setColumns(m_pSpinCols->GetValue());
 						layout->setRows(m_pSpinRows->GetValue());
+						layout->getCellList().clear();
 						doLayout();
 					}
 
@@ -659,7 +665,7 @@ namespace GNC {
 				{
 					if ((*it).IsValid()) {
 						StudyWindow* sw = new StudyWindow(m_pNoteBookWindows, (*it));
-						m_pNoteBookWindows->InsertPage(m_pNoteBookWindows->GetPageCount() - 1, sw, wxString::Format(_("Window %d"), m_pNoteBookWindows->GetPageCount()));
+						m_pNoteBookWindows->InsertPage(m_pNoteBookWindows->GetPageCount() - 1, sw, wxString::Format(_("Window %d"), (int) m_pNoteBookWindows->GetPageCount()));
 						sw->InitPanels(hangingSupportLevel);
 					}
 				}	
@@ -699,18 +705,16 @@ namespace GNC {
 
 			virtual void OnPageChanging( wxAuiNotebookEvent& event ) 
 			{
-				if (event.selection == ((int)m_pNoteBookWindows->GetPageCount() -1)) {
-					if (event.old_selection < 0) {
+				if (event.GetSelection() == ((int)m_pNoteBookWindows->GetPageCount() -1)) {
+					if (event.GetOldSelection() < 0) {
 						//if comes from page closing
 						m_pNoteBookWindows->SetSelection(m_pNoteBookWindows->GetPageCount() - 2);
 					} else {
 						if (hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL) {
-							m_pWorkspacePanel->Freeze();
 							StudyWindow* sw = new StudyWindow(m_pNoteBookWindows);
-							m_pNoteBookWindows->InsertPage(m_pNoteBookWindows->GetPageCount() - 1,sw, wxString::Format(_("Window %d"), m_pNoteBookWindows->GetPageCount()), true);
+							m_pNoteBookWindows->InsertPage(m_pNoteBookWindows->GetPageCount() - 1,sw, wxString::Format(_("Window %d"), (int) m_pNoteBookWindows->GetPageCount()), true);
 							sw->InitPanels(hangingSupportLevel);
 							m_pNoteBookWindows->Layout();
-							m_pWorkspacePanel->Thaw();
 						} else {
 							wxMessageBox(_("This view doesn't support multiple windows"),_("Info"),wxOK | wxICON_INFORMATION, this);
 						}
@@ -726,7 +730,7 @@ namespace GNC {
 				if (m_pNoteBookWindows->GetPageCount() <= 2) {
 					event.Veto();
 				} else {
-					event.Skip();
+					event.Skip();					
 				}
 			}
 
@@ -736,13 +740,13 @@ namespace GNC {
 			GNC::GCS::Ptr<GNC::GCS::HangingProtocol> hangingProtocol;	
 		};
 		////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-		class wxTreeItemDataProtocols: public wxTreeItemData
+		class wxHangingClientData: public wxClientData
 		{
 		public:
-			wxTreeItemDataProtocols(const GNC::GCS::Ptr<GNC::GCS::HangingProtocol>& hp): hangingProtocol(hp)
+			wxHangingClientData(const GNC::GCS::Ptr<GNC::GCS::HangingProtocol>& hp): hangingProtocol(hp)
 			{
 			}
-			~wxTreeItemDataProtocols()
+			virtual ~wxHangingClientData()
 			{
 			}
 			GNC::GCS::Ptr<GNC::GCS::HangingProtocol> hangingProtocol;
@@ -750,15 +754,32 @@ namespace GNC {
 		////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 		HangingProtocolConfigurationPanel::HangingProtocolConfigurationPanel(wxWindow* pParent,IDialogoConfiguracion* pDialogo): HangingProtocolConfigurationPanelBase(pParent), IPasoConfiguracion(pDialogo)
 		{
-			Recargar();
 			wxColour barColor = wxColour(200,200,200);
 			wxFont fontBar = wxFont( 10, 70, 90, wxFONTWEIGHT_BOLD, false, wxEmptyString );
-			m_pTreeListProtocols->Connect(wxEVT_COMMAND_TREE_ITEM_ACTIVATED, wxTreeEventHandler( HangingProtocolConfigurationPanel::OnHangingListDClick ), NULL, this );
-			m_pTreeListProtocols->Connect(wxEVT_COMMAND_TREE_SEL_CHANGED, wxTreeEventHandler( HangingProtocolConfigurationPanel::OnHangingListChangeSelection ), NULL, this );
+
+			m_pModel = new wxDataViewListStore();
+			m_pListHanging->AssociateModel(m_pModel.get());
+
+			m_pListHanging->AppendColumn( new wxDataViewColumn( _("Name"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), COL_HP_NAME, 200, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+			m_pListHanging->AppendColumn( new wxDataViewColumn( _("Active"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), COL_HP_ACTIVE, 150, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+
+
+			m_pListHanging->Connect(wxEVT_DATAVIEW_ITEM_ACTIVATED, wxDataViewEventHandler( HangingProtocolConfigurationPanel::OnHangingListDClick ), NULL, this );
+			m_pListHanging->Connect(wxEVT_DATAVIEW_SELECTION_CHANGED, wxDataViewEventHandler( HangingProtocolConfigurationPanel::OnHangingListChangeSelection ), NULL, this );
+			
+			Recargar();
 		}
 
 		HangingProtocolConfigurationPanel::~HangingProtocolConfigurationPanel()
 		{
+			wxDataViewItemArray children;
+			m_pModel->GetChildren(wxDataViewItem(NULL), children);
+			wxVariant val;
+			for (wxDataViewItemArray::iterator it = children.begin(); it != children.end(); ++it) 
+			{
+				m_pModel->GetValue(val, (*it), COL_HP_CLIENT_DATA);
+				delete (wxHangingClientData*)(val.GetVoidPtr());
+			}
 		}
 
 		void HangingProtocolConfigurationPanel::Recargar()
@@ -766,26 +787,28 @@ namespace GNC {
 			std::list<GNC::GCS::Ptr<GNC::GCS::HangingProtocol> > listOfProtocols = GNC::GCS::HangingProtocolController::Instance()->getHangingProtocols();
 
 			bool primero =true;
-			m_pTreeListProtocols->DeleteRoot();
-			wxTreeItemId idRoot = m_pTreeListProtocols->AddRoot(wxT("Root"));
-
+			
+			wxVector<wxVariant> data;
 			for (std::list<GNC::GCS::Ptr<GNC::GCS::HangingProtocol> >::iterator it = listOfProtocols.begin(); it != listOfProtocols.end(); ++it) 
 			{
-				wxTreeItemId idItem = m_pTreeListProtocols->AppendItem(idRoot,wxString::FromUTF8((*it)->getName().c_str()));
+				data.clear();
+				data.push_back(wxString::FromUTF8((*it)->getName().c_str()));
 				if ((*it)->isActive()) {
-					m_pTreeListProtocols->SetItemText(idItem, 1, _("Yes"));
+					data.push_back(_("Yes"));
 				} else {
-					m_pTreeListProtocols->SetItemText(idItem, 1, _("No"));
+					data.push_back(_("No"));
 				}
-				m_pTreeListProtocols->SetItemData(idItem, new wxTreeItemDataProtocols((*it)));
+				
+				data.push_back(new wxHangingClientData((*it)));
+				m_pModel->AppendItem(data);
 				if(primero) {
-					m_pTreeListProtocols->SelectItem(idItem);
+					m_pListHanging->SelectRow(0);
 					m_pBEdit->Enable(true);
 					m_pBDelete->Enable(true);
 					m_pBActive->Enable(true);
 					primero = false;
 				}
-			}
+			}			
 		}
 
 		//region "Metodos de IPasoConfiguracion"
@@ -814,12 +837,11 @@ namespace GNC {
 		{
 			//get hanging protocols...
 			std::list<GNC::GCS::Ptr<GNC::GCS::HangingProtocol> > listOfProtocols;
-			wxTreeItemIdValue cookie;
-			wxTreeItemId itemActual = m_pTreeListProtocols->GetFirstChild(m_pTreeListProtocols->GetRootItem(), cookie);
-			while (itemActual.IsOk())
+			wxVariant value;
+			for (unsigned int i = 0; i< m_pModel->GetItemCount(); i++)
 			{
-				listOfProtocols.push_back(((wxTreeItemDataProtocols*)m_pTreeListProtocols->GetItemData(itemActual))->hangingProtocol);
-				itemActual = m_pTreeListProtocols->GetNextChild(m_pTreeListProtocols->GetRootItem(), cookie);
+				m_pModel->GetValueByRow(value, i, COL_HP_CLIENT_DATA);
+				listOfProtocols.push_back(((wxHangingClientData*)value.GetVoidPtr())->hangingProtocol);
 			}
 
 			GNC::GCS::HangingProtocolController::Instance()->setHangingProtocols(listOfProtocols);
@@ -828,12 +850,12 @@ namespace GNC {
 		//endregion
 
 
-		void HangingProtocolConfigurationPanel::OnHangingListDClick(wxTreeEvent& )
+		void HangingProtocolConfigurationPanel::OnHangingListDClick(wxDataViewEvent& )
 		{
 			Edit();
 		}
 
-		void HangingProtocolConfigurationPanel::OnHangingListChangeSelection(wxTreeEvent& event)
+		void HangingProtocolConfigurationPanel::OnHangingListChangeSelection(wxDataViewEvent& event)
 		{
 			if(event.GetItem().IsOk()) {
 				m_pBEdit->Enable(true);
@@ -848,14 +870,16 @@ namespace GNC {
 
 		void HangingProtocolConfigurationPanel::OnSetActive(wxCommandEvent &)
 		{
-			wxTreeItemId item = m_pTreeListProtocols->GetSelection();
-			if (item.IsOk()) {
-				GNC::GCS::Ptr<GNC::GCS::HangingProtocol>& hp = ((wxTreeItemDataProtocols*)m_pTreeListProtocols->GetItemData(item))->hangingProtocol;
+			wxDataViewItem selection = m_pListHanging->GetSelection();
+			if (selection.IsOk()) {
+				wxVariant value;
+				m_pModel->GetValue(value, selection, COL_HP_CLIENT_DATA);
+				GNC::GCS::Ptr<GNC::GCS::HangingProtocol>& hp = ((wxHangingClientData*)value.GetVoidPtr())->hangingProtocol;
 				hp->setActive(!hp->isActive());
 				if (hp->isActive()) {
-					m_pTreeListProtocols->SetItemText(item, 1, _("Yes"));
+					m_pListHanging->SetValue( _("Yes"), m_pModel->GetRow(selection), COL_HP_ACTIVE);
 				} else {
-					m_pTreeListProtocols->SetItemText(item, 1, _("No"));
+					m_pListHanging->SetValue( _("No"), m_pModel->GetRow(selection), COL_HP_ACTIVE);
 				}
 				OnPropiedadCambiada();
 			}
@@ -866,13 +890,16 @@ namespace GNC {
 			EditHangingProtocolDialog dlg(this);
 			if (dlg.ShowModal() == wxID_OK) {
 				GNC::GCS::Ptr<GNC::GCS::HangingProtocol> hp = dlg.getHangingProtocol();
-				wxTreeItemId idItem = m_pTreeListProtocols->AppendItem(m_pTreeListProtocols->GetRootItem(),wxString::FromUTF8(hp->getName().c_str()));
+				wxVector<wxVariant> data;
+				data.push_back(wxString::FromUTF8(hp->getName().c_str()));
 				if (hp->isActive()) {
-					m_pTreeListProtocols->SetItemText(idItem, 1, _("Yes"));
+					data.push_back(_("Yes"));
 				} else {
-					m_pTreeListProtocols->SetItemText(idItem, 1, _("No"));
+					data.push_back(_("No"));
 				}
-				m_pTreeListProtocols->SetItemData(idItem, new wxTreeItemDataProtocols(hp));
+				
+				data.push_back(new wxHangingClientData(hp));
+				m_pModel->AppendItem(data);
 				OnPropiedadCambiada();
 			}
 		}
@@ -884,18 +911,20 @@ namespace GNC {
 
 		void HangingProtocolConfigurationPanel::Edit()
 		{
-			wxTreeItemId item = m_pTreeListProtocols->GetSelection();
-			if (item.IsOk()) {
-				EditHangingProtocolDialog dlg(this, ((wxTreeItemDataProtocols*)m_pTreeListProtocols->GetItemData(item))->hangingProtocol);
+			wxDataViewItem selection = m_pListHanging->GetSelection();
+			if (selection.IsOk()) {
+				wxVariant value;
+				m_pModel->GetValue(value, selection, COL_HP_CLIENT_DATA);
+				EditHangingProtocolDialog dlg(this, ((wxHangingClientData*)value.GetVoidPtr())->hangingProtocol);
 				if (dlg.ShowModal() == wxID_OK) {
 					GNC::GCS::Ptr<GNC::GCS::HangingProtocol> hp = dlg.getHangingProtocol();
 					if (hp->isActive()) {
-						m_pTreeListProtocols->SetItemText(item, 1, _("Yes"));
+						m_pListHanging->SetValue( _("Yes"), m_pModel->GetRow(selection), COL_HP_ACTIVE);
 					} else {
-						m_pTreeListProtocols->SetItemText(item, 1, _("No"));
+						m_pListHanging->SetValue( _("No"), m_pModel->GetRow(selection), COL_HP_ACTIVE);
 					}
-					m_pTreeListProtocols->SetItemText(item, 0, wxString::FromUTF8(hp->getName().c_str()));
-					((wxTreeItemDataProtocols*)m_pTreeListProtocols->GetItemData(item))->hangingProtocol = hp;
+					m_pListHanging->SetValue( wxString::FromUTF8(hp->getName().c_str()), m_pModel->GetRow(selection), COL_HP_NAME);
+					((wxHangingClientData*)value.GetVoidPtr())->hangingProtocol = dlg.getHangingProtocol();
 					OnPropiedadCambiada();
 				}
 			}
@@ -903,9 +932,12 @@ namespace GNC {
 
 		void HangingProtocolConfigurationPanel::OnEliminarClick(wxCommandEvent &)
 		{
-			wxTreeItemId item = m_pTreeListProtocols->GetSelection();
-			if (item.IsOk()) {
-				m_pTreeListProtocols->Delete(item);
+			wxDataViewItem selection = m_pListHanging->GetSelection();
+			if (selection.IsOk()) {
+				wxVariant value;
+				m_pModel->GetValue(value, selection, COL_HP_CLIENT_DATA);
+				delete (wxHangingClientData*)value.GetVoidPtr();
+				m_pModel->DeleteItem(m_pListHanging->GetSelectedRow());
 				OnPropiedadCambiada();
 			}
 		}
