@@ -44,8 +44,8 @@ namespace GNC {
 
 
 			protected:
-				virtual void OnHangingListDClick(wxTreeEvent& event);
-				virtual void OnHangingListChangeSelection(wxTreeEvent& event);
+				virtual void OnHangingListDClick(wxDataViewEvent& event);
+				virtual void OnHangingListChangeSelection(wxDataViewEvent& event);
 
 				virtual void OnSetActive(wxCommandEvent &event);
 
@@ -62,6 +62,7 @@ namespace GNC {
 
 				void OnSize(wxSizeEvent &);
 
+				wxObjectDataPtr<wxDataViewListStore> m_pModel;
 		};
 	}
 }
