@@ -18,7 +18,6 @@
 #include <wx/msgout.h>
 #include <wx/dirdlg.h>
 #include <wx/filename.h>
-#include <wx/wxhttpengine/proxysettingsdlg.h>
 #include <main/controllers/configurationcontroller.h>
 #include <sstream>
 #include <wx/file.h>
@@ -175,9 +174,9 @@ namespace GNC {
 				}
 			} else {
 				//se comprueba que puede escribir(escribimos y borramos un fichero chorra)
-				wxString pathFicheroPrueba = path + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d"),rand());
+				wxString pathFicheroPrueba = path + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d"), (int) rand());
 				while(wxFileExists(pathFicheroPrueba)) {
-					pathFicheroPrueba = path + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d"),rand());
+					pathFicheroPrueba = path + wxFileName::GetPathSeparator() + wxString::Format(wxT("%d"), (int) rand());
 				}
 				{
 					wxFile ficheroTmp;
@@ -313,7 +312,7 @@ namespace GNC {
 			OnPropiedadCambiada();
 		}
 
-		void LocalDatabaseConfigurationPanel::OnResetToDefault(wxCommandEvent& evt)
+		void LocalDatabaseConfigurationPanel::OnResetToDefault(wxCommandEvent& /*evt*/)
 		{
 			m_pDICOMDir->SetValue(FROMPATH(GNC::GCS::HistoryController::Instance()->GetDefaultDicomDirPath(true)));
 			m_pCheckDeleteOlder->SetValue(false);
