@@ -45,10 +45,10 @@
 #define COLUMNA_DESCRIPCION       5
 
 
-inline wxBitmap _wxConvertMemoryToBitmap(const unsigned char* data, int length, long type = wxBITMAP_TYPE_ANY )
+inline wxBitmap _wxConvertMemoryToBitmap(const unsigned char* data, int length, wxBitmapType type = wxBITMAP_TYPE_ANY )
 {
 	wxMemoryInputStream stream( data, length );
-	return wxBitmap( wxImage( stream, type, -1 ), -1 );;
+	return wxBitmap( wxImage( stream, type, -1), -1 );;
 }
 
 
