@@ -18,8 +18,10 @@
 #include <api/iconfiguracion.h>
 #include "panelesconfiguracionginkgobase.h"
 
-class wxProxySettings;
 namespace GNC {
+	namespace GCS {
+		class ProxySettings;
+	}
 	namespace GUI {
 
 		class PanelConfiguracionGeneral : public PanelConfiguracionGeneralBase, public IPasoConfiguracion
@@ -53,7 +55,7 @@ namespace GNC {
 				bool m_idiomaCambiado;
 				typedef std::map<std::string, int> TMapLanguages;
 				TMapLanguages m_mapLanguages;
-				wxProxySettings* pProxySettings;
+				GNC::GCS::ProxySettings* pProxySettings;
 		};
 	}
 }
