@@ -39,7 +39,6 @@
 #include <wx/busyinfo.h>
 #include <wx/xml/xml.h>
 
-
 #include "panelconfiguracionpacs.h"
 
 #include <sstream>
@@ -47,6 +46,10 @@
 #include <main/entorno.h>
 #include <resources/ginkgoresourcesmanager.h>
 
+#define NAME_COLUMN_IDX             0
+#define NAME_COLUMN_WIDTH           300
+#define USE_BY_DEFAULT_COLUMN_IDX   1
+#define USE_BY_DEFAULT_COLUMN_WIDTH 80
 
 namespace GNC {
 	namespace GUI {
@@ -77,14 +80,14 @@ namespace GNC {
 
 				RefrescarEstado();
 			}
-			~DialogoEditarCertificado()
-			{}
+			~DialogoEditarCertificado() {
+			}
 
 			virtual void OnAceptarClick(wxCommandEvent&)
 			{
 				if (Validar()) {
 					m_Ok = true;
-					Close();
+					EndModal(wxID_OK);
 				}
 			}
 
@@ -147,6 +150,7 @@ namespace GNC {
 			{
 				RefrescarEstado();
 			}
+
 			virtual void RefrescarEstado()
 			{
 				m_pPanelPublic->Enable(!m_pCheckDefault->IsChecked());
@@ -205,10 +209,12 @@ namespace GNC {
 		class DialogoLocalPACS: public DialogoLocalPACSBase
 		{
 		public:
+
 			DialogoLocalPACS(wxWindow* pParent): DialogoLocalPACSBase(pParent)
 			{
 				m_Ok = false;
 			}
+
 			~DialogoLocalPACS()
 			{}
 
@@ -257,7 +263,7 @@ namespace GNC {
 			{
 				if (Validar()) {
 					m_Ok = true;
-					Close();
+					EndModal(wxID_OK);
 				}
 			}
 
@@ -289,6 +295,7 @@ namespace GNC {
 		class DialogoServidorPACS: public DialogoServidorPACSBase
 		{
 		public:
+
 			DialogoServidorPACS(wxWindow* pParent, PanelConfiguracionPACS::TipoConfigLocal& configLocal, const wxString& strPuertoLocal, const wxString& aetLocal, std::list<std::string> usedPACSIds) :
 				DialogoServidorPACSBase(pParent),
 				m_configLocal(configLocal),
@@ -385,8 +392,8 @@ namespace GNC {
 				m_pId->SetValue(wxString::FromUTF8(tipoPacs.ID.c_str()));
 				m_pAET->SetValue(wxString::FromUTF8(tipoPacs.AET.c_str()));
 				m_pHost->SetValue(wxString::FromUTF8(tipoPacs.HostName.c_str()));
-				m_pPuerto->SetValue(wxString::Format(wxT("%d"), tipoPacs.Port));
-				m_pPDU->SetValue(wxString::Format(wxT("%d"), tipoPacs.PDU));
+				m_pPuerto->SetValue(wxString::Format(wxT("%d"), (int) tipoPacs.Port));
+				m_pPDU->SetValue(wxString::Format(wxT("%d"), (int) tipoPacs.PDU));
 
 				m_pRetrieveMethod->SetSelection((int)tipoPacs.retrieveMethod);
 				m_pRetrieveMode->SetSelection(tipoPacs.retrieveSeries?0:1);
@@ -447,13 +454,13 @@ namespace GNC {
 
 			virtual void OnCancelClick(wxCommandEvent &){
 				m_Ok=false;
-				Close();
+				EndModal(wxID_CANCEL);
 			}
 
 			virtual void OnOkClick(wxCommandEvent &){
 				if(Validar()) {
 					m_Ok=true;
-					Close();
+					EndModal(wxID_OK);
 				}
 			}
 
@@ -536,6 +543,7 @@ namespace GNC {
 				}
 				return ok;
 			}
+
 			virtual void OnProbarClick(wxCommandEvent &)
 			{
 				if(Validar()) {
@@ -683,15 +691,16 @@ namespace GNC {
 			std::string m_defCharset;
 		};
 
-
 		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 		///////////////////////PanelConfiguracionPACS////////////////////////////////////////////////////////////////////////////////////
 		/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 		PanelConfiguracionPACS::PanelConfiguracionPACS(wxWindow* pParent,IDialogoConfiguracion* pDialogo): PanelConfiguracionPACSBase(pParent), IPasoConfiguracion(pDialogo)
 		{
-			this->m_pTreeListPACS->AddColumn(_("Name"), 200, wxALIGN_LEFT, -1, true, false);
-			this->m_pTreeListPACS->AddColumn(_("Use by default"), 70, wxALIGN_LEFT, -1, true, false);
+			m_pModel = new wxDataViewListStore();
+			m_pListPacs->AssociateModel(m_pModel.get());
+			m_pListPacs->AppendColumn( new wxDataViewColumn( _("Name"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), NAME_COLUMN_IDX, NAME_COLUMN_WIDTH, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+			m_pListPacs->AppendColumn( new wxDataViewColumn( _("Use by default"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), USE_BY_DEFAULT_COLUMN_IDX, USE_BY_DEFAULT_COLUMN_WIDTH, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
 			Recargar();
 
 			m_pHelpBitmap->SetBitmap(GinkgoResourcesManager::MenuIcons::GetIcoHelp());
@@ -703,8 +712,8 @@ namespace GNC {
 				this->Refresh(true);
 			}
 
-			m_pTreeListPACS->Connect(wxEVT_COMMAND_TREE_ITEM_ACTIVATED, wxTreeEventHandler( PanelConfiguracionPACS::OnListaPACSDClick ), NULL, this );
-			m_pTreeListPACS->Connect(wxEVT_COMMAND_TREE_SEL_CHANGED, wxTreeEventHandler( PanelConfiguracionPACS::OnListaPACSChoice ), NULL, this );
+			m_pListPacs->Connect(wxEVT_DATAVIEW_SELECTION_CHANGED, wxDataViewEventHandler(PanelConfiguracionPACS::OnListaPACSChoice), NULL, this);
+			m_pListPacs->Connect(wxEVT_DATAVIEW_ITEM_ACTIVATED, wxDataViewEventHandler(PanelConfiguracionPACS::OnListaPACSDClick), NULL, this);
 		}
 
 		PanelConfiguracionPACS::~PanelConfiguracionPACS()
@@ -733,33 +742,41 @@ namespace GNC {
 			m_configLocal.privateKey = serverLocal->GetPrivateKey();
 			m_configLocal.certificate = serverLocal->GetCertificate();
 
+			wxVector<wxVariant> data;
+
 			if(GNC::GCS::IControladorPermisos::Instance()->Get("core.pacs.limits","remote_pacs")) {
 				m_pPACSServers->Enable(true);
 
-				m_pTreeListPACS->DeleteRoot();
-				wxTreeItemId idRoot = m_pTreeListPACS->AddRoot(wxT("Root"));
+				m_pListPacs->DeleteAllItems();
 				m_servidores.clear();
-
+				
 				DicomServerList::Instance()->Reload();
-
 				DicomServerList::TServerList ListOfServers = DicomServerList::Instance()->GetServerList();
+				
+				wxVector<wxVariant> data;
 				for (DicomServerList::TServerList::iterator it = ListOfServers.begin(); it != ListOfServers.end(); ++it)
 				{
-					m_servidores.push_back((*it));
-					wxTreeItemId idItem = m_pTreeListPACS->AppendItem(idRoot, wxString::FromUTF8((*it)->ID.c_str()));
-					if((*it)->isDefault) {
-						m_pTreeListPACS->SetItemText(idItem, 1, _("Yes"));
+					DicomServerList::TServerList::value_type& tuple = (*it);
+					data.clear();
+					m_servidores.push_back(tuple);
+
+					data.push_back(wxString::FromUTF8(tuple->ID.c_str()));
+					if (tuple->isDefault) {
+						data.push_back(_("Yes"));
 					} else {
-						m_pTreeListPACS->SetItemText(idItem, 1, _("No"));
+						data.push_back(_("No"));
 					}
+					m_pModel->AppendItem(data);
 				}
 
-				if(m_pTreeListPACS->GetChildrenCount(idRoot) > 0){
-					wxTreeItemIdValue cookie;
-					m_pTreeListPACS->SelectItem(m_pTreeListPACS->GetFirstChild(idRoot, cookie));
-					wxTreeEvent evt;
-					OnListaPACSChoice(evt);
+				if(m_pModel->GetCount() > 0) {
+					wxDataViewItem item = m_pModel->GetItem(0);
+					if (item.IsOk()) {
+						m_pListPacs->SelectRow(0);						
+					}
 				}
+				wxDataViewEvent evt;
+				OnListaPACSChoice(evt);
 			}
 			else {
 				m_pPACSServers->Enable(false);
@@ -881,21 +898,23 @@ namespace GNC {
 			}
 		}
 
-		void PanelConfiguracionPACS::OnListaPACSChoice(wxTreeEvent &){
+		void PanelConfiguracionPACS::OnListaPACSChoice(wxDataViewEvent &){
 			//se carga la descripcion
-			bool enable = m_pTreeListPACS->GetSelection().IsOk();
+
+			bool enable = m_pListPacs->GetSelection().IsOk();
 			m_pEditButton->Enable(enable);
 			m_pDelButton->Enable(enable);
 			m_pDefaultButton->Enable(enable);
 		}
 
-		void PanelConfiguracionPACS::OnListaPACSDClick(wxTreeEvent &)
+		void PanelConfiguracionPACS::OnListaPACSDClick(wxDataViewEvent &)
 		{
 			wxCommandEvent evt;
 			OnEditarClick(evt);
 		}
 
 		void PanelConfiguracionPACS::OnNuevoClick(wxCommandEvent &){
+			
 			std::list<std::string> listIdsPacs;
 			for (TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it) {
 				listIdsPacs.push_back((*it)->ID);
@@ -903,31 +922,53 @@ namespace GNC {
 			DialogoServidorPACS dialogo(this, m_configLocal, m_pPuertoLocal->GetValue(), wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET( std::string(m_pAETLocal->GetValue().ToUTF8()) ).c_str() ), listIdsPacs );
 			dialogo.ShowModal();
 			if(dialogo.m_Ok){
-				GNC::GCS::Ptr<DicomServer> tp(new DicomServer());
-				dialogo.GetParametros(*tp);
-				if (m_pTreeListPACS->GetChildrenCount(m_pTreeListPACS->GetRootItem()) == 0) {
-					tp->isDefault = true;
+				GNC::GCS::Ptr<DicomServer> tuple(new DicomServer());
+				dialogo.GetParametros(*tuple);
+				tuple->isDefault = true;
+				if(m_pModel->GetCount() > 0) {
+					wxDataViewItem item = m_pModel->GetItem(0);
+					if (item.IsOk()) {
+						tuple->isDefault = false;
+					}
 				}
-				m_servidores.push_back(tp);
+				m_servidores.push_back(tuple);
 
-				wxTreeItemId idItem = m_pTreeListPACS->AppendItem(m_pTreeListPACS->GetRootItem(), wxString::FromUTF8(tp->ID.c_str()));
-				if(tp->isDefault) {
-					m_pTreeListPACS->SetItemText(idItem, 1, _("Yes"));
+				wxVector<wxVariant> data;
+
+				data.push_back(wxString::FromUTF8(tuple->ID.c_str()));
+				if (tuple->isDefault) {
+					data.push_back(_("Yes"));
 				} else {
-					m_pTreeListPACS->SetItemText(idItem, 1, _("No"));
+					data.push_back(_("No"));
 				}
+				m_pModel->AppendItem(data);
+				
 
-				m_pTreeListPACS->SelectItem(idItem);
-				wxTreeEvent evt;
+				wxVariant val;
+				bool notFound = true;
+				for (unsigned int i = 0; notFound && i < m_pModel->GetCount(); ++i) {
+					wxDataViewItem item = m_pModel->GetItem(i);
+					m_pModel->GetValueByRow(val, i, NAME_COLUMN_IDX);
+					std::string stdVal(val.GetString().ToUTF8());
+					if (stdVal == tuple->ID) {
+						notFound = false;
+						m_pListPacs->SelectRow(i);
+					}
+				}
+				wxDataViewEvent evt;
 				OnListaPACSChoice(evt);
 				OnPropiedadCambiada();
 			}
 		}
 
 		void PanelConfiguracionPACS::OnEditarClick(wxCommandEvent &){
-			wxTreeItemId id  = m_pTreeListPACS->GetSelection();
-			if(id.IsOk()){
-				std::string idSeleccionado(m_pTreeListPACS->GetItemText(id).ToUTF8());
+
+			wxDataViewItem selection = m_pListPacs->GetSelection();
+
+			if(selection.IsOk()){
+				wxVariant val;
+				m_pModel->GetValue(val, selection, NAME_COLUMN_IDX);
+				std::string idSeleccionado(val.GetString().ToUTF8());
 
 				std::list<std::string> listIdsPacs;
 				for (TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it) {
@@ -944,11 +985,23 @@ namespace GNC {
 						dialogo.ShowModal();
 						if(dialogo.m_Ok){
 							dialogo.GetParametros(*(*it));
-							//se refresca el combo
-							m_pTreeListPACS->SetItemText(id,wxString::FromUTF8((*it)->ID.c_str()));
-							m_pTreeListPACS->SelectItem(id);
+							// Se refresca el valor
+							val = wxString::FromUTF8((*it)->ID.c_str());
+							m_pModel->SetValue(val, selection, NAME_COLUMN_IDX);
+							m_pModel->ItemChanged(selection);
 
-							wxTreeEvent evt;
+							wxVariant val2;
+							bool notFound = true;
+							for (unsigned int i = 0; notFound && i < m_pModel->GetCount(); ++i) {
+								wxDataViewItem item = m_pModel->GetItem(i);
+								m_pModel->GetValueByRow(val2, i, NAME_COLUMN_IDX);
+								if (val == val2) {
+									m_pListPacs->SelectRow(i);									
+									break;
+								}
+							}
+							
+							wxDataViewEvent evt;
 							OnListaPACSChoice(evt);
 							OnPropiedadCambiada();
 						}
@@ -958,19 +1011,36 @@ namespace GNC {
 		}
 
 		void PanelConfiguracionPACS::OnEliminarClick(wxCommandEvent &){
-			wxTreeItemId itemSeleccionado = m_pTreeListPACS->GetSelection();
-			if(itemSeleccionado.IsOk()){
-				std::string idSeleccionado(m_pTreeListPACS->GetItemText(itemSeleccionado).ToUTF8());
-				int answer = wxMessageBox(_("Confirm the removal of the node") + wxString::FromUTF8(idSeleccionado.c_str()), _("Data modified"), wxYES_NO | wxCANCEL, this);
+
+			wxDataViewItem selection =m_pListPacs->GetSelection();
+
+			if(selection.IsOk()){
+				wxVariant val;
+				m_pModel->GetValue(val, selection, NAME_COLUMN_IDX);
+				std::string idSeleccionado(val.GetString().ToUTF8());
+
+				int answer = wxMessageBox(_("Confirm the removal of the node") + wxT(" ") + wxString::FromUTF8(idSeleccionado.c_str()), _("Data modified"), wxYES_NO | wxCANCEL, this);
 				if(answer == wxYES){
 					for(TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it){
 						if((*it)->ID == idSeleccionado){
-							m_pTreeListPACS->Delete(itemSeleccionado);
+
+							bool notFound = true;
+							for (unsigned int i = 0; notFound && i < m_pModel->GetCount(); ++i) {
+								wxDataViewItem item = m_pModel->GetItem(i);
+
+								wxVariant val2;
+								m_pModel->GetValue(val2, item, NAME_COLUMN_IDX);
+								if (val == val2) {
+									notFound = false;
+									m_pModel->DeleteItem(i);
+								}
+							}
 							m_servidores.erase(it);
 							break;
 						}
 					}
-					wxTreeEvent evt;
+					m_pListPacs->Refresh();
+					wxDataViewEvent evt;
 					OnListaPACSChoice(evt);
 					OnPropiedadCambiada();
 				}
@@ -979,31 +1049,43 @@ namespace GNC {
 
 		void PanelConfiguracionPACS::OnSetDefaultClick(wxCommandEvent &)
 		{
-			wxTreeItemId itemSeleccionado = m_pTreeListPACS->GetSelection();
-			if(itemSeleccionado.IsOk()){
-				std::string idSeleccionado(m_pTreeListPACS->GetItemText(itemSeleccionado).ToUTF8());
+			
+			wxDataViewItem selection = m_pListPacs->GetSelection();
+			if(selection.IsOk()){
+				wxVariant val;
+				m_pModel->GetValue(val, selection, NAME_COLUMN_IDX);
+				std::string idSeleccionado(val.GetString().ToUTF8());
+
 				for(TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it){
-					if((*it)->ID == idSeleccionado){
-						(*it)->isDefault = true;
+					TipoListaPACS::value_type& item = (*it);
+					if(item->ID == idSeleccionado){
+						item->isDefault = true;
 					} else {
-						(*it)->isDefault = false;
+						item->isDefault = false;
 					}
 				}
-				wxTreeItemIdValue cookie;
-				wxTreeItemId itemActual = m_pTreeListPACS->GetFirstChild(m_pTreeListPACS->GetRootItem(), cookie);
-				while (itemActual.IsOk())
-				{
-					if (itemActual == itemSeleccionado) {
-						m_pTreeListPACS->SetItemText(itemActual,1,_("Yes"));
+
+				wxDataViewItemArray items;
+				
+				for (unsigned int i = 0; i < m_pModel->GetCount(); ++i) {
+					wxVariant val2;
+					wxDataViewItem item = m_pModel->GetItem(i);
+					m_pModel->GetValue(val2, item, NAME_COLUMN_IDX);
+					
+					if (val == val2) {
+						m_pModel->SetValue(_("Yes"), item, USE_BY_DEFAULT_COLUMN_IDX);
 					} else {
-						m_pTreeListPACS->SetItemText(itemActual,1,_("No"));
+						m_pModel->SetValue(_("No"), item, USE_BY_DEFAULT_COLUMN_IDX);
 					}
-					itemActual = m_pTreeListPACS->GetNextChild(m_pTreeListPACS->GetRootItem(), cookie);
+					items.Add(item);
 				}
-				wxTreeEvent evt;
+				m_pModel->ItemsChanged(items);
+
+				wxDataViewEvent evt;
 				OnListaPACSChoice(evt);
 				OnPropiedadCambiada();
 			}
+			
 		}
 
 		void PanelConfiguracionPACS::OnTextoCambiado(wxCommandEvent & )
