@@ -49,7 +49,13 @@
 
 #define COL_NAME			  0
 #define COL_VALUE			  1
-#define COL_DEFAULT_VALUE 2
+#define COL_DEFAULT_VALUE     2
+
+#define PERM_COL_NAME_IDX     0
+#define PERM_COL_NAME_WIDTH   340
+#define PERM_COL_ACTIVE_IDX   1
+#define PERM_COL_ACTIVE_WIDTH 80
+#define PERM_COL_XML	     2
 
 #define COLOUR_ACTIVE wxColour(10,174,10)
 #define COLOUR_INACTIVE wxColour(174,10,10)
@@ -77,6 +83,7 @@ namespace GNC {
 				}
 			} TipoPermiso;
 			typedef std::map <std::string, GNC::GCS::Permisos::EstadoPermiso> TipoMapaPermisos;
+
 		public:
 			ProfileDialog(wxWindow* pParent, std::list<std::string>& listaNombres, bool isnew = false) :
 					ProfileDialogBase(pParent),
@@ -113,28 +120,31 @@ namespace GNC {
 				//cargamos los permisos "publicos" definidos
 				std::string ultimaCategoria = "";
 				wxPGProperty* cat = NULL;
-				m_gridPermisos->SetColumnCount(3);
-				m_gridPermisos->SetColumnProportion(COL_NAME, 3);
-				m_gridPermisos->SetColumnProportion(COL_VALUE, 4);
-				m_gridPermisos->SetColumnProportion(COL_DEFAULT_VALUE, 2);
+				m_pGridPermisos->SetColumnCount(3);
+				
+				m_pGridPermisos->SetColumnProportion(COL_NAME, 3);
+				m_pGridPermisos->SetColumnProportion(COL_VALUE, 4);
+				m_pGridPermisos->SetColumnProportion(COL_DEFAULT_VALUE, 2);
+				
+				
 				for(GNC::ControladorPermisos::TipoMapaDefiniciones::const_iterator it = definiciones.begin(); it != definiciones.end(); ++it)
 				{
 					if(!(*it).second.privado) {
 						if ((*it).second.espacioNombres != ultimaCategoria) {
 							ultimaCategoria = (*it).second.espacioNombres;
-							cat = m_gridPermisos->Append(new wxPropertyCategory(wxString::FromUTF8((*it).second.descripcionNamespace.c_str()),wxString::FromUTF8(ultimaCategoria.c_str())));
+							cat = m_pGridPermisos->Append(new wxPropertyCategory(wxString::FromUTF8((*it).second.descripcionNamespace.c_str()),wxString::FromUTF8(ultimaCategoria.c_str())));
 						}
 						std::string clave = (*it).second.espacioNombres + SEPARADOR + (*it).second.id;
 						wxLongStringProperty* propValue = new wxLongStringProperty(wxString::FromUTF8((*it).second.descripcion.c_str()), wxString::FromUTF8(clave.c_str()), wxString::FromUTF8((*it).second.valorPorDefecto.c_str()));
 						wxPGProperty* prop = cat->AppendChild(propValue);
-						prop->SetCell(COL_DEFAULT_VALUE, new wxPGCell( _("Default value") ));
+						m_pGridPermisos->SetPropertyCell(prop, COL_DEFAULT_VALUE, _("Default value"));
 						SetPropertyActive(prop, (*it).second.activoPorDefecto);
 					}
 				}
 
-				m_gridPermisos->GetRoot()->SetFlagRecursively(wxPG_PROP_NO_ESCAPE, true);
-				m_gridPermisos->Connect(wxEVT_PG_DOUBLE_CLICK, wxPropertyGridEventHandler( ProfileDialog::OnPgDoubleClick ), NULL, this );
-				m_gridPermisos->Connect(wxEVT_PG_RIGHT_CLICK, wxPropertyGridEventHandler( ProfileDialog::OnPgMenu ), NULL, this );
+				m_pGridPermisos->GetRoot()->SetFlagRecursively(wxPG_PROP_NO_ESCAPE, true);
+				m_pGridPermisos->Connect(wxEVT_PG_DOUBLE_CLICK, wxPropertyGridEventHandler( ProfileDialog::OnPgDoubleClick ), NULL, this );
+				m_pGridPermisos->Connect(wxEVT_PG_RIGHT_CLICK, wxPropertyGridEventHandler( ProfileDialog::OnPgMenu ), NULL, this );
 			}
 
 			~ProfileDialog()
@@ -151,13 +161,12 @@ namespace GNC {
 				doc.SetRoot(root);
 
 				//transformamos lo que esta viendo el usuario a un xml...
-				for(wxPropertyGridIterator it = m_gridPermisos->GetIterator(); !it.AtEnd(); it.Next())
+				for(wxPropertyGridIterator it = m_pGridPermisos->GetIterator(); !it.AtEnd(); it.Next())
 				{
 					wxPGProperty* pProperty = it.GetProperty();
 
 					wxString clave = pProperty->GetName();
 
-
 					wxStringTokenizer tkz(clave, wxString::FromUTF8(SEPARADOR));
 					std::string espacioNombres ="", id="";
 					if ( tkz.HasMoreTokens() )
@@ -206,7 +215,6 @@ namespace GNC {
 						wxXmlNode* data = new wxXmlNode(permiso, wxXML_ELEMENT_NODE, wxT("default_value"));
 						data = new wxXmlNode(data, wxXML_CDATA_SECTION_NODE, wxT("default_value"));
 						data->SetContent(wxString::FromUTF8(def.valorPorDefecto.c_str()));
-
 						data = new wxXmlNode(permiso, wxXML_ELEMENT_NODE, wxT("value"));
 						data = new wxXmlNode(data, wxXML_CDATA_SECTION_NODE, wxT("value"));
 						data->SetContent(wxString::FromUTF8(val.c_str()));
@@ -231,18 +239,18 @@ namespace GNC {
 
 			bool IsPropertyActive(wxPGProperty* pProp) 
 			{
-				wxColour col = pProp->GetCell(COL_NAME)->GetFgCol();
+				wxColour col = pProp->GetCell(COL_NAME).GetFgCol();
 				return col == COLOUR_ACTIVE;
 			}
 
 			void SetPropertyActive(wxPGProperty* pProp, bool value) 
 			{
 				if (value) {	
-					m_gridPermisos->SetPropertyCell(pProp->GetId(), COL_NAME, pProp->GetLabel(), GinkgoResourcesManager::MenuIcons::GetIcoTick(), COLOUR_ACTIVE);
+					m_pGridPermisos->SetPropertyCell(pProp, COL_NAME, pProp->GetLabel(), GinkgoResourcesManager::MenuIcons::GetIcoTick(), COLOUR_ACTIVE);
 				} else {
-					m_gridPermisos->SetPropertyCell(pProp->GetId(), COL_NAME, pProp->GetLabel(), GinkgoResourcesManager::MenuIcons::GetIcoCross(), COLOUR_INACTIVE);
+					m_pGridPermisos->SetPropertyCell(pProp, COL_NAME, pProp->GetLabel(), GinkgoResourcesManager::MenuIcons::GetIcoCross(), COLOUR_INACTIVE);
 				}
-				m_gridPermisos->RefreshProperty(pProp);
+				m_pGridPermisos->RefreshProperty(pProp);
 			}
 
 			virtual void OnPgMenu(wxPropertyGridEvent &event) 
@@ -265,12 +273,12 @@ namespace GNC {
 				menu.Connect(pActive->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ProfileDialog::OnActiveSelectedProperty ), NULL, this );
 				menu.Connect(pInactive->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ProfileDialog::OnDesactiveSelectedProperty ), NULL, this );
 				menu.Connect(pDefault->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ProfileDialog::OnSetDefaultSelected ), NULL, this );
-				m_gridPermisos->PopupMenu(&menu);
+				m_pGridPermisos->PopupMenu(&menu);
 			}
 
 			void OnActiveSelectedProperty(wxCommandEvent&) 
 			{
-				wxPGProperty* prop = m_gridPermisos->GetSelectedProperty();
+				wxPGProperty* prop = m_pGridPermisos->GetSelectedProperty();
 				if (prop != NULL) {
 					SetPropertyActive(prop, true);
 				}
@@ -278,7 +286,7 @@ namespace GNC {
 
 			void OnDesactiveSelectedProperty(wxCommandEvent&) 
 			{
-				wxPGProperty* prop = m_gridPermisos->GetSelectedProperty();
+				wxPGProperty* prop = m_pGridPermisos->GetSelectedProperty();
 				if (prop != NULL) {
 					SetPropertyActive(prop, false);
 				}
@@ -286,7 +294,7 @@ namespace GNC {
 
 			void OnSetDefaultSelected(wxCommandEvent&) 
 			{
-				wxPGProperty* prop = m_gridPermisos->GetSelectedProperty();
+				wxPGProperty* prop = m_pGridPermisos->GetSelectedProperty();
 				if (prop != NULL) {
 					wxString clave = prop->GetName();
 
@@ -313,7 +321,7 @@ namespace GNC {
 						}
 
 						prop->SetValue(wxString::FromUTF8(def.valorPorDefecto.c_str()));
-						m_gridPermisos->SetPropertyCell(prop->GetId(), COL_DEFAULT_VALUE, _("Default value"), wxNullBitmap, wxNullColour);
+						m_pGridPermisos->SetPropertyCell(prop, COL_DEFAULT_VALUE, _("Default value"), wxNullBitmap, wxColour(0,0,0));
 						SetPropertyActive(prop, def.activoPorDefecto);
 					}
 				}
@@ -326,7 +334,7 @@ namespace GNC {
 
 				TipoMapaPermisos mapa = GetPermisosFromXml(xml);
 
-				for(wxPropertyGridIterator it = m_gridPermisos->GetIterator(); !it.AtEnd(); it.Next())
+				for(wxPropertyGridIterator it = m_pGridPermisos->GetIterator(); !it.AtEnd(); it.Next())
 				{
 					wxPGProperty* pProperty = it.GetProperty();
 					if(pProperty != NULL) {
@@ -338,10 +346,10 @@ namespace GNC {
 
 							pProperty->SetValue( wxString::FromUTF8(perm.GetRawValue().c_str()) );
 							if (perm.TieneValorPorDefecto()) {
-								pProperty->GetCell(COL_DEFAULT_VALUE)->SetText(_("Default value"));
+								m_pGridPermisos->SetPropertyCell(pProperty, COL_DEFAULT_VALUE, _("Default value"), wxNullBitmap, wxColour(0,0,0));
 							}
 							else {
-								m_gridPermisos->SetPropertyCell(pProperty->GetId(), COL_DEFAULT_VALUE, _("Set by user"), wxNullBitmap, COLOUR_SET_BY_USER);
+								m_pGridPermisos->SetPropertyCell(pProperty, COL_DEFAULT_VALUE, _("Set by user"), wxNullBitmap, COLOUR_SET_BY_USER);
 							}
 						}
 
@@ -371,13 +379,13 @@ namespace GNC {
 			}
 
 			virtual void OnCancelClick(wxCommandEvent &){
-				Close();
+				EndModal(wxID_CANCEL);
 			}
 
 			virtual void OnOkClick(wxCommandEvent &){
 				if (Validar()) {
 					m_Ok=true;
-					Close();
+					EndModal(wxID_OK);
 				}
 			}
 
@@ -411,18 +419,22 @@ namespace GNC {
 
 		PanelConfiguracionPermisos::PanelConfiguracionPermisos(wxWindow* pParent,IDialogoConfiguracion* pDialogo): PanelConfiguracionPermisosBase(pParent), IPasoConfiguracion(pDialogo)
 		{
-			this->m_pTreeListProfiles->AddColumn(_("Name"), 200, wxALIGN_LEFT, -1, true, false);
-			this->m_pTreeListProfiles->AddColumn(_("Active"), 150, wxALIGN_LEFT, -1, true, false);
+			m_pModel = new wxDataViewListStore();
+			m_pListProfiles->AssociateModel(m_pModel.get());
+
+			m_pListProfiles->AppendColumn( new wxDataViewColumn( _("Name"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), PERM_COL_NAME_IDX, PERM_COL_NAME_WIDTH, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+			m_pListProfiles->AppendColumn( new wxDataViewColumn( _("Active"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), PERM_COL_ACTIVE_IDX, PERM_COL_ACTIVE_WIDTH, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+
 			Recargar();
 			m_permisosCambiados = false;
 
-			m_pTreeListProfiles->Connect(wxEVT_COMMAND_TREE_ITEM_ACTIVATED, wxTreeEventHandler( PanelConfiguracionPermisos::OnListaPermisosDClick ), NULL, this );
-			m_pTreeListProfiles->Connect(wxEVT_COMMAND_TREE_SEL_CHANGED, wxTreeEventHandler( PanelConfiguracionPermisos::OnListaPermisosChangeSelection ), NULL, this );
+			m_pListProfiles->Connect(wxEVT_DATAVIEW_SELECTION_CHANGED, wxDataViewEventHandler( PanelConfiguracionPermisos::OnListaPermisosChangeSelection ), NULL, this );
+			m_pListProfiles->Connect(wxEVT_DATAVIEW_ITEM_ACTIVATED, wxDataViewEventHandler( PanelConfiguracionPermisos::OnListaPermisosDClick ), NULL, this );
+			
 		}
 
 		PanelConfiguracionPermisos::~PanelConfiguracionPermisos()
 		{
-			m_profiles.clear();
 		}
 
 		void PanelConfiguracionPermisos::Recargar()
@@ -433,23 +445,35 @@ namespace GNC {
 			std::string strTmp, xml;
 			bool apply;
 			bool primero =true;
-			m_pTreeListProfiles->DeleteRoot();
-			wxTreeItemId idRoot = m_pTreeListProfiles->AddRoot(wxT("Root"));
+			m_pListProfiles->DeleteAllItems();
 
-			for (GNC::GCS::ConfigurationController::TListGroups::iterator it = profiles.begin(); it != profiles.end(); ++it) {
-				(*it).readStringValue("Name", strTmp);
-				wxTreeItemId idItem = m_pTreeListProfiles->AppendItem(idRoot,wxString::FromUTF8(strTmp.c_str()));
-				(*it).readBoolValue("Apply", apply, false);
-				(*it).readStringValue("XML", xml);
+			wxVector<wxVariant> data;
+			
+			for (GNC::GCS::ConfigurationController::TListGroups::iterator it = profiles.begin(); it != profiles.end(); ++it)
+			{	
+				GNC::GCS::ConfigurationController::TListGroups::value_type tuple = (*it);
+				data.clear();
 
+				tuple.readStringValue("Name", strTmp);
+				data.push_back(wxString::FromUTF8(strTmp.c_str()));
+				tuple.readBoolValue("Apply", apply, false);
 				if(apply) {
-					m_pTreeListProfiles->SetItemText(idItem, 1, _("Yes"));
+					data.push_back(_("Yes"));
 				} else {
-					m_pTreeListProfiles->SetItemText(idItem, 1, _("No"));
+					data.push_back(_("No"));
 				}
-				m_profiles.push_back(TipoProfile(strTmp,xml,apply));
+				tuple.readStringValue("XML", xml);
+				data.push_back(wxString::FromUTF8(xml.c_str()));
+				
+				m_pModel->AppendItem(data);
+
 				if(primero) {
-					m_pTreeListProfiles->SelectItem(idItem);
+					if(m_pModel->GetCount() > 0) {
+						wxDataViewItem item = m_pModel->GetItem(0);
+						if (item.IsOk()) {
+							m_pListProfiles->SelectRow(0);						
+						}
+					}
 					m_pBEdit->Enable(true);
 					m_pBDelete->Enable(true);
 					m_pBActive->Enable(true);
@@ -490,11 +514,16 @@ namespace GNC {
 			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/Profiles");
 			GNC::GCS::ConfigurationController::TListGroups profiles;
 
-			for(TipoListaProfiles::iterator it = m_profiles.begin(); it!= m_profiles.end(); ++it){
+			for (unsigned int i = 0; i< m_pModel->GetItemCount(); i++)
+			{
 				GNC::GCS::ConfigurationController::TMapValues profile;
-				profile["Name"] = (*it).nombre;
-				profile.insertBool("Apply", (*it).aplicar);
-				profile["XML"] = (*it).xml;
+				wxVariant value;
+				m_pModel->GetValueByRow(value, i, PERM_COL_NAME_IDX);
+				profile["Name"] = value.GetString().ToUTF8();
+				m_pModel->GetValueByRow(value, i, PERM_COL_ACTIVE_IDX);				
+				profile.insertBool("Apply", value.GetString().CompareTo(_("Yes")) == 0);
+				m_pModel->GetValueByRow(value, i, PERM_COL_XML);			
+				profile["XML"] = value.GetString().ToUTF8();
 				profiles.push_back(profile);
 			}
 			GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/Profiles", profiles, "Profile");
@@ -504,13 +533,13 @@ namespace GNC {
 		//endregion
 
 
-		void PanelConfiguracionPermisos::OnListaPermisosDClick(wxTreeEvent& )
+		void PanelConfiguracionPermisos::OnListaPermisosDClick(wxDataViewEvent& )
 		{
 			wxCommandEvent evt;
 			OnEditarClick(evt);
 		}
 
-		void PanelConfiguracionPermisos::OnListaPermisosChangeSelection(wxTreeEvent& event)
+		void PanelConfiguracionPermisos::OnListaPermisosChangeSelection(wxDataViewEvent& event)
 		{
 			if(event.GetItem().IsOk()) {
 				m_pBEdit->Enable(true);
@@ -525,111 +554,123 @@ namespace GNC {
 
 		void PanelConfiguracionPermisos::OnSetActive(wxCommandEvent &)
 		{
-			wxTreeItemId item = m_pTreeListProfiles->GetSelection();
-			if (item.IsOk()) {
-				std::string nombreSeleccionado( m_pTreeListProfiles->GetItemText(item).ToUTF8() );
-
-				for(TipoListaProfiles::iterator it = m_profiles.begin(); it != m_profiles.end(); ++it) {
-					if((*it).nombre == nombreSeleccionado) {
-						(*it).aplicar = true;
-					} else {
-						(*it).aplicar = false;
-					}
+			wxDataViewItem selection = m_pListProfiles->GetSelection();
+			if (selection.IsOk()) {
+				wxDataViewItemArray items;
+				for (unsigned int i = 0; i < m_pModel->GetCount(); ++i) {
+					wxDataViewItem item = m_pModel->GetItem(i);
+					m_pModel->SetValue(_("No"), item, PERM_COL_ACTIVE_IDX);
+					items.Add(item);
 				}
-
-				wxTreeItemIdValue cookie;
-				wxTreeItemId itemActual = m_pTreeListProfiles->GetFirstChild(m_pTreeListProfiles->GetRootItem(), cookie);
-				while (itemActual.IsOk())
-				{
-					if (itemActual == item) {
-						m_pTreeListProfiles->SetItemText(itemActual,1,_("Yes"));
-					} else {
-						m_pTreeListProfiles->SetItemText(itemActual,1,_("No"));
-					}
-					itemActual = m_pTreeListProfiles->GetNextChild(m_pTreeListProfiles->GetRootItem(), cookie);
-				}
-
+				m_pModel->SetValue(_("Yes"), selection, PERM_COL_ACTIVE_IDX);
+				m_pModel->ItemsChanged(items);
+				
 				OnPropiedadCambiada();
 			}
 		}
 
-		void PanelConfiguracionPermisos::OnNuevoClick(wxCommandEvent &){
+		void PanelConfiguracionPermisos::OnNuevoClick(wxCommandEvent &)
+		{
 			//se le pasa la lista de identificadores para que no duplique
+			
 			std::list<std::string> listaNombres;
-			for (TipoListaProfiles::iterator it = m_profiles.begin(); it != m_profiles.end(); ++it)
+			wxVariant val;
+			for (unsigned int i = 0; i < m_pModel->GetCount(); ++i) 
 			{
-				listaNombres.push_back((*it).nombre);
+				m_pModel->GetValueByRow(val, i, PERM_COL_NAME_IDX);
+				listaNombres.push_back(std::string(val.GetString().ToUTF8()));
 			}
 
 			ProfileDialog dialogo(this, listaNombres, true);
 			dialogo.ShowModal();
-			if(dialogo.m_Ok){
-				bool es_unico = false;
-
-				if (m_pTreeListProfiles->GetChildrenCount(m_pTreeListProfiles->GetRootItem(), false) == 0) {
-					es_unico = true;
+			if(dialogo.m_Ok)
+			{				
+				std::string name, xml;
+				dialogo.GetParametros(name, xml);
+				bool apply = true;
+				if(m_pModel->GetCount() > 0) {
+					wxDataViewItem item = m_pModel->GetItem(0);
+					if (item.IsOk()) {
+						apply = false;
+					}
 				}
 
-				TipoProfile tp;
-				dialogo.GetParametros(tp.nombre, tp.xml);
-				tp.aplicar = es_unico;
-				m_profiles.push_back(tp);
-
-				wxTreeItemId idItem = m_pTreeListProfiles->AppendItem(m_pTreeListProfiles->GetRootItem(),wxString::FromUTF8(tp.nombre.c_str()));
-				if(tp.aplicar) {
-					m_pTreeListProfiles->SetItemText(idItem, 1, _("Yes"));
+				wxVector<wxVariant> data;
+				data.push_back(wxString::FromUTF8(name.c_str()));
+				if (apply) {
+					data.push_back(_("Yes"));
 				} else {
-					m_pTreeListProfiles->SetItemText(idItem, 1, _("No"));
+					data.push_back(_("No"));
+				}
+				data.push_back(wxString::FromUTF8(xml.c_str()));
+				m_pModel->AppendItem(data);
+
+				
+				wxVariant val;
+				bool notFound = true;
+				for (unsigned int i = 0; notFound && i < m_pModel->GetCount(); ++i) {
+					wxDataViewItem item = m_pModel->GetItem(i);
+					m_pModel->GetValueByRow(val, i, PERM_COL_NAME_IDX);
+					std::string stdVal(val.GetString().ToUTF8());
+					if (stdVal == name) {
+						notFound = false;
+						m_pListProfiles->SelectRow(i);
+					}
 				}
-				m_pTreeListProfiles->SelectItem(idItem);
 
 				OnPropiedadCambiada();
 			}
 		}
 
-		void PanelConfiguracionPermisos::OnEditarClick(wxCommandEvent &){
-			wxTreeItemId item = m_pTreeListProfiles->GetSelection();
-			if (item.IsOk()) {
+		void PanelConfiguracionPermisos::OnEditarClick(wxCommandEvent &)
+		{
+			
+			wxDataViewItem selection = m_pListProfiles->GetSelection();
+
+			if (selection.IsOk()) {
+				wxVariant val;
 				//se le pasa la lista de identificadores para que no duplique
 				std::list<std::string> listaNombres;
-				for (TipoListaProfiles::iterator it = m_profiles.begin(); it != m_profiles.end(); ++it)
+				for (unsigned int i = 0; i < m_pModel->GetCount(); ++i) 
 				{
-					listaNombres.push_back((*it).nombre);
+					m_pModel->GetValueByRow(val, i, PERM_COL_NAME_IDX);
+					listaNombres.push_back(std::string(val.GetString().ToUTF8()));
 				}
-				//item seleccionado
-				std::string nombreSeleccionado( m_pTreeListProfiles->GetItemText(item).ToUTF8() );
+									
+				ProfileDialog dialogo(this, listaNombres);
 
-				for(TipoListaProfiles::iterator it = m_profiles.begin(); it != m_profiles.end(); ++it){
-					if((*it).nombre == nombreSeleccionado) {
-						ProfileDialog dialogo(this, listaNombres);
+				m_pModel->GetValue(val, selection, PERM_COL_NAME_IDX);
+				std::string name(val.GetString().ToUTF8());
+				m_pModel->GetValue(val, selection, PERM_COL_XML);
+				std::string xml(val.GetString().ToUTF8());
 
-						dialogo.SetParametros((*it).nombre,(*it).xml);
+				dialogo.SetParametros(name, xml);
 
-						dialogo.ShowModal();
-						if(dialogo.m_Ok){
-							dialogo.GetParametros((*it).nombre, (*it).xml);
-							//se cambia el nombre en el arbol...
-							m_pTreeListProfiles->SetItemText(item, wxString::FromUTF8((*it).nombre.c_str()) );
-							OnPropiedadCambiada();
-						}
-					}
+				dialogo.ShowModal();
+				if(dialogo.m_Ok){
+					dialogo.GetParametros( name, xml);
+					m_pModel->SetValue(wxVariant(wxString::FromUTF8(name.c_str())), selection, PERM_COL_NAME_IDX);
+					m_pModel->SetValue(wxVariant(wxString::FromUTF8(xml.c_str())), selection, PERM_COL_XML);
+					m_pModel->ItemChanged(selection);
+					OnPropiedadCambiada();
 				}
 			}
 		}
 
 		void PanelConfiguracionPermisos::OnEliminarClick(wxCommandEvent &){
-			wxTreeItemId item = m_pTreeListProfiles->GetSelection();
-			if(item.IsOk()){
-				std::string nombre(m_pTreeListProfiles->GetItemText(item).ToUTF8());
-				int answer = wxMessageBox(_("Confirm the removal of the profile ") + wxString::FromUTF8(nombre.c_str()), _("Data modified"), wxYES_NO | wxCANCEL, this);
+
+			wxDataViewItem selection = m_pListProfiles->GetSelection();
+
+			if(selection.IsOk()){
+
+				wxVariant val;
+				m_pModel->GetValue(val, selection, PERM_COL_NAME_IDX);
+				std::string idSeleccionado(val.GetString().ToUTF8());
+
+				
+				int answer = wxMessageBox(_("Confirm the removal of the profile ") + wxString::FromUTF8(idSeleccionado.c_str()), _("Data modified"), wxYES_NO | wxCANCEL, this);
 				if(answer == wxYES){
-					for(TipoListaProfiles::iterator it = m_profiles.begin(); it != m_profiles.end(); ++it){
-						if((*it).nombre == nombre){
-							m_pTreeListProfiles->Delete(item);
-							m_profiles.erase(it);
-							break;
-						}
-					}
+					m_pModel->DeleteItem(m_pListProfiles->GetSelectedRow());
 					OnPropiedadCambiada();
 				}
 			}
