@@ -42,8 +42,8 @@ namespace GNC {
 
 
 			protected:
-				virtual void OnListaPermisosDClick(wxTreeEvent& event);
-				virtual void OnListaPermisosChangeSelection(wxTreeEvent& event);
+				virtual void OnListaPermisosDClick(wxDataViewEvent& event);
+				virtual void OnListaPermisosChangeSelection(wxDataViewEvent& event);
 
 				virtual void OnSetActive(wxCommandEvent &event);
 
@@ -58,25 +58,9 @@ namespace GNC {
 				virtual void OnPropiedadCambiada();
 
 				void OnSize(wxSizeEvent &);
-
-				typedef struct TipoProfile{
-					std::string nombre;
-					std::string xml;
-					bool aplicar;
-					TipoProfile() :
-						aplicar(false)
-					{
-					}
-
-					TipoProfile(const std::string& _nombre, const std::string& _xml, bool _aplicar) :
-						nombre(_nombre),
-						xml(_xml),
-						aplicar(_aplicar)
-					{						
-					}
-				} TipoProfile;
-				typedef std::vector <TipoProfile> TipoListaProfiles;
-				TipoListaProfiles m_profiles;
+				
+				wxObjectDataPtr<wxDataViewListStore> m_pModel;
+				
 				bool m_permisosCambiados;
 
 		};
