@@ -13,6 +13,7 @@
  */
 #pragma once
 #include <api/iconfiguracion.h>
+#include <api/ientorno.h>
 #include "panelesconfiguracionginkgobase.h"
 #include <string>
 #include <vector>
@@ -44,18 +45,17 @@ namespace GNC {
 				bool Guardar();
 				//endregion
 
-				//region "Helpers"
-				void AutoSizeGrid();
-				//endregion
-
 			public:
-				Ubicaciones::UbicacionesGridTable* m_pUbicacionesGridTable;
-
+				wxObjectDataPtr<wxDataViewListStore> m_pModel;
+				typedef GNC::GCS::IEntorno::MapaUbicaciones UbicationsMapType;
+				UbicationsMapType m_Ubicaciones;
 
 			protected:
 				
-				virtual void OnGridDClick( wxGridEvent& event );
-				virtual void OnGridSelectionChanged(wxGridRangeSelectEvent& event);
+
+				virtual void OnUbicationsDClick( wxDataViewEvent& event );
+				virtual void OnUbicationsSelectionChanged( wxDataViewEvent& event);
+				
 				virtual void OnNuevoClick( wxCommandEvent& event );
 				virtual void OnEditarClick( wxCommandEvent& event );
 				virtual void OnEliminarClick( wxCommandEvent& event );
