@@ -26,7 +26,7 @@
 
 namespace GNC {
 	namespace GCS {
-		class IContratoExportacion;
+		class IWidgetsContract;
 		class IVista;
 		class IEntorno;
 	}
@@ -36,18 +36,18 @@ namespace GNC {
 		{
 			public:
 
-				ParametrosPrincipales(wxWindow* pParent,IWizard* pWizard, GNC::GCS::Ptr<TipoWizardExportacion> pDatosPersistentes);
+				ParametrosPrincipales(wxWindow* pParent,IWizard* pWizard, GNC::GCS::IWidgetsContract* WidgetsContract);
 				~ParametrosPrincipales();
 
 			protected:			
-				GNC::GCS::Ptr<TipoWizardExportacion> m_pDatosPersistentes;
+				GNC::GCS::IWidgetsContract* WidgetsContract;
 
 				void OnChoiceFormatoDestino(wxCommandEvent &event);
 
+				void ExportImage(const wxString& path);
+
 			public:
-
-				bool Seleccionardirectorio();
-
+				
 				virtual std::string GetTitle();
 
 				virtual std::string GetSubTitle();
