@@ -20,12 +20,16 @@
 #include <vector>
 
 namespace GNC {
+	namespace GCS
+	{
+		class WidgetsContract;
+	}
 	namespace GUI {
 		class wxWidzardExportacionGinkgo: public wxWizardGinkgoBase
 		{
 
 		public:
-			wxWidzardExportacionGinkgo(wxWindow* pParent, GNC::GCS::Ptr<GNC::GCS::IImageExportDelegate>& pVista);
+			wxWidzardExportacionGinkgo(wxWindow* pParent, GNC::GCS::IWidgetsContract* WidgetsContract);
 			~wxWidzardExportacionGinkgo();
 
 			virtual void OnCancelarClick(wxCommandEvent& event);
@@ -38,8 +42,6 @@ namespace GNC {
 
 
 		protected:
-			GNC::GCS::Ptr<TipoWizardExportacion>				 m_pDatosPersistentes;
-
 			typedef std::list<IPasoWizard*> ListaPasos;
 			ListaPasos m_ListaPasos;
 
