@@ -17,8 +17,6 @@
 #include <main/controllers/commandcontroller.h>
 #include <resources/ginkgoresourcesmanager.h>
 
-#include <main/controllers/anonusagestats.h>
-
 #include <wx/msgdlg.h>
 
 GNC::GUI::OpenGinkgoCloudDialog::OpenGinkgoCloudDialog(wxWindow* pParent): GNC::GUI::OpenGinkgoCloudDialogBase(pParent)
@@ -28,8 +26,6 @@ GNC::GUI::OpenGinkgoCloudDialog::OpenGinkgoCloudDialog(wxWindow* pParent): GNC::
 	this->SetIcon(icono);
 
 	m_pFileLink->SetFocus();
-
-	LOG_STAT(ANON_STAT_OPEN_CLOUD)
 }
 
 GNC::GUI::OpenGinkgoCloudDialog::~OpenGinkgoCloudDialog()
