@@ -29,7 +29,7 @@
 #include <wx/bitmap.h>
 #include <wx/image.h>
 #include <wx/icon.h>
-#include <wx/treelistctrl/treelistctrl.h>
+#include <wx/treelist.h>
 #include <wx/link_additions.h>
 #include <wx/radiobut.h>
 #include <wx/datectrl.h>
