@@ -20,14 +20,8 @@ namespace GNC {
 	namespace GUI {
 		class ConfirmDeleteDialog:public ConfirmDeleteDialogBase {
 		public:
-			typedef enum {
-				TR_Eliminar,
-				TR_Cancelar
-			} TipoResultado;
-
 			ConfirmDeleteDialog(wxWindow* parent, const wxString& label):ConfirmDeleteDialogBase(parent){
 				m_pLabelEliminar->SetLabel(m_pLabelEliminar->GetLabel() + label + _(" from History?"));
-				m_resultado = TR_Cancelar;
 				m_pTitled->Layout();
 				m_body->Layout();
 				Layout();
@@ -37,20 +31,14 @@ namespace GNC {
 			};
 
 			void OnEliminarClick(wxCommandEvent &) {
-				m_resultado = TR_Eliminar;
-				Close();
+				EndModal(wxOK);
 			}
 
 			void OnCancelarClick(wxCommandEvent &) {
-				m_resultado = TR_Cancelar;
-				Close();
+				EndModal(wxCANCEL);
 			}
 
-			const TipoResultado& GetResultado() const{
-				return m_resultado;
-			}
 		protected:
-			TipoResultado m_resultado;
 		};
 	};
 };
