@@ -16,16 +16,16 @@
 #include <list>
 #include <api/autoptr.h>
 
-#include <wx/aui/aui.h>
 #include <main/controllers/historytoolscontroller.h>
 #include <api/controllers/ieventscontroller.h>
 
+#include <wx/wxginkgotoolbar.h>
 
 namespace GNC {
 	namespace GUI {
 		class HistoryPanel3;
 
-		class HistoryToolMenu: public AUI_NAMESPACE wxAuiToolBar
+		class HistoryToolMenu: public wxGinkgoToolBar
 		{
 			public:
 				HistoryToolMenu(HistoryPanel3* pParent);
