@@ -149,16 +149,25 @@ namespace GNC {
 			icono.CopyFromBitmap(GinkgoResourcesManager::Logos::GetLogoGinkgo32x32());
 			this->SetIcon(icono);
 
+
+			// column 0 of the view control:
+			m_pListViewCtrl->AppendColumn( new wxDataViewColumn( _("Date"), new wxDataViewTextRenderer( wxT("string"), wxDATAVIEW_CELL_INERT ), COL_FECHA, 138, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+			m_pListViewCtrl->AppendColumn( new wxDataViewColumn( _("Destination"), new wxDataViewTextRenderer( wxT("string"), wxDATAVIEW_CELL_INERT ), COL_DESTINO, 70, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+			m_pListViewCtrl->AppendColumn( new wxDataViewColumn( _("Status"), new wxDataViewTextRenderer( wxT("string"), wxDATAVIEW_CELL_INERT ), COL_ESTADO, 128, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+			m_pListViewCtrl->AppendColumn( new wxDataViewColumn( _("Error message"), new wxDataViewTextRenderer( wxT("string"), wxDATAVIEW_CELL_INERT ), COL_MENSAJE_ERROR, 128, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+			m_pListViewCtrl->AppendColumn( new wxDataViewColumn( _("Date Time"), new wxDataViewTextRenderer( wxT("string"), wxDATAVIEW_CELL_INERT ), COL_FECHA, 128, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+
+
 			m_pLabelEnvio->SetLabel(wxString::FromUTF8("Proceso de envío:"));
 
 			m_pTimerRefresh = new TimerControlHL7(this);
 
 			ActualizarEstadoControlador();
 			RefrescarMensajes();
-
-			m_treeListCtrlMensajes->Connect(wxEVT_COMMAND_TREE_ITEM_MENU, wxTreeEventHandler( VentanaControlHL7::OnMensajeMenu ), NULL, this );
-			m_treeListCtrlMensajes->Connect(wxEVT_COMMAND_TREE_ITEM_ACTIVATED, wxTreeEventHandler( VentanaControlHL7::OnMensajeDClick ), NULL, this );
-			m_treeListCtrlMensajes->Connect(wxEVT_COMMAND_TREE_KEY_DOWN, wxTreeEventHandler( VentanaControlHL7::OnListaKey ), NULL, this );
+			
+			m_pListViewCtrl->Connect(wxEVT_DATAVIEW_ITEM_CONTEXT_MENU, wxDataViewEventHandler( VentanaControlHL7::OnMensajeMenu ), NULL, this );
+			m_pListViewCtrl->Connect(wxEVT_DATAVIEW_ITEM_ACTIVATED, wxDataViewEventHandler( VentanaControlHL7::OnMensajeDClick ), NULL, this );
+			m_pListViewCtrl->Connect(wxEVT_CHAR, wxKeyEventHandler( VentanaControlHL7::OnKeyDown ), NULL, this );
 
 			this->Connect( m_menuItemPurgarMensajes->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaControlHL7::OnPurgarMensajes ) );
 			this->Connect( m_menuItemSalir->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaControlHL7::OnMenuSalir ) );
@@ -188,11 +197,11 @@ namespace GNC {
 			}
 		}
 
-		void VentanaControlHL7::OnMensajeMenu(wxTreeEvent& )
+		void VentanaControlHL7::OnMensajeMenu(wxDataViewEvent& )
 		{
 			//si hay un mensaje seleccionado..
-			wxArrayTreeItemIds seleccionados;
-			m_treeListCtrlMensajes->GetSelections(seleccionados);
+			wxDataViewItemArray seleccionados;
+			m_pListViewCtrl->GetSelections(seleccionados);
 			if(seleccionados.size() > 0) {
 				wxMenu* popup = new wxMenu();
 				wxMenuItem* pMenuMostrarVentana = new wxMenuItem(popup,wxID_ANY,_("Show Message"));
@@ -215,7 +224,7 @@ namespace GNC {
 				delete popup;
 			} 
 		}
-		void VentanaControlHL7::OnMensajeDClick(wxTreeEvent& )
+		void VentanaControlHL7::OnMensajeDClick(wxDataViewEvent& )
 		{
 			MostrarVentanaMensaje();
 		}
@@ -227,13 +236,19 @@ namespace GNC {
 
 		void VentanaControlHL7::OnEditarMensaje(wxCommandEvent &)
 		{
-			wxTreeItemId id = m_treeListCtrlMensajes->GetSelection();
+			wxDataViewItem id = m_pListViewCtrl->GetSelection();
 			if(id.IsOk()) {
-				wxString fecha = m_treeListCtrlMensajes->GetItemText(id,COL_FECHA);
-				wxString destino = m_treeListCtrlMensajes->GetItemText(id,COL_DESTINO);
-				wxString estado = m_treeListCtrlMensajes->GetItemText(id,COL_ESTADO);
-				wxString mensaje = m_treeListCtrlMensajes->GetItemText(id,COL_MENSAJE);
-				wxString str = m_treeListCtrlMensajes->GetItemText(id,COL_ID);
+				wxVariant value;
+				m_pListModel->GetValue(value, id, COL_FECHA);
+				wxString fecha = value;
+				m_pListModel->GetValue(value, id, COL_DESTINO);
+				wxString destino = value;
+				m_pListModel->GetValue(value, id, COL_ESTADO);
+				wxString estado = value;
+				m_pListModel->GetValue(value, id, COL_MENSAJE);
+				wxString mensaje = value;
+				m_pListModel->GetValue(value, id, COL_ID);
+				wxString str = value;
 				long idMensaje;
 				if(str.ToLong(&idMensaje)){
 					DialogoMostrarMensaje mostrar(this,fecha,destino,estado,mensaje, true);
@@ -251,9 +266,9 @@ namespace GNC {
 			}
 		}
 
-		void VentanaControlHL7::OnListaKey(wxTreeEvent &event)
+		void VentanaControlHL7::OnListaKey(wxKeyEvent &event)
 		{
-			int keycode = event.GetKeyEvent().GetKeyCode();
+			int keycode = event.GetKeyCode();
 			switch (keycode) {
 				case WXK_DELETE:
 				case WXK_CLEAR:
@@ -322,16 +337,14 @@ namespace GNC {
 			Freeze();
 			try {
 				//conservamos los ids seleccionados
-				wxArrayTreeItemIds seleccionados;
-				m_treeListCtrlMensajes->GetSelections(seleccionados);
+				wxDataViewItemArray seleccionados;
+				m_pListViewCtrl->GetSelections(seleccionados);
 				std::set<int> listaIds;
-
-				for(wxArrayTreeItemIds::iterator it =seleccionados.begin(); it!= seleccionados.end(); ++it) {
-					wxString str = m_treeListCtrlMensajes->GetItemText((*it),COL_ID);
-					long id;
-					if(str.ToLong(&id)){
-						listaIds.insert((int)id);
-					}
+				for(wxDataViewItemArray::iterator it =seleccionados.begin(); it!= seleccionados.end(); ++it) {
+					wxVariant value;
+					m_pListModel->GetValue(value, (*it), COL_ID);
+					long id = value.GetLong();
+					listaIds.insert((int)id);
 				}
 				//
 
@@ -339,36 +352,37 @@ namespace GNC {
 				TListaMensajes listaMensajes;
 				GIL::HL7::ControladorBBDDHl7::Instance()->GetMensajesHL7(listaMensajes);
 				//primero vaciamos el arbol
-				m_treeListCtrlMensajes->DeleteRoot();
-				m_treeListCtrlMensajes->AddRoot(wxT("raiz"));
-				bool primero=true;
+				m_pListViewCtrl->DeleteAllItems();
+				wxVector<wxVariant> data;
 				for(TListaMensajes::iterator it = listaMensajes.begin(); it != listaMensajes.end(); ++it)
 				{
-					wxTreeItemId item = m_treeListCtrlMensajes->AppendItem(m_treeListCtrlMensajes->GetRootItem(),wxString::FromUTF8((*it).m_fecha.c_str()));
-					m_treeListCtrlMensajes->SetItemText(item,COL_MENSAJE,wxString::FromUTF8((*it).m_mensaje.c_str()));
-					m_treeListCtrlMensajes->SetItemText(item,COL_DESTINO,wxString::FromUTF8((*it).m_destino.c_str()));
+					data.clear();
+					data.push_back(wxString::FromUTF8((*it).m_fecha.c_str()));
+					data.push_back(wxString::FromUTF8((*it).m_destino.c_str()));
 					switch((*it).m_estado) {
 						case GIL::HL7::MensajeHL7::TE_Enviado:
-							m_treeListCtrlMensajes->SetItemText(item,COL_ESTADO,_("Sent"));
+							data.push_back(_("Sent"));
+							data.push_back(wxEmptyString);
 							break;
 						case GIL::HL7::MensajeHL7::TE_Pendiente:
-							m_treeListCtrlMensajes->SetItemText(item,COL_ESTADO,_("Pending"));
+							data.push_back(_("Pending"));
+							data.push_back(wxEmptyString);
 							break;
 						case GIL::HL7::MensajeHL7::TE_Warning:
-							m_treeListCtrlMensajes->SetItemText(item,COL_ESTADO,_("Warning"));
-							m_treeListCtrlMensajes->SetItemText(item,COL_MENSAJE_ERROR,wxString::FromUTF8((*it).m_mensajeError.c_str()));
+							data.push_back(_("Warning"));
+							data.push_back(wxString::FromUTF8((*it).m_mensajeError.c_str()));
 							break;
 						case GIL::HL7::MensajeHL7::TE_Error:
-							m_treeListCtrlMensajes->SetItemText(item,COL_ESTADO,_("Error"));
-							m_treeListCtrlMensajes->SetItemText(item,COL_MENSAJE_ERROR,wxString::FromUTF8((*it).m_mensajeError.c_str()));
+							data.push_back(_("Error"));
+							data.push_back(wxString::FromUTF8((*it).m_mensajeError.c_str()));
 							break;
 					}
-					std::ostringstream ostr;
-					ostr << (*it).m_id;
-					m_treeListCtrlMensajes->SetItemText(item,COL_ID,wxString::FromUTF8(ostr.str().c_str()));
+					data.push_back(wxString::FromUTF8((*it).m_mensaje.c_str()));
+					data.push_back(wxString::Format(wxT("%d"), (*it).m_id));
+					m_pListModel->AppendItem(data);
+
 					if(listaIds.find((*it).m_id) != listaIds.end()) {
-						m_treeListCtrlMensajes->SelectItem(item,NULL,primero);
-						primero = false;
+						m_pListViewCtrl->SelectRow(m_pListModel->GetItemCount()-1);
 					}
 				}
 			}catch (GIL::HL7::HL7Exception& ex) {
@@ -397,12 +411,17 @@ namespace GNC {
 
 		void VentanaControlHL7::MostrarVentanaMensaje()
 		{
-			wxTreeItemId id = m_treeListCtrlMensajes->GetSelection();
+			wxDataViewItem id = m_pListViewCtrl->GetSelection();
 			if(id.IsOk()) {
-				wxString fecha = m_treeListCtrlMensajes->GetItemText(id,COL_FECHA);
-				wxString destino = m_treeListCtrlMensajes->GetItemText(id,COL_DESTINO);
-				wxString estado = m_treeListCtrlMensajes->GetItemText(id,COL_ESTADO);
-				wxString mensaje = m_treeListCtrlMensajes->GetItemText(id,COL_MENSAJE);
+				wxVariant value;
+				m_pListModel->GetValue(value, id, COL_FECHA);
+				wxString fecha = value;
+				m_pListModel->GetValue(value, id, COL_DESTINO);
+				wxString destino = value;
+				m_pListModel->GetValue(value, id, COL_ESTADO);
+				wxString estado = value;
+				m_pListModel->GetValue(value, id, COL_MENSAJE);
+				wxString mensaje = value;
 				DialogoMostrarMensaje* mostrar = new DialogoMostrarMensaje(this,fecha,destino,estado,mensaje, false);
 				mostrar->Show();
 			}
@@ -411,16 +430,14 @@ namespace GNC {
 		void VentanaControlHL7::EliminarMensaje()
 		{
 			//pillamos los elementos seleccionados
-			wxArrayTreeItemIds seleccionados;
-			m_treeListCtrlMensajes->GetSelections(seleccionados);
+			wxDataViewItemArray seleccionados;
+			m_pListViewCtrl->GetSelections(seleccionados);
 			std::list<int> listaIds;
 
-			for(wxArrayTreeItemIds::iterator it =seleccionados.begin(); it!= seleccionados.end(); ++it) {
-				wxString str = m_treeListCtrlMensajes->GetItemText((*it),COL_ID);
-				long id;
-				if(str.ToLong(&id)){
-					listaIds.push_back((int)id);
-				}
+			for(wxDataViewItemArray::iterator it =seleccionados.begin(); it!= seleccionados.end(); ++it) {
+				wxVariant value;
+				m_pListModel->GetValue(value, (*it), COL_ID);
+				listaIds.push_back(value.GetLong());
 			}
 
 			if(listaIds.empty())
@@ -467,7 +484,7 @@ namespace GNC {
 					event.Skip(false);
 					break;
 				case WXK_TAB:
-					m_treeListCtrlMensajes->SetFocus();
+					m_pListViewCtrl->SetFocus();
 					event.Skip(false);
 					break;
 				default:
