@@ -37,11 +37,11 @@ namespace GNC{
 			~VentanaControlHL7();
 
 			void OnActivate(wxActivateEvent &event);
-			void OnMensajeMenu(wxTreeEvent& event);
-			void OnMensajeDClick(wxTreeEvent& event);
+			void OnMensajeMenu(wxDataViewEvent& event);
+			void OnMensajeDClick(wxDataViewEvent& event);
 			void OnMostrarMensaje(wxCommandEvent &event);
 			void OnEditarMensaje(wxCommandEvent &event);
-			void OnListaKey(wxTreeEvent &event);
+			void OnListaKey(wxKeyEvent &event);
 			void OnEliminarMensaje(wxCommandEvent &event);
 			void OnPurgarMensajes(wxCommandEvent& event);
 			void OnActualizar(wxCommandEvent &event);
