@@ -43,7 +43,6 @@ namespace GNC {
 
 
 //region "Metodos de obtencion de resultados del dialogo"
-			virtual bool               IsOK();
 			//devuelve la ruta del directorio temporal
 			virtual std::list<std::string> GetRuta();
 
@@ -61,7 +60,6 @@ namespace GNC {
 
 			IPasoWizard::ListaFicheros        m_ListaFicheros;
 			wxString                          m_pathDirTemporal;
-			bool                              m_OK;
 			GNC::GCS::Ptr<GIL::IModeloIntegracion>   m_pModeloIntegracion;
 		};
 	}
