@@ -100,10 +100,6 @@
 #define ID_ACERCA_DE 1062
 #define ID_CONFIGURACION 1063
 #define ID_PANTALLA_COMPLETA 1070
-#define ID_MOSAICO_VERTICAL 1071
-#define ID_MOSAICO_HORIZONTAL 1072
-#define ID_GRID_2_COLUMNAS 1073
-#define ID_GRID_3_COLUMNAS 1074
 #define ID_MOSAICO_RESTAURAR 1075
 #define ID_CONTROLHL7 1076
 #define ID_CONTROLLOGS 1077
@@ -1710,13 +1706,6 @@ void VentanaPrincipal::OnNotebookMenuTab(wxAuiNotebookEvent& )
 
 	wxMenu* subMenuPestanias = new wxMenu();
 	wxMenuItem* pMenuMostrarPrimerPlano = new wxMenuItem(subMenuPestanias, wxID_ANY, _("Tab Regroup"), _("Tab Regroup"), wxITEM_NORMAL );
-	wxMenuItem*  pMosaicoHorizontal = new wxMenuItem( subMenuPestanias, ID_MOSAICO_HORIZONTAL, _("Tile Horizontally"), _("Tile Horizontally"), wxITEM_NORMAL );
-	wxMenuItem*  pMosaicoVertical = new wxMenuItem( subMenuPestanias, ID_MOSAICO_VERTICAL, _("Tile Vertically"), _("Tile Vertically"), wxITEM_NORMAL );
-
-	wxMenu* subMenuGrid = new wxMenu();
-	wxMenuItem*  pGrid2Col = new wxMenuItem( subMenuGrid, ID_GRID_2_COLUMNAS, _("Grid (two columns)"), _("Grid (two columns)"), wxITEM_NORMAL );
-	wxMenuItem*  pGrid3Col = new wxMenuItem( subMenuGrid, ID_GRID_3_COLUMNAS, _("Grid (three columns)"), _("Grid (three columns)"), wxITEM_NORMAL );
-
 	wxMenuItem* pMenuCerrarActiva = new wxMenuItem(menu, ID_CERRAR, _("&Close"), _("Close"), wxITEM_NORMAL );
 	wxMenuItem* pMenuCerrarTodas = new wxMenuItem(menu, ID_CERRAR_TODAS, _("&Close all") , _("Close all windows"), wxITEM_NORMAL );
 
@@ -1726,26 +1715,17 @@ void VentanaPrincipal::OnNotebookMenuTab(wxAuiNotebookEvent& )
 	pMenuCerrarActiva->SetBitmaps(GinkgoResourcesManager::MenuIcons::GetIcoCerrarTab());
 	pMenuMostrarPrimerPlano->SetBitmaps(GinkgoResourcesManager::MenuTabs::GetIcoReagrupar());
 	pPantallaCompleta->SetBitmaps(GinkgoResourcesManager::MenuIcons::GetIcoPantallaCompleta());
-	pGrid2Col->SetBitmaps(GinkgoResourcesManager::MenuTabs::GetIcoGrid2Col());
-	pGrid3Col->SetBitmaps(GinkgoResourcesManager::MenuTabs::GetIcoGrid3Col());
 #else
 	pMenuCerrarActiva->SetBitmap(GinkgoResourcesManager::MenuIcons::GetIcoCerrarTab());
 	pMenuMostrarPrimerPlano->SetBitmap(GinkgoResourcesManager::MenuTabs::GetIcoReagrupar());
 	pPantallaCompleta->SetBitmap(GinkgoResourcesManager::MenuIcons::GetIcoPantallaCompleta());
-	pGrid2Col->SetBitmap(GinkgoResourcesManager::MenuTabs::GetIcoGrid2Col());
-	pGrid3Col->SetBitmap(GinkgoResourcesManager::MenuTabs::GetIcoGrid3Col());
 #endif
 
 	menu->Append( pPantallaCompleta );
 	menu->AppendSeparator();
 	subMenuPestanias->Append(pMenuMostrarPrimerPlano);
 	subMenuPestanias->AppendSeparator();
-	subMenuPestanias->Append(pMosaicoHorizontal);
-	subMenuPestanias->Append(pMosaicoVertical);
 	menu->AppendSubMenu(subMenuPestanias,_("Tabbed organization"));
-	subMenuGrid->Append(pGrid2Col);
-	subMenuGrid->Append(pGrid3Col);
-	menu->AppendSubMenu(subMenuGrid,_("Grid organization"));
 	menu->AppendSeparator();
 	menu->Append(pMenuCerrarActiva);
 	menu->Append(pMenuCerrarTodas);
