@@ -207,8 +207,6 @@ public:
 	//toggle entre enc
 	void ShowStartUp(bool show);
 	void EncajarDesencajar(GNC::GCS::IVista* pVista);
-	void OnMosaicoHorizontal(wxCommandEvent& event);
-	void OnMosaicoVertical(wxCommandEvent& event);
 	void OnMosaicoRestaurar(wxCommandEvent& event);
 	void ReplegarPestanias();
 
@@ -220,29 +218,6 @@ public:
 	/*evento que se ejecuta cuando se activa la app sirve para parsear los parametros*/
 	void OnInicioAplicacion(wxCommandEvent& event);
 	void EjecutarParametro(const wxString cadena, bool doLogin = false);
-	/* Evento absurdo pero necesario para evitar efectos de "flickering" */
-
-	virtual void OnVentanaPrincipalEraseBackground( wxEraseEvent& event )
-	{
-		event.Skip(false);
-	}
-
-	virtual void OnPanelActualizacionEraseBackground( wxEraseEvent& event )
-	{
-		event.Skip(false);
-	}
-	virtual void OnPanelActualizacionInternoEraseBackground( wxEraseEvent& event )
-	{
-		event.Skip(true);
-	}
-	virtual void OnPanelCentralEraseBackground( wxEraseEvent& event )
-	{
-		event.Skip(false);
-	}
-	virtual void OnNoteBookEraseBackground( wxEraseEvent& event )
-	{
-		event.Skip(false);
-	}
 
 	/* Cambio de tamaño de la ventana */
 	void OnSize(wxSizeEvent& event);
@@ -300,7 +275,7 @@ public:
 //region "Getters y Setters de elementos de la interfaz"
 
 public:
-	AUI_NAMESPACE wxAuiNotebook* GetAUINoteBook();
+	wxAuiNotebook* GetAUINoteBook();
 
 public:
 
