@@ -8,7 +8,8 @@ namespace GNC {
 		////////////////////////////////////////////////////
 		////////////DIALOGO DICOMDIR////////////////////////
 		////////////////////////////////////////////////////
-
+		
+		class DicomDirTableModel;
 		class DialogoDicomDir: public DialogoDicomDirBase
 		{
 		public:
@@ -17,8 +18,13 @@ namespace GNC {
 			~DialogoDicomDir();
 			void OnCopyClick(wxCommandEvent&);
 			void OnLinkClick(wxCommandEvent&);
+			void OnItemActivation(wxDataViewEvent& event);
+			void OnColumnHeaderClick(wxDataViewEvent& event);
+			void OnListChar(wxKeyEvent&event);
 		protected:
 			void Acquire(bool copy);
+
+			wxObjectDataPtr<DicomDirTableModel> m_pDicomDirTableModel;
 		};
 
 		class SelectDrive: public SelectDriveBase
