@@ -22,7 +22,7 @@ namespace GNC {
 	namespace GUI {
 		class FirstLevelPanel: public FirstLevelPanelBase, public INodoHistorial {
 		public:
-			FirstLevelPanel(GNC::GCS::IVista* pView, INodoHistorial* pPadre,  GNC::GUI::IPreviewNode* pNode, bool desplegarNodo = false);
+			FirstLevelPanel(GNC::GCS::IVista* pView, INodoHistorial* pPadre,  GNC::GUI::IPreviewNode* pNode);
 			~FirstLevelPanel();
 
 			wxWindow* GetWxWindow();
@@ -31,15 +31,12 @@ namespace GNC {
 
 		protected:
 			virtual void OnChar(wxKeyEvent &event);
-			void Deploy(bool show = true);
 			virtual void OnPaint(wxPaintEvent& event);
 			virtual void OnSize(wxSizeEvent &event);
 			virtual void OnMouseWheel(wxMouseEvent &event);
-			virtual void OnCabeceraClick(wxMouseEvent &event);
 			virtual void OnEraseBackground( wxEraseEvent& event );
 
 			GNC::GUI::IPreviewNode* m_pNode;
-			bool m_deployed;
 			GNC::GCS::IVista* m_pView;
 		};
 	}
