@@ -72,13 +72,25 @@ namespace GNC {
 			int leafIndex = 0;
 			for (IPreviewNode::TListNodes::iterator it = pNode->children.begin(); it != pNode->children.end(); ++it, ++leafIndex)
 			{
-				IPreviewLeaf* pLeaf = dynamic_cast<IPreviewLeaf*>((*it));
+				IPreviewNode* curNode = (*it);
+				IPreviewLeaf* pLeaf = dynamic_cast<IPreviewLeaf*>(curNode);
 				if (pLeaf != NULL) {
 					LeafPanel* p = new LeafPanel(m_pView, this, pLeaf, leafIndex%2); 
 					m_pPanelPreviews->GetSizer()->Add(p,0,wxBOTTOM|wxEXPAND,0);
 				} else {
-					FirstLevelPanel* pNewLevel = new FirstLevelPanel(m_pView, this, (*it), true);
+					FirstLevelPanel* pNewLevel = new FirstLevelPanel(m_pView, this, curNode);
 					m_pPanelPreviews->GetSizer()->Add(pNewLevel,0,wxBOTTOM|wxEXPAND,0);
+					for (IPreviewNode::TListNodes::iterator itFirstLevel = curNode->children.begin(); itFirstLevel != curNode->children.end(); ++itFirstLevel, ++leafIndex)
+					{
+						IPreviewNode* curNode2 = (*itFirstLevel);
+						IPreviewLeaf* pLeaf = dynamic_cast<IPreviewLeaf*>(curNode2);
+						if (pLeaf != NULL) {
+							LeafPanel* p = new LeafPanel(m_pView, this, pLeaf, leafIndex%2); 
+							m_pPanelPreviews->GetSizer()->Add(p,0,wxBOTTOM|wxEXPAND,0);
+						} else {
+							LOG_ERROR("FirstLevelPanel", "leaf panel isn't an IPreviewLeaf");
+						}				
+					} 
 				}				
 			}
 			Show();
