@@ -127,13 +127,12 @@ namespace GNC {
 
 
 		protected:
-			void ActualizarInterfaz();
-
 			void OnMostrarOcultarDialogoProgreso(wxMouseEvent& event);
 			void OnSize(wxSizeEvent& event);
 			void OnMove(wxMoveEvent& event);
 
 			void OnMensajeUsuario(EventoMensajesUsuarioAsync& event );
+			void OnIdle(wxIdleEvent &WXUNUSED(event));
 
 
 		public:
@@ -145,6 +144,7 @@ namespace GNC {
 			wxGauge* m_pProgresoTarea;
 			wxStaticText* m_pMensajeTarea;
 			wxStaticBitmap* m_pIconoParado;
+			bool m_dirty;
 
 		};
 	}
