@@ -13,6 +13,10 @@
  */
 //#define _GINKGO_TRACE
 
+#if defined(__DEPRECATED)
+#undef __DEPRECATED
+#endif
+
 #include <wx/wx.h>
 #include <wx/menu.h>
 #include <wx/image.h>
@@ -191,30 +195,7 @@ void GNC::WidgetsManager::RenderPrivate(GNC::GCS::Contexto3D* c)
 			(*it)->Render(c);
 		}
 	}
-
-	{
-		GNC::GCS::Vector boundingBox;
-
-		// Tercera pasada: dibujado de overlays
-		for (IteradorListaWidgets it = m_Widgets.begin(); boundingBox.EsNulo() && it != m_Widgets.end(); ++it)
-		{
-			GNC::GCS::Widgets::IWidget* w = (*it);
-			if(!w->EstaOculto() && w->EstaIluminado() && (w->GetVID() == c->GetRenderer()->GetVID()) ){
-				if (m_pRendererActivo != NULL) {
-					m_pRendererActivo->ImprimirOverlay(w, c, boundingBox);
-				}
-			}
-		}
-
-		for (GNC::GCS::ListaBuilders::iterator it = m_pBuilders.begin(); it != m_pBuilders.end(); ++it) {
-			if (!boundingBox.EsNulo()) {
-				if (m_pRendererActivo != NULL) {
-					m_pRendererActivo->ImprimirOverlay(*it, c, boundingBox);
-				}
-			}
-		}
-	}
-
+	
 	//cursor
 	if(widgetIluminado)
 	{
@@ -646,7 +627,14 @@ void GNC::WidgetsManager::PropagarHitTestSeleccion(GNC::GCS::Vector* vertices, i
 
 void GNC::WidgetsManager::SetRendererActivo(GNC::GCS::IWidgetsRenderer* pRenderer)
 {
-	m_pRendererActivo = pRenderer;
+	if (m_pRendererActivo != pRenderer)
+	{
+		if (m_pRendererActivo != NULL)
+		{
+			m_pRendererActivo->Modificar(true);
+		}
+		m_pRendererActivo = pRenderer;
+	}
 }
 
 void GNC::WidgetsManager::InsertarRenderer(GNC::GCS::IWidgetsRenderer* pRenderer)
@@ -820,8 +808,8 @@ void GNC::WidgetsManager::RemoveUserAnnotationWidgets(bool propagateEvents)
 
 void GNC::WidgetsManager::EliminarTodosLosWidgets(bool propagarEventos)
 {
-	for (IteradorListaWidgets it = m_Widgets.begin(); it != m_Widgets.end(); ++it) {
-		GNC::GCS::Widgets::IWidget* w = (*it);
+	while (!m_Widgets.empty()) {
+		GNC::GCS::Widgets::IWidget* w = m_Widgets.front();
 		if (propagarEventos) {
 			NotificarDestruccion(w);
 		}
@@ -834,8 +822,8 @@ void GNC::WidgetsManager::EliminarTodosLosWidgets(bool propagarEventos)
 			}
 		}
 		delete w;
+		m_Widgets.erase(m_Widgets.begin());
 	}
-	m_Widgets.clear();
 }
 
 /** Set visible on all widgets matching TID **/
