@@ -44,6 +44,12 @@ namespace GNC {
 					event.SetText(_("Detach view"));
 				}
 			}
+
+			virtual void OnToolClick(wxCommandEvent &)
+			{
+				m_pCornerTool->doDetach();
+			}
+
 			GNC::DetachWindowTool* m_pCornerTool;
 		};
 
@@ -63,9 +69,15 @@ GNC::DetachWindowTool::~DetachWindowTool()
 }
 		
 bool GNC::DetachWindowTool::ExecuteAction()
+{
+	//if i put it here it will be called twice because of toolsystembar
+	//GNC::Entorno::Instance()->GetVentanaPrincipal()->EncajarDesencajar(ViewContract->GetView());
+	return false;
+}
+
+void GNC::DetachWindowTool::doDetach()
 {
 	GNC::Entorno::Instance()->GetVentanaPrincipal()->EncajarDesencajar(ViewContract->GetView());
-	return true;
 }
 
 void GNC::DetachWindowTool::AppendToolIn(wxEvtHandler* pParent, wxMenu* pMenu)
@@ -101,3 +113,5 @@ bool GNC::DetachWindowTool::IsDetached()
 	}
 	return false;
 }
+
+
