@@ -13,7 +13,8 @@
  */
 #include "imageexporttool.h"
 #include <api/ivista.h>
-#include <export/contracts/iimageexportcontract.h>
+#include <export/contracts/iwidgetscontract.h>
+#include <api/iwidgetsmanager.h>
 #include <main/gui/toolsystem/wxmenuitemtool.h>
 #include <main/gui/export/wxwizardexportacionginkgo.h>
 
@@ -60,16 +61,7 @@ GNC::ImageExportTool::~ImageExportTool()
 		
 bool GNC::ImageExportTool::ExecuteAction()
 {	
-	GNC::GCS::Ptr<GNC::GCS::IImageExportDelegate> pDelegate(ExportContract->GetNewExportDelegate());
-	GNC::GUI::wxWidzardExportacionGinkgo dlg(ExportContract->GetView()->GetWindow(), pDelegate);
-	if (ExportContract->GetView()->GetWindow() != NULL) {
-		//set position relative to view window...
-		wxPoint position = ExportContract->GetView()->GetWindow()->GetPosition();
-		wxPoint screeenPosition = ExportContract->GetView()->GetWindow()->ClientToScreen(position);
-		screeenPosition.x += 20;
-		screeenPosition.y += 20;
-		dlg.SetPosition(screeenPosition);
-	}
+	GNC::GUI::wxWidzardExportacionGinkgo dlg(WidgetsContract->GetManager()->GetVista()->GetWindow(), WidgetsContract);
 	dlg.ShowModal();
 	return true;
 }
@@ -82,7 +74,3 @@ void GNC::ImageExportTool::AppendToolIn(wxEvtHandler* pParent, wxMenu* pMenu)
 	}
 }
 
-bool GNC::ImageExportTool::IsEnabled()
-{
-	return ExportContract->CanBeExported();
-}
