@@ -27,7 +27,8 @@
 #include <widgets/welipse.h>
 #include <widgets/wpunto.h>
 #include <widgets/wtrapezoide.h>
-#include <widgets/wpoligono.h>
+#include <widgets/wfreeform.h>
+#include <widgets/wpolygon.h>
 #include <resources/ginkgoresourcesmanager.h>
 
 
@@ -40,8 +41,9 @@
 #define USAR_FLECHA     1451
 #define USAR_ELIPSE     1452
 #define USAR_TRAPEZOIDE 1453
-#define USAR_POLIGONO   1454
+#define USAR_FREEFORM   1454
 #define USAR_PUNTO      1455
+#define USAR_POLYGON      1456
 
 namespace GNC {
 	namespace GUI {
@@ -56,7 +58,8 @@ namespace GNC {
 				m_pParent->Connect(USAR_FLECHA, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaFlechaClick),NULL,this);
 				m_pParent->Connect(USAR_ELIPSE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaElipseClick),NULL,this);
 				m_pParent->Connect(USAR_TRAPEZOIDE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaTrapezoideClick),NULL,this);
-				m_pParent->Connect(USAR_POLIGONO,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaPoligonoClick),NULL,this);
+				m_pParent->Connect(USAR_FREEFORM,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaFreeFormClick),NULL,this);
+				m_pParent->Connect(USAR_POLYGON,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaPolygonClick),NULL,this);
 			}
 
 			~EventHandlerMarkerTools()
@@ -65,7 +68,8 @@ namespace GNC {
 				m_pParent->Disconnect(USAR_FLECHA, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaFlechaClick),NULL,this);
 				m_pParent->Disconnect(USAR_ELIPSE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaElipseClick),NULL,this);
 				m_pParent->Disconnect(USAR_TRAPEZOIDE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaTrapezoideClick),NULL,this);
-				m_pParent->Disconnect(USAR_POLIGONO,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaPoligonoClick),NULL,this);
+				m_pParent->Disconnect(USAR_FREEFORM,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaFreeFormClick),NULL,this);
+				m_pParent->Disconnect(USAR_POLYGON,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( EventHandlerMarkerTools::OnHerramientaPolygonClick),NULL,this);
 				m_pParent = NULL;
 				m_pHerramienta = NULL;
 			}
@@ -90,10 +94,15 @@ namespace GNC {
 				event.Skip(false);
 			}
 
-			virtual void OnHerramientaPoligonoClick( wxCommandEvent& event ){
-				m_pHerramienta->SetTipoMarcado(GNC::MarkerTool::TW_Poligono);
+			virtual void OnHerramientaFreeFormClick( wxCommandEvent& event ){
+				m_pHerramienta->SetTipoMarcado(GNC::MarkerTool::TW_FreeForm);
 				event.Skip(false);
-			}			
+			}	
+
+			virtual void OnHerramientaPolygonClick( wxCommandEvent& event ){
+				m_pHerramienta->SetTipoMarcado(GNC::MarkerTool::TW_Polygon);
+				event.Skip(false);
+			}	
 
 			GNC::MarkerTool* m_pHerramienta;
 			wxEvtHandler* m_pParent;
@@ -163,7 +172,8 @@ void GNC::MarkerTool::AppendDropDownMenu(wxEvtHandler* pParent, wxMenu* pMenu)
 	pMenu->Append(new GNC::GUI::wxMenuItemTool(pMenu,USAR_FLECHA,_("Arrow"), GinkgoResourcesManager::MarkingBar::GetIcoFlecha(),new GNC::GUI::EventHandlerMarkerTools(pParent, this)));
 	pMenu->Append(new GNC::GUI::wxMenuItemTool(pMenu,USAR_ELIPSE,_("Ellipse"), GinkgoResourcesManager::MarkingBar::GetIcoElipse(), new GNC::GUI::EventHandlerMarkerTools(pParent, this)));
 	pMenu->Append(new GNC::GUI::wxMenuItemTool(pMenu,USAR_TRAPEZOIDE,_("Trapezoid"), GinkgoResourcesManager::MarkingBar::GetIcoTrapezoide(), new GNC::GUI::EventHandlerMarkerTools(pParent, this)));
-	pMenu->Append(new GNC::GUI::wxMenuItemTool(pMenu,USAR_POLIGONO,_("Polygon"), GinkgoResourcesManager::MarkingBar::GetIcoPoligono(), new GNC::GUI::EventHandlerMarkerTools(pParent, this)));
+	pMenu->Append(new GNC::GUI::wxMenuItemTool(pMenu,USAR_POLYGON,_("Polygon"), GinkgoResourcesManager::MarkingBar::GetIcoPoligono(), new GNC::GUI::EventHandlerMarkerTools(pParent, this)));
+	pMenu->Append(new GNC::GUI::wxMenuItemTool(pMenu,USAR_FREEFORM,_("Free form"), GinkgoResourcesManager::MarkingBar::GetIcoFreeForm(), new GNC::GUI::EventHandlerMarkerTools(pParent, this)));
 }
 
 
@@ -192,9 +202,9 @@ void GNC::MarkerTool::SetTipoMarcado(TipoMarcado tipo)
 				m_pBuilder = new GNC::GCS::Widgets::WTrapezoideBuilder(WidgetsContract->GetManager(), GetTriggerButton(), (unsigned long)this);
 				icon = GinkgoResourcesManager::MarkingBar::GetIcoTrapezoide();
 				break;
-			case TW_Poligono:
-				m_pBuilder = new GNC::GCS::Widgets::WPoligonoBuilder(GNC::GCS::Widgets::MP_Normal, WidgetsContract->GetManager(), GetTriggerButton());
-				icon = GinkgoResourcesManager::MarkingBar::GetIcoPoligono();
+			case TW_FreeForm:
+				m_pBuilder = new GNC::GCS::Widgets::WFreeFormBuilder(WidgetsContract->GetManager(), GetTriggerButton());
+				icon = GinkgoResourcesManager::MarkingBar::GetIcoFreeForm();
 				break;
 			case TW_Punto:
 				{
@@ -202,6 +212,12 @@ void GNC::MarkerTool::SetTipoMarcado(TipoMarcado tipo)
 					icon = GinkgoResourcesManager::MarkingBar::GetIcoPunto();
 				}
 				break;
+			case TW_Polygon:
+				{
+					m_pBuilder = new GNC::GCS::Widgets::WPolygonBuilder(WidgetsContract->GetManager(), GetTriggerButton());
+					icon = GinkgoResourcesManager::MarkingBar::GetIcoPoligono();
+				}
+				break;
 			default:
 				std::cerr << "Error, Elemento de marcado no soportado." << std::endl;
 				break;
