@@ -36,7 +36,8 @@ namespace GNC {
 			TW_Elipse,
 			TW_Punto,
 			TW_Trapezoide,
-			TW_Poligono
+			TW_FreeForm,
+			TW_Polygon
 		} TipoMarcado;
 
 		MarkerTool();
