@@ -4,7 +4,7 @@
  *  $Id: openfiletool.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -19,7 +19,7 @@ namespace GNC {
 
 	class OpenGinkgoCloudLinkTool : public GNC::GCS::IHistoryTool {
 	public:
-		static const GNC::GCS::IHistoryTool::UID ID =  HCore_OpenGinkgoCloudLink;
+		static const GNC::GCS::IHistoryTool::UID ID =  HCore_OpenGinkgoCloudLinkHistory;
 		OpenGinkgoCloudLinkTool();
 		virtual ~OpenGinkgoCloudLinkTool();
 		virtual bool Enabled();
