@@ -53,11 +53,16 @@ namespace GNC {
 
 			virtual void OnUpdateUI(wxUpdateUIEvent &event)
 			{
-				wxDefaultEvtHandlerTool::OnUpdateUI(event);
-				if(m_pPixelsBluringTool->IsSet()) {
-					event.SetText(_("Unset pixels blurring"));
+				if (m_pPixelsBluringTool->IsEnabled()) {
+					wxDefaultEvtHandlerTool::OnUpdateUI(event);
+					if(m_pPixelsBluringTool->IsSet()) {
+						event.SetText(_("Unset pixels blurring"));
+					} else {
+						event.SetText(_("Set pixels blurring"));
+					}
+					event.Enable(true);
 				} else {
-					event.SetText(_("Set pixels blurring"));
+					event.Enable(false);
 				}
 			}
 			GNC::PixelsBluringTool* m_pPixelsBluringTool;
@@ -112,6 +117,15 @@ void GNC::PixelsBluringTool::AppendToolIn(wxEvtHandler* pParent, wxMenu* pMenu)
 
 bool GNC::PixelsBluringTool::IsSet()
 {
-	return PixelsBluringContract->GetViewerActivo()->GetInterpolationMode() == VTK_LINEAR_INTERPOLATION;
+	if (PixelsBluringContract->GetViewerActivo() != NULL) {
+		return PixelsBluringContract->GetViewerActivo()->GetInterpolationMode() == VTK_LINEAR_INTERPOLATION;
+	} else {
+		return NULL;
+	}
+}
+
+bool GNC::PixelsBluringTool::IsEnabled()
+{
+	return PixelsBluringContract->GetViewerActivo() != NULL;
 }
 #endif
