@@ -21,11 +21,10 @@
 #include <api/api.h>
 
 namespace GNC {
+	class wxToolSliderKeyHandler;
 
 	class EXTAPI ToolSlider : public GNC::GCS::IToolSlider {
 	public:
-		typedef GNC::GCS::Events::EventoRaton       TEventoRaton;
-		typedef GNC::GCS::Events::EventoTeclado     TEventoTeclado;
 		typedef GNC::GCS::Widgets::WSliderBuilder      TBuilder;
 		ToolSlider();
 		~ToolSlider();
@@ -33,9 +32,14 @@ namespace GNC {
 		virtual GNC::GCS::ITool* NewTool();
 		virtual void Connect();
 		virtual void Disconnect();
+
+		virtual void ConnectKeyEvents(wxWindow* pWindow);
+
 	protected:
+		friend class wxToolSliderKeyHandler;
 
 		TBuilder*            m_pBuilder;
+		wxToolSliderKeyHandler* m_pHandler;
 	};
 }
 #endif
