@@ -21,7 +21,7 @@
 #include <widgets/wzoom.h>
 
 namespace GNC {
-
+	class wxToolZoomKeyHandler;
 	class EXTAPI ToolZoom : public GNC::GCS::IToolZoom {
 	public:
 		typedef GNC::GCS::Events::EventoRaton       TEventoRaton;
@@ -37,10 +37,12 @@ namespace GNC {
 		virtual void AppendDropDownMenu(wxEvtHandler* pParent, wxMenu* pMenu);
 
 		virtual void ZoomOneOne();
+		virtual void ConnectKeyEvents(wxWindow* pWindow);
 
 	protected:
-
+		friend class wxToolZoomKeyHandler;
 		TBuilder*            m_pBuilder;
+		wxToolZoomKeyHandler* m_pHandler;
 	};
 }
 #endif
