@@ -4,7 +4,7 @@
  *  $Id: toolpan.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -18,10 +18,18 @@
 #define TRACKBALLTOOL_H
 
 #include <export/tools/itrackballtool.h>
-#include <widgets/wtrackball.h>
 #include <api/api.h>
 
 namespace GNC {
+	namespace GCS {
+		namespace Widgets {
+			class WTrackballBuilder;
+		}
+		namespace Events {
+			class EventoRaton;
+			class EventoTeclado;
+		}
+	}
 
 	class EXTAPI TrackballTool : public GNC::GCS::ITrackballTool {
 	public:
