@@ -19,6 +19,7 @@
 #include <api/toolsystem/iwidgettool.h>
 #include <api/toolsystem/itoolsregistry.h>
 #include <api/controllers/icontroladorlog.h>
+#include <api/controllers/iconfigurationcontroller.h>
 #include <api/controllers/ieventscontroller.h>
 #include <eventos/toolevents.h>
 #include <api/icontract.h>
@@ -29,6 +30,10 @@
 #include <wx/menu.h>
 #include <wx/wxginkgotoolbar.h>
 
+#define LEFT_BUTTON_CONF_KEY   "lbt"
+#define MIDDLE_BUTTON_CONF_KEY "mbt"
+#define RIGHT_BUTTON_CONF_KEY  "rbt"
+
 namespace GNC {
 	namespace GUI {
 		const wxEventType wxEVT_ACTIVATE_TOOL_ASYNC = wxNewEventType();
@@ -129,11 +134,8 @@ namespace GNC {
 	}
 }
 
-GNC::ToolController::ToolController(): EventHandler(new GNC::GUI::wxEventHandlerToolController(this))
-{
-	m_leftTool = NULL;
-	m_rightTool = NULL;
-
+GNC::ToolController::ToolController(): EventHandler(new GNC::GUI::wxEventHandlerToolController(this)), m_leftTool(NULL), m_rightTool(NULL), m_middleTool(NULL)
+{	
 }
 
 GNC::ToolController::~ToolController()
@@ -148,19 +150,36 @@ GNC::ToolController::~ToolController()
 
 void GNC::ToolController::InitializeToolController()
 {
-	//set first tool of visualizator family
+
+	// By default, try to select:
+	// * The first visualization tool available => to left button,
+	// * The next visualiation tool available after left button assignation => to right button
+	// * The next visualiation tool available after rifht button assignation => to middle button
 	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
 	{
-		GNC::GCS::IWidgetTool* pWidgetTool = dynamic_cast<GNC::GCS::IWidgetTool*> ((*it).second);
-		if (pWidgetTool != NULL && pWidgetTool->FamilyId == GNC::GCS::ITool::TFamiliaVisualizacion && pWidgetTool->IsReady()) {
-			if (m_leftTool == NULL) {
+		GNC::GCS::ITool* pWidgetTool = dynamic_cast<GNC::GCS::ITool*> ((*it).second);
+		if (pWidgetTool != NULL && pWidgetTool->FamilyId == GNC::GCS::ITool::TFamiliaVisualizacion && pWidgetTool->IsReady())
+		{
+			if (m_leftTool == NULL)
+			{
 				GNC::GCS::TriggerButton buttonMask;
 				buttonMask.EnableLeft();
 				DoActivateTool(pWidgetTool->ID, buttonMask, NULL);
-			} else if (m_rightTool == NULL) {
+			}
+			else if (m_rightTool == NULL)
+			{
 				GNC::GCS::TriggerButton buttonMask;
 				buttonMask.EnableRight();
 				DoActivateTool(pWidgetTool->ID, buttonMask, NULL);
+			}
+			else if (m_middleTool == NULL)
+			{
+				GNC::GCS::TriggerButton buttonMask;
+				buttonMask.EnableMiddle();
+				DoActivateTool(pWidgetTool->ID, buttonMask, NULL);
+			}
+			else
+			{
 				break;
 			}
 		}
@@ -180,6 +199,12 @@ void GNC::ToolController::FinalizeToolController()
 		m_rightTool->Disconnect();
 		GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(false, m_rightTool, this));
 	}
+
+	if (m_middleTool != NULL) {
+		m_middleTool->GetTriggerButton().DisableMiddle();
+		m_middleTool->Disconnect();
+		GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(false, m_middleTool, this));
+	}
 }
 
 void GNC::ToolController::ReconnectToolController()
@@ -190,13 +215,71 @@ void GNC::ToolController::ReconnectToolController()
 	if (m_rightTool != NULL) {
 		m_rightTool->Disconnect();
 	}
+	if (m_middleTool != NULL) {
+		m_middleTool->Disconnect();
+	}
+
 	if(m_leftTool != NULL && m_leftTool->IsEnabled()) {
 		m_leftTool->Connect();
 	}
-
 	if (m_rightTool != NULL && m_rightTool->IsEnabled() && m_rightTool != m_leftTool) {
 		m_rightTool->Connect();
 	}
+	if (m_middleTool != NULL && m_middleTool->IsEnabled() && m_middleTool != m_leftTool && m_middleTool != m_rightTool) {
+		m_middleTool->Connect();
+	}
+}
+
+void GNC::ToolController::LoadStatus(const std::string& view, const std::string& modality) {
+	
+	if ( view.empty() || modality.empty() ) {
+		return;
+	}
+
+	int selectedLeftToolId = -1;
+	int selectedMiddleToolId = -1;
+	int selectedRightToolId = -1;
+
+	std::string scope(GetToolStatusScope(view, modality));
+
+	GNC::GCS::IConfigurationController::Instance()->readIntUser(scope, LEFT_BUTTON_CONF_KEY, selectedLeftToolId, -1);
+	GNC::GCS::IConfigurationController::Instance()->readIntUser(scope, MIDDLE_BUTTON_CONF_KEY, selectedMiddleToolId, -1);
+	GNC::GCS::IConfigurationController::Instance()->readIntUser(scope, RIGHT_BUTTON_CONF_KEY, selectedRightToolId, -1);
+
+	if (selectedLeftToolId != -1) {
+		GNC::GCS::TriggerButton buttonMask;
+		buttonMask.EnableLeft();
+		DoActivateTool(selectedLeftToolId, buttonMask, NULL);
+	}
+	if (selectedMiddleToolId != -1) {
+		GNC::GCS::TriggerButton buttonMask;
+		buttonMask.EnableMiddle();
+		DoActivateTool(selectedMiddleToolId, buttonMask, NULL);
+	}
+	if (selectedRightToolId != -1) {
+		GNC::GCS::TriggerButton buttonMask;
+		buttonMask.EnableRight();
+		DoActivateTool(selectedRightToolId, buttonMask, NULL);
+	}
+}
+
+void GNC::ToolController::SaveStatus(const std::string& view, const std::string& modality) {
+
+	if ( view.empty() || modality.empty() ) {
+		return;
+	}
+
+	std::string scope(GetToolStatusScope(view, modality));
+
+	if (m_leftTool != NULL) {
+		GNC::GCS::IConfigurationController::Instance()->writeIntUser(scope, LEFT_BUTTON_CONF_KEY, m_leftTool->ID);
+	}
+	if (m_middleTool != NULL) {
+		GNC::GCS::IConfigurationController::Instance()->writeIntUser(scope, MIDDLE_BUTTON_CONF_KEY, m_middleTool->ID);
+	}
+	if (m_rightTool != NULL) {
+		GNC::GCS::IConfigurationController::Instance()->writeIntUser(scope, RIGHT_BUTTON_CONF_KEY, m_rightTool->ID);
+	}
 }
 
 void GNC::ToolController::AddTool(long idTool, GNC::GCS::IContract* pContract)
@@ -261,9 +344,7 @@ wxWindow* GNC::ToolController::CreateNewToolBar(wxWindow* pParent, const GNC::GC
 	if (!alignLeft) {
 		pToolController->AddStretchSpacer(1);
 	}
-
-	AppendsToolsInToolBar(pToolController, toolsToInclude);
-	
+	AppendsToolsInToolBar(pToolController, toolsToInclude);	
 	pToolController->Realize();
 	return pToolController;
 }
@@ -366,6 +447,9 @@ void GNC::ToolController::OnKeyAccelerator(GNC::GCS::Events::EventoTeclado& even
 			GNC::GCS::ITool*& pTool = (*it).second;
 			if (pTool->IsEnabled() && pTool->GetKeyCode() == evento.GetKeyCode()) {
 				GNC::GCS::TriggerButton buttonMask;
+				if (evento.ShiftDown() && evento.AltDown() ) {
+					buttonMask.EnableMiddle();
+				}
 				if (evento.ShiftDown()) {
 					buttonMask.EnableRight();
 				}
@@ -418,12 +502,16 @@ void GNC::ToolController::DoActivateTool(long idTool, const GNC::GCS::TriggerBut
 			m_leftTool->Disconnect();
 			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(false, m_leftTool, this));
 		}
-
 		if (m_rightTool != NULL) {
 			m_rightTool->GetTriggerButton().DisableRight();
 			m_rightTool->Disconnect();
 			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(false, m_rightTool, this));
 		}
+		if (m_middleTool != NULL) {
+			m_middleTool->GetTriggerButton().DisableMiddle();
+			m_middleTool->Disconnect();
+			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(false, m_middleTool, this));
+		}
 
 		if ( buttonMask.IsLeftEnabled() && !pWidgetTool->GetTriggerButton().IsLeftEnabled()) {
 			m_leftTool = pWidgetTool;
@@ -431,23 +519,32 @@ void GNC::ToolController::DoActivateTool(long idTool, const GNC::GCS::TriggerBut
 		if ( buttonMask.IsRightEnabled() && !pWidgetTool->GetTriggerButton().IsRightEnabled()) {
 			m_rightTool = pWidgetTool;
 		}
+		if ( buttonMask.IsMiddleEnabled() && !pWidgetTool->GetTriggerButton().IsMiddleEnabled()) {
+			m_middleTool = pWidgetTool;
+		}
 
 		if (m_leftTool != NULL) {
 			m_leftTool->GetTriggerButton().EnableLeft();
 		}
 		if (m_rightTool != NULL) {
 			m_rightTool->GetTriggerButton().EnableRight();
-		}		
+		}
+		if (m_middleTool != NULL) {
+			m_middleTool->GetTriggerButton().EnableMiddle();
+		}
 
 		if(m_leftTool != NULL && m_leftTool->IsEnabled()) {
 			m_leftTool->Connect();
 			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(true, m_leftTool, this));
 		}
-
 		if (m_rightTool != NULL && m_rightTool->IsEnabled() && m_rightTool != m_leftTool) {
 			m_rightTool->Connect();
 			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(true, m_rightTool, this));
 		}
+		if (m_middleTool != NULL && m_middleTool->IsEnabled() && m_middleTool != m_leftTool && m_middleTool != m_rightTool) {
+			m_middleTool->Connect();
+			GNC::GCS::IEventsController::Instance()->ProcesarEvento(new GNC::GCS::Events::ToolConnectedEvent(true, m_middleTool, this));
+		}
 	}
 }
 
@@ -481,3 +578,14 @@ GNC::GCS::IWidgetTool* GNC::ToolController::GetRightTool()
 {
 	return m_rightTool;
 }
+
+GNC::GCS::IWidgetTool* GNC::ToolController::GetMiddleTool()
+{
+	return m_middleTool;
+}
+
+std::string GNC::ToolController::GetToolStatusScope(const std::string& view, const std::string& modality) {
+	std::ostringstream os;
+	os << "/TooBarStatus/" << view << "/" << modality;
+	return os.str();
+}
\ No newline at end of file
