@@ -152,6 +152,11 @@ wxBitmap GinkgoResourcesManager::MarkingBar::GetIcoPoligono() {
 	LoadPNG(bmp, MarkingBarDir, wxT("ico_poligono_marcado.png"));
 	return bmp;
 }
+wxBitmap GinkgoResourcesManager::MarkingBar::GetIcoFreeForm() {
+	wxBitmap bmp;
+	LoadPNG(bmp, MarkingBarDir, wxT("ico_free_form.png"));
+	return bmp;
+}
 wxBitmap GinkgoResourcesManager::MarkingBar::GetIcoPunto() {
 	wxBitmap bmp;
 	LoadPNG(bmp, MarkingBarDir, wxT("ico_punto_marcado.png"));
