@@ -116,10 +116,11 @@ public:
 
 	~stConnection() {}
 
-	bool OnExecute(const wxString& /*topic*/, wxChar*data, int /*size*/,
-		wxIPCFormat /*format*/)
-	{
-		wxString filename(data);
+	virtual bool OnExec(const wxString& WXUNUSED(topic),
+                      const wxString& data)
+  {
+
+	  wxString filename(data);
 		LOG_INFO("Core", "Servidor, OnExecute "<< filename.ToUTF8());
 		if (filename.IsEmpty())
 		{
@@ -137,7 +138,7 @@ public:
 			GinkgoDispatcher::Instance()->InsertarPeticion(std::string(TOPATH(filename)));
 		}
 		return true;
-	}
+  }
 };
 
 class stServer: public wxServer
