@@ -563,7 +563,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 					scalars->GetRange(range);
 					double diff = range[1] - range[0];
 
-
+					vptr = (unsigned char*) scalars->GetVoidPointer(0);
 					unsigned char *dst = pResampledPixelData;
 
 					switch (scalars->GetDataType()) {
@@ -1333,7 +1333,8 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 			}
 												
 		}
-		else { // Parameters for LUT shader
+		else if (LookupTable != NULL) 
+		{ // Parameters for LUT shader
 
 			// === lookupTable ===
 			loc = vtkgl::GetUniformLocation(this->ProgramObject,"lookuptable");
