@@ -28,9 +28,6 @@ GNC::GCS::Widgets::Dialogos::SeleccionTexto::SeleccionTexto(wxWindow* parent, TW
 	m_pManager = pManager;
 	m_pControlTexto->SetValue(wxString::FromUTF8(m_pWidget->m_Texto.c_str()));
 	m_pControlTexto->SetSelection(-1,-1);
-	m_pColorPicker->SetColour( wxColour( (unsigned char) (pWidget->m_Color.B8()), (unsigned char) (pWidget->m_Color.G8()), (unsigned char) (pWidget->m_Color.R8()) ) );
-	IniciarColores();
-
 }
 
 GNC::GCS::Widgets::Dialogos::SeleccionTexto::~SeleccionTexto()
@@ -85,53 +82,19 @@ void GNC::GCS::Widgets::Dialogos::SeleccionTexto::OnBotonAceptarClick( wxCommand
 	Close();
 }
 
-void GNC::GCS::Widgets::Dialogos::SeleccionTexto::OnColorCambiado(wxColourPickerEvent& /*event*/)
-{
-	Actualizar(false);
-}
-
 void GNC::GCS::Widgets::Dialogos::SeleccionTexto::OnActivar(wxActivateEvent &/*event*/)
 {
 	m_pControlTexto->SetFocus();
 }
 
-void GNC::GCS::Widgets::Dialogos::SeleccionTexto::IniciarColores()
-{
-	const GNC::GCS::Widgets::Color& colorWidget = m_pWidget->GetColor();
-	const GNC::GCS::Widgets::Color colorFondo = colorWidget.Inverso();
-
-	wxColour wColorFondo (colorFondo.R8(), colorFondo.G8(), colorFondo.B8());
-	wxColour wColorTexto (colorWidget.B8(), colorWidget.G8(), colorWidget.R8());
-
-	m_pColorPicker->SetColour(wColorTexto);
-
-	m_pControlTexto->SetForegroundColour(wColorTexto);
-	m_pControlTexto->SetBackgroundColour(wColorFondo);
-}
-
 void GNC::GCS::Widgets::Dialogos::SeleccionTexto::Actualizar(bool actualizarWidget)
 {
-	wxColour wColorFondo;
-	wxColour wColorTexto = m_pColorPicker->GetColour();
 
-	GNC::GCS::Widgets::Color colorTexto(wColorTexto.Blue(), wColorTexto.Green(), wColorTexto.Red());
-	GNC::GCS::Widgets::Color ctmp = GNC::GCS::Widgets::Color(colorTexto).Invertir();
-
-	wColorFondo.Set(ctmp.B8(), ctmp.G8(), ctmp.R8());
-
-	m_pControlTexto->SetForegroundColour(wColorTexto);
-	m_pControlTexto->SetBackgroundColour(wColorFondo);
-	m_pControlTexto->Refresh();
 
 	if (actualizarWidget) {
 
 		bool modifica = false;
 
-		if (colorTexto != m_pWidget->GetColor()) {
-			m_pWidget->SetColor(colorTexto);
-			modifica = true;
-		}
-
 		std::string textoControl(m_pControlTexto->GetValue().ToUTF8());
 
 		if (m_pWidget->GetTexto() != textoControl) {
