@@ -13,7 +13,7 @@
  */
 #pragma once
 #include "selecciontextobase.h"
-#include "../wnota.h"
+#include "../wtextbox.h"
 
 namespace GNC {
 	namespace GCS {
@@ -21,7 +21,7 @@ namespace GNC {
 			namespace Dialogos {
 				class SeleccionTexto : public SeleccionTextoBase {
 				public:
-					typedef GNC::GCS::Widgets::WCajaTexto TWidget;
+					typedef GNC::GCS::Widgets::WTextBox TWidget;
 					typedef GNC::GCS::IWidgetsManager TManager;
 
 					SeleccionTexto(wxWindow* parent, TWidget* pWidget, TManager* pManager);
@@ -41,18 +41,12 @@ namespace GNC {
 
 					virtual void OnBotonAceptarClick( wxCommandEvent& event );
 
-					virtual void OnColorCambiado(wxColourPickerEvent& event);
-
 					virtual void OnActivar(wxActivateEvent &event);
 
-					void IniciarColores();
-
 					void Actualizar(bool actualizarWidget = true);
 
 					TWidget*   m_pWidget;
 					TManager*  m_pManager;
-
-					wxColour    m_ColorFondo; // Color del fondo del campo de texto. Se cambia automaticamente a fin de leerlo correctamente.
 				};
 			}
 		}
