@@ -15,6 +15,7 @@
 #include <api/globals.h>
 #include <api/helpers/helpertexto.h>
 #include <api/westilo.h>
+#include <api/controllers/icontroladorlog.h>
 #include "openglhelper.h"
 #include <sstream>
 #include <string>
@@ -519,13 +520,35 @@ inline unsigned int GNC::GCS::TexturaCairo::NearestPOT(unsigned int size)
 void GNC::GCS::TexturaCairo::SetFontNormal(const std::string& fontname, float tamFuente)
 {
 	cairo_font_options_t* options;
-	cairo_select_font_face (cr, fontname.c_str(), CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
-	cairo_set_font_size(cr, tamFuente);
-	options = cairo_font_options_create ();
-	cairo_get_font_options(cr, options);
-	cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
-	cairo_set_font_options(cr, options);
-	cairo_font_options_destroy(options);
+	if (cr != NULL) {
+		cairo_select_font_face (cr, fontname.c_str(), CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
+		cairo_set_font_size(cr, tamFuente);
+		options = cairo_font_options_create ();
+		cairo_get_font_options(cr, options);
+		cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
+		cairo_set_font_options(cr, options);
+		cairo_font_options_destroy(options);
+	}
+	else {
+		LOG_WARN("Core/RenderAPI", "Unable to set font. Context not created yet");
+	}
+}
+
+void GNC::GCS::TexturaCairo::SetFontBold(const std::string& fontname, float tamFuente)
+{
+	cairo_font_options_t* options;
+	if (cr != NULL) {
+		cairo_select_font_face (cr, fontname.c_str(), CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
+		cairo_set_font_size(cr, tamFuente);
+		options = cairo_font_options_create ();
+		cairo_get_font_options(cr, options);
+		cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
+		cairo_set_font_options(cr, options);
+		cairo_font_options_destroy(options);
+	}
+	else {
+		LOG_WARN("Core/RenderAPI","Unable to set font. Context not created yet");
+	}
 }
 
 void GNC::GCS::TexturaCairo::SetSourceColor(float b, float g, float r, float a)
@@ -536,24 +559,24 @@ void GNC::GCS::TexturaCairo::SetSourceColor(float b, float g, float r, float a)
 //--------------------------------------------------------------------------------------------
 
 
-GNC::GCS::GLHelper::TVector GNC::GCS::GLHelper::calcularBoundingBox(TTextura& tc, const std::string& texto, float anchoMaximo, TAlineamiento alineamiento)
+GNC::GCS::GLHelper::TVector GNC::GCS::GLHelper::calcularBoundingBox(TTextura& tc, const std::string& texto, bool withShadow, float anchoMaximo, TAlineamiento alineamiento)
 {
 	if (!tc.contextoCreado) {
 		tc.Redimensionar(2, 2);
 	}
-	return GNC::GCS::Widgets::HelperTexto::procesarTexto(tc.cr, texto, NULL, anchoMaximo, alineamiento, false);
+	return GNC::GCS::Widgets::HelperTexto::procesarTexto(tc.cr, texto, NULL, withShadow, anchoMaximo, alineamiento, false);
 }
 
-GNC::GCS::GLHelper::TVector GNC::GCS::GLHelper::dibujarTexto(TTextura& tc, const std::string& texto, float anchoMaximo, TAlineamiento alineamiento)
+GNC::GCS::GLHelper::TVector GNC::GCS::GLHelper::dibujarTexto(TTextura& tc, const std::string& texto, bool withShadow, float anchoMaximo, TAlineamiento alineamiento)
 {
 	tc.texturaModificada = true;
-	return GNC::GCS::Widgets::HelperTexto::procesarTexto(tc.cr, texto, NULL, anchoMaximo, alineamiento, true);
+	return GNC::GCS::Widgets::HelperTexto::procesarTexto(tc.cr, texto, NULL, withShadow, anchoMaximo, alineamiento, true);
 }
 
-GNC::GCS::GLHelper::TVector GNC::GCS::GLHelper::dibujarTexto(TTextura& tc, const std::string& texto, const TColor& c, float anchoMaximo, TAlineamiento alineamiento)
+GNC::GCS::GLHelper::TVector GNC::GCS::GLHelper::dibujarTexto(TTextura& tc, const std::string& texto, const TColor& c, bool withShadow, float anchoMaximo, TAlineamiento alineamiento)
 {
 	tc.texturaModificada = true;
-	return GNC::GCS::Widgets::HelperTexto::procesarTexto(tc.cr, texto, &c, anchoMaximo, alineamiento, true);
+	return GNC::GCS::Widgets::HelperTexto::procesarTexto(tc.cr, texto, &c, withShadow, anchoMaximo, alineamiento, true);
 }
 
 //--------------------------------------------------------------------------------------------
