@@ -113,6 +113,7 @@ namespace GNC
 			inline unsigned int NearestPOT(unsigned int size);
 
 			void SetFontNormal(const std::string& fontname, float tamFuente);
+			void SetFontBold(const std::string& fontname, float tamFuente);
 
 			void SetSourceColor(float b, float g, float r, float a);
 
@@ -127,13 +128,13 @@ namespace GNC
 			typedef GNC::GCS::Widgets::HelperTexto::TAlineamiento TAlineamiento;
 
 			/* Calcula el bounding box del texto sobre cairo para la fuente seleccionada. Realiza word-wrapping. */
-			static TVector calcularBoundingBox(TTextura& tc, const std::string& text, float anchoMaximo = -1, TAlineamiento alineamiento = GNC::GCS::Widgets::HelperTexto::TA_Izquierda);
+			static TVector calcularBoundingBox(TTextura& tc, const std::string& text, bool withShadow, float anchoMaximo = -1.0f, TAlineamiento alineamiento = GNC::GCS::Widgets::HelperTexto::TA_Izquierda);
 
 			/* Dibuja el texto en el contexto cairo con fuente seleccionada. Realiza word-wrapping. */
-			static TVector dibujarTexto(TTextura& tc, const std::string& texto, float anchoMaximo = -1, TAlineamiento alineamiento = GNC::GCS::Widgets::HelperTexto::TA_Izquierda);
+			static TVector dibujarTexto(TTextura& tc, const std::string& texto, bool withShadow, float anchoMaximo = -1.0f, TAlineamiento alineamiento = GNC::GCS::Widgets::HelperTexto::TA_Izquierda);
 
 			/* Dibuja el texto en el contexto cairo con fuente seleccionada y color especificado. Realiza word-wrapping. */
-			static TVector dibujarTexto(TTextura& tc, const std::string& texto, const TColor& c, float anchoMaximo = -1, TAlineamiento alineamiento = GNC::GCS::Widgets::HelperTexto::TA_Izquierda);
+			static TVector dibujarTexto(TTextura& tc, const std::string& texto, const TColor& c, bool withShadow, float anchoMaximo = -1.0f, TAlineamiento alineamiento = GNC::GCS::Widgets::HelperTexto::TA_Izquierda);
 		};
 	}
 }
