@@ -48,13 +48,12 @@ namespace GNC
 
 				void Render(const std::string& text, const GNC::GCS::Vector& renderPosition, bool leftAlign = true);
 
-				void Update(const std::string& strip, const GNC::GCS::Widgets::Color& color, double fontSize);
+				void Update(const std::string& strip, const GNC::GCS::Widgets::Color& color, double fontSize, bool drawShadow);
 
 				double GetTextHeigh();
 
 				void Destroy();
 
-
 				std::map<char, StripDescription> m_CharMap;
 				_cairo_font_options* m_pFontOptions;
 				double m_textHeigh;
