@@ -20,6 +20,7 @@
 #include <api/math/geometry3d.h>
 #include <api/internationalization/internationalization.h>
 #include "wangulo.h"
+#include "wtextbox.h"
 #include <api/ievento.h>
 #include <api/icontexto.h>
 #include <api/iwidgetsrenderer.h>
@@ -30,7 +31,6 @@
 #include "openglhelper.h"
 #include <wx/xml/xml.h>
 
-
 //region "Implementacion de WAnguloBuilder"
 
 GNC::GCS::Widgets::WAnguloBuilder::WAnguloBuilder(GNC::GCS::IWidgetsManager* pManager, const GNC::GCS::TriggerButton& buttonMask) :
@@ -81,7 +81,7 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 					else {
 						m_pAnguloTemp->m_Nodos[2] = evento.iP;
 						m_NodoActual = 2;
-						m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+						m_pAnguloTemp->Recalcular(evento.c->GetRenderer(), true);
 						ConsumirEvento();
 					}
 				} else {
@@ -93,7 +93,7 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 						m_pAnguloTemp = NULL;
 					}
 					else {
-						m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+						m_pAnguloTemp->Recalcular(evento.c->GetRenderer(), true);
 						m_pManager->InsertarWidget(m_pAnguloTemp);
 						LanzarEventoCreacion(m_pAnguloTemp);
 						m_pAnguloTemp = NULL;
@@ -104,7 +104,7 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 				}
 			} else { // Angulo de Cobb
 				m_pAnguloTemp->m_Nodos[m_NodoActual] = evento.iP;
-				m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+				m_pAnguloTemp->Recalcular(evento.c->GetRenderer(), true);
 				if (m_NodoActual == 1) {
 					if ( (m_pAnguloTemp->m_Nodos[1] - m_pAnguloTemp->m_Nodos[0]).Norma2Cuadrado() < GNC::GCS::Vector::EpsilonDeReales() ) {
 						m_NodoActual = 0;
@@ -125,6 +125,7 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 					}
 					else {
 						m_pManager->InsertarWidget(m_pAnguloTemp);
+						
 						m_pManager->LanzarEventoCreacion(m_pAnguloTemp);
 						m_pAnguloTemp = NULL;
 						m_Estado = WBS_Ninguno;
@@ -142,9 +143,12 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 				if (m_pAnguloTemp != NULL) {
 					delete m_pAnguloTemp;
 				}
-				m_pAnguloTemp = new GNC::GCS::Widgets::WAngulo(m_pManager, evento.c->GetRenderer()->GetVID(), m_Modo,"Ángulo");
+				m_pAnguloTemp = new GNC::GCS::Widgets::WAngulo(m_pManager, evento.c->GetRenderer()->GetVID(), m_Modo, "Angle");
+				if (m_Modo == MA_Cobb) {
+					m_pAnguloTemp->SetCompleted(false);
+				}
 				m_pAnguloTemp->m_Nodos[0] = m_pAnguloTemp->m_Nodos[1] = m_pAnguloTemp->m_Nodos[2] = evento.iP;
-				m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+				m_pAnguloTemp->Recalcular(evento.c->GetRenderer(), true);
 				m_NodoActual = 1;
 				ConsumirEvento();
 			}
@@ -152,6 +156,7 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 			if (m_pAnguloTemp != NULL) {
 				if (m_Modo == MA_Cobb) {  // Angulo de Cobb
 					if (m_NodoActual == 2) {
+						m_pAnguloTemp->SetCompleted(true);
 						m_pAnguloTemp->m_Nodos[2] = evento.iP;
 						m_NodoActual = 3;
 						m_pAnguloTemp->m_Nodos[3] = evento.iP;
@@ -166,14 +171,14 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 	} else if (evento.Dragging() && m_Estado == WBS_Creando) {
 		if (m_pAnguloTemp != NULL) {
 			m_pAnguloTemp->m_Nodos[m_NodoActual] = evento.iP;
-			m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+			m_pAnguloTemp->Recalcular(evento.c->GetRenderer(), true);
 			m_pManager->Modificado();
 			ConsumirEvento();
 		}
 	} else if (evento.Moving() && m_Estado == WBS_Creando) {
 		if (m_pAnguloTemp != NULL) {
 			m_pAnguloTemp->m_Nodos[m_NodoActual] = evento.iP;
-			m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+			m_pAnguloTemp->Recalcular(evento.c->GetRenderer(), true);
 			m_pManager->Modificado();
 			ConsumirEvento();
 		}
@@ -193,7 +198,7 @@ void GNC::GCS::Widgets::WAnguloBuilder::Render(GNC::GCS::Contexto3D* c)
 	}
 	if (c->GetRenderer()->GetVID() == m_pAnguloTemp->GetVID()) {
 
-		glLineWidth(WIDGET_GROSOR_LINEA);
+		glLineWidth(m_LineWidthProp);
 
 		if (m_Modo == MA_Normal) {
 			if (m_NodoActual < 2) {
@@ -232,25 +237,27 @@ GNC::GCS::Widgets::TipoCursor GNC::GCS::Widgets::WAnguloBuilder::GetCursor()
 
 //endregion
 
-
 //region "Constructor y destructor"
 
 GNC::GCS::Widgets::WAngulo::WAngulo(IWidgetsManager* pManager, long vid, ModoAngulo modo, const char* nombre) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre,0,TID_USER_ANNOTATION_WIDGET), GNC::GCS::Widgets::IWidgetSerializable()
 {
-	m_AnchoMaximo = 150.0f;
 	m_Modo = modo;
 
 	m_MouseDown = false;
 	m_Oculto = false;
-	m_ReservaRecursos = true;
-	Recalcular(NULL);
+	
+	m_pTextBox = new GNC::GCS::Widgets::WTextBox(m_pManager, m_VID, m_Nodos[1], GNC::GCS::Widgets::WTextBox::TNM_Dynamic, "ruleBox", "");
+	m_pTextBox->SetTexto("0");
+	m_pManager->InsertarWidget(m_pTextBox);
 
+	Recalcular(NULL, false);
 	GNC::GCS::Events::EventoModificacionImagen evt1(m_pManager->GetVista());
 }
 
 GNC::GCS::Widgets::WAngulo::~WAngulo()
 {
-	LanzarEventoDestruccion();
+	m_pManager->EliminarWidget(m_pTextBox, false);
+	LanzarEventoDestruccion();	
 }
 
 //endregion
@@ -258,7 +265,6 @@ GNC::GCS::Widgets::WAngulo::~WAngulo()
 //region "Serializado y desserializado"
 GNC::GCS::Widgets::WAngulo::WAngulo(IWidgetsManager* pManager, long vid, wxXmlNode* nodo):GNC::GCS::Widgets::IWidget(pManager, vid, "Ángulo"), GNC::GCS::Widgets::IWidgetSerializable(nodo)
 {
-	m_AnchoMaximo = 150.0f;
 	if(nodo->GetName() != wxT("angle_widget")){
 		std::cerr<< "Ha ocurrido un error al desserializar el widget regla"<<std::endl;
 	}
@@ -284,12 +290,19 @@ GNC::GCS::Widgets::WAngulo::WAngulo(IWidgetsManager* pManager, long vid, wxXmlNo
 	}
 
 	m_MouseDown = false;
-	m_ReservaRecursos = true;
 
-	Recalcular(NULL);
+	m_pTextBox = new GNC::GCS::Widgets::WTextBox(m_pManager, m_VID, m_Nodos[1], GNC::GCS::Widgets::WTextBox::TNM_Dynamic, "ruleBox", "");
+	m_pTextBox->SetTexto("0");
+	m_pManager->InsertarWidget(m_pTextBox);
+
+	Recalcular(NULL, false);
 
 	GNC::GCS::Events::EventoModificacionImagen evt1(m_pManager->GetVista());
+}
 
+void GNC::GCS::Widgets::WAngulo::SetCompleted(bool completed)
+{
+	m_pTextBox->Ocultar(!completed);		
 }
 
 wxXmlNode* GNC::GCS::Widgets::WAngulo::Serializar(const std::string& nombreMedico)
@@ -368,7 +381,7 @@ void GNC::GCS::Widgets::WAngulo::OnMouseEvents(GNC::GCS::Events::EventoRaton& ev
 			m_Nodos[3] += delta;
 		}
 
-		Recalcular(evento.c->GetRenderer());
+		Recalcular(evento.c->GetRenderer(), false);
 		LanzarEventoModificacion();
 		ConsumirEvento();
 
@@ -660,7 +673,7 @@ void GNC::GCS::Widgets::WAngulo::RenderNormal(GNC::GCS::Contexto3D* c)
 		fsombray = WIDGET_OFFSET_Y_SOMBRA * escala.y;
 	}
 
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 
 	// Sombra cuerpo
 	wColorSombra.Aplicar();
@@ -782,38 +795,6 @@ void GNC::GCS::Widgets::WAngulo::RenderNormal(GNC::GCS::Contexto3D* c)
 	glBegin(GL_POINTS);
 		glVertex2d(m_Nodos[1].x, m_Nodos[1].y);
 	glEnd();
-
-	TexturaAngulo* ta = GetTextura(c->GetRenderer());
-	if(ta->texto != m_Texto) {
-		Recalcular(c->GetRenderer());
-	}
-	GNC::GCS::TexturaCairo* tc = ta->m_textura;
-	// Dibujado de la medida.
-	if (!tc->contextoCreado) {
-		//std::cerr << "Error: Contexto no creado" << std::endl;
-		return;
-	}
-	if (!tc->texturaCargada) {
-		tc->Cargar();
-	}
-	if (tc->texturaModificada) {
-		tc->Actualizar();
-	}
-
-	// Dibujado del texto.
-
-	// Compute display pos
-	GNC::GCS::Vector3D planePos(puntoTexto.x, puntoTexto.y, (double)c->pRenderer->m_pImageViewer->GetTindex());
-	GNC::GCS::Vector3D worldPos;
-	GNC::GCS::Vector3D displayPos;
-
-	c->pRenderer->m_pImageViewer->UnProyect2D(planePos.v, worldPos.v);
-	c->pRenderer->WorldToDisplay(worldPos.v, displayPos.v);
-
-	// Alineamiento
-
-	GNC::GCS::Vector alineacion = GNC::GCS::Vector(0.0, (tc->alto / 2.0));
-	wDibujarTexturaTexto2D(c, *tc, (GNC::GCS::Vector(displayPos.x, displayPos.y) + alineacion ).Redondear());
 }
 
 void GNC::GCS::Widgets::WAngulo::RenderCobb(GNC::GCS::Contexto3D* c)
@@ -830,7 +811,6 @@ void GNC::GCS::Widgets::WAngulo::RenderCobb(GNC::GCS::Contexto3D* c)
 		return;
 	}
 
-
 	// Sombra
 	float fsombrax, fsombray;
 	if (m_Seleccionado && m_MouseDown)
@@ -844,7 +824,7 @@ void GNC::GCS::Widgets::WAngulo::RenderCobb(GNC::GCS::Contexto3D* c)
 		fsombray = WIDGET_OFFSET_Y_SOMBRA * escala.y;
 	}
 
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 
 	// Sombra
 	wColorSombra.Aplicar();
@@ -972,7 +952,6 @@ void GNC::GCS::Widgets::WAngulo::RenderCobb(GNC::GCS::Contexto3D* c)
 	// Cuerpo
 	wAplicarColor(m_Iluminado, m_MouseDown, m_Seleccionado);
 
-
 	glBegin(GL_LINES);
 		glVertex2d(m_Nodos[0].x, m_Nodos[0].y);
 		glVertex2d(m_Nodos[1].x, m_Nodos[1].y);
@@ -980,7 +959,6 @@ void GNC::GCS::Widgets::WAngulo::RenderCobb(GNC::GCS::Contexto3D* c)
 		glVertex2d(m_Nodos[3].x, m_Nodos[3].y);
 	glEnd();
 
-
 	// Puntas de flechas
 	wAplicarColor(m_Iluminado || m_Nodos[1].m_Iluminado, m_MouseDown, m_Seleccionado);
 	glBegin(GL_LINE_STRIP);
@@ -1031,59 +1009,15 @@ void GNC::GCS::Widgets::WAngulo::RenderCobb(GNC::GCS::Contexto3D* c)
 	glBegin(GL_POINTS);
 	glVertex2d(interseccion.x, interseccion.y);
 	glEnd();
-
-	TexturaAngulo* ta = GetTextura(c->GetRenderer());
-	if(ta->texto != m_Texto) {
-		Recalcular(c->GetRenderer());
-	}
-	GNC::GCS::TexturaCairo* tc = ta->m_textura;
-	// Dibujado de la medida.
-	if (!tc->contextoCreado) {
-		//std::cerr << "Error: Contexto no creado" << std::endl;
-		return;
-	}
-	if (!tc->texturaCargada) {
-		tc->Cargar();
-	}
-	if (tc->texturaModificada) {
-		tc->Actualizar();
-	}
-
-	// Dibujado del texto.
-
-	// Compute display pos
-	GNC::GCS::Vector3D planePos(puntoTexto.x, puntoTexto.y, (double)c->pRenderer->m_pImageViewer->GetTindex());
-	GNC::GCS::Vector3D worldPos;
-	GNC::GCS::Vector3D displayPos;
-
-	c->pRenderer->m_pImageViewer->UnProyect2D(planePos.v, worldPos.v);
-	c->pRenderer->WorldToDisplay(worldPos.v, displayPos.v);
-
-	// Alineamiento
-
-	GNC::GCS::Vector alineacion = GNC::GCS::Vector(0.0, (m_TamTexto.y / 2.0));
-
-	wDibujarTexturaTexto2D(c, *tc, (GNC::GCS::Vector(displayPos.x, displayPos.y) + alineacion ).Redondear());
-
 }
 
-GNC::GCS::Widgets::WAngulo::TexturaAngulo* GNC::GCS::Widgets::WAngulo::GetTextura(GNC::GCS::IWidgetsRenderer* renderer)
-{
-	if(m_mapaRecursos.find(renderer) == m_mapaRecursos.end()) {
-		TexturaAngulo* pTextura = new TexturaAngulo();
-		m_mapaRecursos[renderer] = pTextura;
-		Recalcular(renderer);
-	}
-	return m_mapaRecursos[renderer];
-}
-
-void GNC::GCS::Widgets::WAngulo::Recalcular(GNC::GCS::IWidgetsRenderer* renderer)
+void GNC::GCS::Widgets::WAngulo::Recalcular(GNC::GCS::IWidgetsRenderer* renderer, bool building)
 {
 	GNC::GCS::Vector3D worldNodes[4];
 	if (renderer != NULL && renderer->m_pImageViewer != NULL) {
 		const double tindex = renderer->m_pImageViewer->GetTindex();
 		for (int i = 0; i < 4; i++) {
-			double imagePosition[3] = {m_Nodos[i].x, m_Nodos[i].y, tindex};
+			double imagePosition[3] = { m_Nodos[i].x, m_Nodos[i].y, tindex };
 			renderer->m_pImageViewer->CoordenadasImagenACoordenadasMundo(imagePosition, worldNodes[i].v);
 		}
 	} else {
@@ -1147,65 +1081,21 @@ void GNC::GCS::Widgets::WAngulo::Recalcular(GNC::GCS::IWidgetsRenderer* renderer
 	os.precision(2);
 	os.fill('0');
 
-	os << (std::abs(m_Angulo) * 180 / M_PI)  << " º";
+	os << (std::abs(m_Angulo) * 180.0 / M_PI)  << " º";
 
 	std::string medida = os.str();
 
-	if (renderer != NULL) {
-
-		TexturaAngulo* ta = GetTextura(renderer);
-		if (m_Texto != medida || ta->texto != medida) {
-			ta->texto = medida;
-			m_Texto = medida;
-			//std::cout << "distancia = " << m_Texto << std::endl;
-			GNC::GCS::TexturaCairo* tc = ta->m_textura;
-
-			if (!tc->contextoCreado) {
-				tc->Redimensionar(2, 2);
-			}
-
-			cairo_font_options_t* options;
-
-			cairo_select_font_face (tc->cr, "Arial", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-			cairo_set_font_size(tc->cr, WIDGET_SIZE_FUENTE);
-			options = cairo_font_options_create ();
-			cairo_get_font_options(tc->cr, options);
-			cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
-			cairo_set_font_options(tc->cr, options);
-
-			m_TamTexto = GNC::GCS::GLHelper::calcularBoundingBox((*tc), m_Texto, m_AnchoMaximo); // Tamaño de la region en pixels
-
-			tc->Redimensionar(std::ceil(m_TamTexto.x), std::ceil(m_TamTexto.y));
-			m_TamTexto.Asignar(tc->ancho, tc->alto);
-
-			cairo_select_font_face (tc->cr, "Arial", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-			cairo_set_font_size(tc->cr, WIDGET_SIZE_FUENTE);
-			cairo_get_font_options(tc->cr, options);
-			cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
-			cairo_set_font_options(tc->cr, options);
-			cairo_font_options_destroy(options);
-			options = NULL;
-
-			cairo_set_operator(tc->cr, CAIRO_OPERATOR_SOURCE);
-			cairo_set_source_rgba(tc->cr, 0.0f, 0.0f, 0.0f, 0.0f);
-			cairo_paint(tc->cr);
-
-			cairo_set_source_rgba (tc->cr, 1.0f, 1.0f, 1.0f, 1.0f);
-			GNC::GCS::GLHelper::dibujarTexto((*tc), m_Texto, m_AnchoMaximo);
+	m_pTextBox->SetTexto(medida);
+	if (building) {
+		if (m_Modo == MA_Normal) {
+			m_pTextBox->SetPosition(m_Nodos[1]);
+		}
+		else {
+			m_pTextBox->SetPosition(m_Nodos[1].PuntoMedio(m_Nodos[2]));
 		}
 	}
 }
 
-void GNC::GCS::Widgets::WAngulo::LiberarRecursos(GNC::GCS::IWidgetsRenderer* pKey)
-{
-	TMapaRecursos::iterator it = m_mapaRecursos.find(pKey);
-	if(it!=m_mapaRecursos.end()) {
-		delete (*it).second;
-		m_mapaRecursos.erase(it);
-	}
-}
-
-
 void GNC::GCS::Widgets::WAngulo::InsertarPropiedades(TListaMapasPropiedades &listaMapaPropiedades)
 {
 	TMapaPropiedades& primerMapa = listaMapaPropiedades.front();
@@ -1220,7 +1110,7 @@ void GNC::GCS::Widgets::WAngulo::InsertarPropiedades(TListaMapasPropiedades &lis
 		os.precision(2);
 		os.fill('0');
 
-		os << (std::abs(m_Angulo) * 180 / M_PI)  << " º";
+		os << (std::abs(m_Angulo) * 180.0 / M_PI)  << " º";
 
 		std::string medida = os.str();
 		primerMapa[_Std("Value")] = medida;
@@ -1231,10 +1121,7 @@ void GNC::GCS::Widgets::WAngulo::InsertarPropiedades(TListaMapasPropiedades &lis
 
 void GNC::GCS::Widgets::WAngulo::OffscreenRender(GNC::GCS::Contexto3D* c)
 {
-	
 	const GNC::GCS::Vector& escala = c->RefRelacionMundoPantallaOffscreen();
-	GNC::GCS::Vector TamTexto;
-
 	float Angulo;
 
 	if (m_Modo == MA_Normal) {
@@ -1271,15 +1158,6 @@ void GNC::GCS::Widgets::WAngulo::OffscreenRender(GNC::GCS::Contexto3D* c)
 		}
 	}
 
-	std::stringstream os;
-	os.setf(ios::floatfield, ios::fixed );
-	os.precision(2);
-	os.fill('0');
-
-	os << (std::abs(Angulo) * 180 / M_PI)  << " º";
-
-	std::string Texto = os.str();
-
 	if (m_Modo == MA_Normal) {
 
 		TVector Nodos[3] = { c->Reproyectar(m_Nodos[0]) * c->factorReescalado, c->Reproyectar(m_Nodos[1]) * c->factorReescalado, c->Reproyectar(m_Nodos[2]) * c->factorReescalado };
@@ -1293,7 +1171,7 @@ void GNC::GCS::Widgets::WAngulo::OffscreenRender(GNC::GCS::Contexto3D* c)
 		if (n1 == 0.0f || n2 == 0.0f) {
 			return;
 		}
-		cairo_set_line_width(c->cr, WIDGET_GROSOR_LINEA);
+		cairo_set_line_width(c->cr, m_LineWidthProp);
 
 		float anguloPunta = M_PI_4 / 2.0f;
 		TVector vOrtogonalA = (Nodos[1] - Nodos[0]).VectorOrtonormal() * escala * 15.0f;
@@ -1362,27 +1240,6 @@ void GNC::GCS::Widgets::WAngulo::OffscreenRender(GNC::GCS::Contexto3D* c)
 
 		cairo_arc(c->cr, Nodos[1].x, Nodos[1].y, ( (WIDGET_SIZE_PUNTO / 2.0f) * escala.x), 0, M_2PI);
 		cairo_fill(c->cr);
-
-		// Texto de la medida
-		cairo_font_options_t* options;
-		options = cairo_font_options_create ();
-
-		cairo_select_font_face (c->cr, "Arial", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-		cairo_set_font_size(c->cr, std::max(WIDGET_SIZE_FUENTE * escala.x,(double)8.0f));
-		cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
-		cairo_set_font_options(c->cr, options);
-
-		TamTexto = GNC::GCS::Widgets::HelperTexto::calcularBoundingBox(c, Texto, m_AnchoMaximo * escala.x); // Tamaño de la region en pixels
-
-		GNC::GCS::Vector puntoTextoCorregido(puntoTexto.x, puntoTexto.y - (TamTexto.y / 2.0f));
-		puntoTextoCorregido.Redondear();
-		cairo_set_source_rgba (c->cr, 1.0f, 1.0f, 1.0f, 1.0f);		
-		cairo_save(c->cr);
-		cairo_translate(c->cr, puntoTextoCorregido.x, puntoTextoCorregido.y);
-		GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, Texto, m_AnchoMaximo * escala.x);
-		cairo_restore(c->cr);
-
-		cairo_font_options_destroy(options);
 	}
 	else {
 		TVector Nodos[4] = { c->Reproyectar(m_Nodos[0]) * c->factorReescalado, c->Reproyectar(m_Nodos[1]) * c->factorReescalado, c->Reproyectar(m_Nodos[2]) * c->factorReescalado, c->Reproyectar(m_Nodos[3]) * c->factorReescalado };
@@ -1396,7 +1253,7 @@ void GNC::GCS::Widgets::WAngulo::OffscreenRender(GNC::GCS::Contexto3D* c)
 			return;
 		}
 
-		cairo_set_line_width(c->cr, WIDGET_GROSOR_LINEA);
+		cairo_set_line_width(c->cr, m_LineWidthProp);
 
 		float anguloPunta = M_PI_4 / 2.0f;
 		TVector vOrtogonalA = (Nodos[0] - Nodos[1]).VectorOrtonormal() * escala * 15.0f;
@@ -1417,14 +1274,11 @@ void GNC::GCS::Widgets::WAngulo::OffscreenRender(GNC::GCS::Contexto3D* c)
 			va = Nodos[3].PuntoMedio(Nodos[2]);
 		}
 
-		TVector puntoTexto;
-
 		TVector interseccion = TVector::InterseccionEntreRectas(Nodos[0], Nodos[1], Nodos[2], Nodos[3]);
 		// Arco
 		{
 			TVector p0 = Nodos[0].PuntoMedio(Nodos[1]);
 			TVector p1 = Nodos[3].PuntoMedio(Nodos[2]);
-			puntoTexto = p0.PuntoMedio(p1);
 
 			wColorAngulo.AplicarCairo(c->cr);
 			cairo_move_to(c->cr, p0.x, p0.y);
@@ -1484,26 +1338,5 @@ void GNC::GCS::Widgets::WAngulo::OffscreenRender(GNC::GCS::Contexto3D* c)
 		wColorAngulo.AplicarCairo(c->cr);
 		cairo_arc(c->cr, interseccion.x, interseccion.y,  (WIDGET_SIZE_PUNTO / 2.0f) * escala.x, 0, M_2PI);
 		cairo_fill(c->cr);
-
-		// Texto de la medida
-		cairo_font_options_t* options;
-		options = cairo_font_options_create ();
-
-		cairo_select_font_face (c->cr, "Arial", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-		cairo_set_font_size(c->cr, std::max(WIDGET_SIZE_FUENTE * escala.x,(double)8.0f));
-		cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
-		cairo_set_font_options(c->cr, options);
-
-		TamTexto = GNC::GCS::Widgets::HelperTexto::calcularBoundingBox(c, Texto, m_AnchoMaximo * escala.x); // Tamaño de la region en pixels
-
-		GNC::GCS::Vector puntoTextoCorregido(puntoTexto.x, puntoTexto.y - (TamTexto.y / 2.0f));
-		puntoTextoCorregido.Redondear();
-		cairo_set_source_rgba (c->cr, 1.0f, 1.0f, 1.0f, 1.0f);
-		cairo_save(c->cr);		
-		cairo_translate(c->cr, puntoTextoCorregido.x, puntoTextoCorregido.y);
-		GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, Texto, m_AnchoMaximo * escala.x);
-		cairo_restore(c->cr);
-
-		cairo_font_options_destroy(options);
 	}
 }
