@@ -17,11 +17,6 @@
 #include <cstring>
 #include <cairo/cairo.h>
 
-#ifdef __WXOSX__
-#define FUENTE_CAIRO "Arial"
-#else
-#define FUENTE_CAIRO "Arial"
-#endif
 //#define _GINKGO_TRACE
 #include <api/globals.h>
 #include <api/helpers/helpertexto.h>
@@ -40,6 +35,7 @@
 #include <main/controllers/controladoreventos.h>
 #include <main/controllers/configurationcontroller.h>
 #include <main/controllers/modalitysettingscontroller.h>
+#include <api/controllers/icontroladorpermisos.h>
 
 #include "wanotacionesquina.h"
 
@@ -50,8 +46,6 @@
 #include <vtk/vtkginkgoimageviewer.h>
 #include "striptexthelper.h"
 
-#define ANNOTATOR_TEXT_COLOR 0.9f, 0.9f, 0.9f, 1.0f
-
 namespace GNC {
 	const char* PatientOrientation[10*3*3] = {
 		"",  "",  "",    "", "",  "",    "", "",  "", // N/A
@@ -84,7 +78,8 @@ namespace GNC {
 					TP_NumPosiciones
 				} TPosicionAnotacion;
 				OrientationMarks() {
-					m_StripTextRenderer.Update("RLAPIS", GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR), TAMFUENTE);
+					m_FontSizeProp = GNC::GCS::IControladorPermisos::Instance()->Get("style", "cornerAnnotation.fontSize").ObtenerValor<float>();
+					m_StripTextRenderer.Update("RLAPIS", GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR), m_FontSizeProp, ANNOTATION_TEXT_WITH_SHADOW);
 				}
 
 				~OrientationMarks()
@@ -127,6 +122,7 @@ namespace GNC {
 
 				std::string m_TextoAnotacion[4];
 				GNC::GCS::Widgets::StripTextRenderer m_StripTextRenderer;
+				float m_FontSizeProp;
 			};
 
 			/**
@@ -174,7 +170,6 @@ namespace GNC {
 
 				Anotaciones(GNC::GCS::IWidgetsRenderer* pRenderer)
 				{
-					m_TamFuente           = TAMFUENTE;
 					m_Correcta            = false;
 					m_RecalcularTamOptimo = false;
 					m_pRenderer           = pRenderer;
@@ -184,6 +179,8 @@ namespace GNC {
 						m_TexturaModificada[i] = false;
 					}
 
+					m_FontSizeProp = GNC::GCS::IControladorPermisos::Instance()->Get("style", "cornerAnnotation.fontSize").ObtenerValor<float>();
+
 					m_Alineacion[GNC::GCS::AnnotationSettings::TP_TopLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
 					m_Alineacion[GNC::GCS::AnnotationSettings::TP_TopRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
 					m_Alineacion[GNC::GCS::AnnotationSettings::TP_BottomLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
@@ -362,22 +359,22 @@ namespace GNC {
 					if (m_RecalcularTamOptimo) {
 						m_RecalcularTamOptimo = false;
 						m_TamCajaMaxima = m_TamViewPort;
-						m_TamFuente = TAMFUENTE;
+						m_TamFuente = m_FontSizeProp;
 						for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; ++i) {
 							m_TamTexto[i].Asignar(0.0f, 0.0f);
 							if (m_TextoAnotacion[i].size() > 0) {
-								cairo_select_font_face(m_TexturaMetrica.cr, FUENTE_CAIRO, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
-								cairo_set_font_size(m_TexturaMetrica.cr, TAMFUENTE);
-								m_TamTexto[i] = GNC::GCS::GLHelper::calcularBoundingBox(m_TexturaMetrica, m_TextoAnotacion[i], -1);
+								cairo_select_font_face(m_TexturaMetrica.cr, WIDGETS_TEXT_FONT_FAMILY, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
+								cairo_set_font_size(m_TexturaMetrica.cr, m_FontSizeProp);
+								m_TamTexto[i] = GNC::GCS::GLHelper::calcularBoundingBox(m_TexturaMetrica, m_TextoAnotacion[i], ANNOTATION_TEXT_WITH_SHADOW, -1.0f);
 								m_TamCajaMaxima.AsignarMaximos(m_TamTexto[i]);
 							}
 						}
 						if (!m_TamCajaMaxima.EsNulo()) {
-							m_TamFuente = ((m_TamViewPort * TAMFUENTE) / m_TamCajaMaxima).Redondear().ComponenteMinima(); // Calculo del tamanyo de fuente maxima
+							m_TamFuente = ((m_TamViewPort * m_FontSizeProp) / m_TamCajaMaxima).Redondear().ComponenteMinima(); // Calculo del tamanyo de fuente maxima
 							m_TamFuente = std::max(TAMFUENTE_MIN, m_TamFuente);
 
 							for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; ++i) {
-								m_TamTexto[i] *=  (m_TamFuente / TAMFUENTE);
+								m_TamTexto[i] *=  (m_TamFuente / m_FontSizeProp);
 								m_TamTexto[i].RedondearAlza();
 								m_Texturas[i].Redimensionar(m_TamTexto[i].x, m_TamTexto[i].y);
 								m_TexturaModificada[i] = true;
@@ -403,7 +400,7 @@ namespace GNC {
 
 						if ( m_TexturaModificada[i] && m_Texturas[i].EsValida() && (m_TextoAnotacion[i].size() > 0) )
 						{
-							cairo_select_font_face(m_Texturas[i].cr, FUENTE_CAIRO, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
+							cairo_select_font_face(m_Texturas[i].cr, WIDGETS_TEXT_FONT_FAMILY, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
 							cairo_set_font_size(m_Texturas[i].cr, m_TamFuente);
 
 							cairo_get_font_options(m_Texturas[i].cr, m_pFontOptions);
@@ -413,7 +410,7 @@ namespace GNC {
 
 							cairo_set_source_rgba (m_Texturas[i].cr, 1.0f, 1.0f, 0.0f, 0.0f);
 							cairo_paint(m_Texturas[i].cr);
-							m_TamTexto[i] = GNC::GCS::GLHelper::dibujarTexto(m_Texturas[i], texto, color, m_TamCajaMaxima.x, m_Alineacion[i]);
+							m_TamTexto[i] = GNC::GCS::GLHelper::dibujarTexto(m_Texturas[i], texto, color, ANNOTATION_TEXT_WITH_SHADOW, m_TamCajaMaxima.x, m_Alineacion[i]);
 							m_TexturaModificada[i] = false;
 						}
 					}
@@ -472,6 +469,7 @@ namespace GNC {
 
 				bool m_Correcta;
 				float m_TamFuente;
+				float m_FontSizeProp;
 
 				GNC::GCS::Widgets::HelperTexto::TAlineamiento m_Alineacion[GNC::GCS::AnnotationSettings::TP_NumPos];
 
@@ -721,6 +719,18 @@ void GNC::GCS::Widgets::WAnotador::Ocultar(bool oculto)
 //endregion
 
 void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaciones, GNC::GCS::Contexto3D* c)
+{
+	std::ostringstream dirs[6]; // left, right, top, bottom, back, forward
+
+	ComputeOrientation(c, dirs);
+	pAnotaciones->SetAnotation(OrientationMarks::TP_Left, dirs[0].str());
+	pAnotaciones->SetAnotation(OrientationMarks::TP_Right, dirs[1].str());
+	pAnotaciones->SetAnotation(OrientationMarks::TP_Top, dirs[2].str());	
+	pAnotaciones->SetAnotation(OrientationMarks::TP_Bottom, dirs[3].str());
+	
+}
+
+void GNC::GCS::Widgets::WAnotador::ComputeOrientation(GNC::GCS::Contexto3D* c, std::ostringstream* dirs )
 {
 	GNC::GCS::Vector3D camPos;
 	GNC::GCS::Vector3D camDir;
@@ -764,14 +774,12 @@ void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaci
 
 	int patientPosIndex = GetOrientationIndex(patPosition, false);
 
-	std::ostringstream left;
-	std::ostringstream right;
-	std::ostringstream top;
-	std::ostringstream bottom;
+
 
 	LOG_DEBUG("View", "Current orientation:");
 	LOG_DEBUG("View", "Left = " << camOrient[0][1] << ", Right = " << camOrient[0][0]);
 	LOG_DEBUG("View", "Up  = " << camOrient[1][0] << ", Down = " << camOrient[1][1]);
+	LOG_DEBUG("View", "Back  = " << camOrient[2][0] << ", Front = " << camOrient[2][1]);
 
 	const int offPos = 9 * patientPosIndex;
 	const int offX = 0;
@@ -783,132 +791,193 @@ void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaci
 
 	// Left X:
 	if (camOrient[0][1][0] == 1.0) {
-		left << PatientOrientation[offPos + offX + offSignPos];
+		dirs[0] << PatientOrientation[offPos + offX + offSignPos];
 	}
 	else if (camOrient[0][1][0] == -1.0) {
-		left << PatientOrientation[offPos + offX + offSignNeg];
+		dirs[0] << PatientOrientation[offPos + offX + offSignNeg];
 	}
 	else {
-		left << PatientOrientation[offPos + offX + offSignZero];
+		dirs[0] << PatientOrientation[offPos + offX + offSignZero];
 	}
 	// Left Y:
 	if (camOrient[0][1][1] == 1.0) {
-		left << PatientOrientation[offPos + offY + offSignPos];
+		dirs[0] << PatientOrientation[offPos + offY + offSignPos];
 	}
 	else if (camOrient[0][1][1] == -1.0) {
-		left << PatientOrientation[offPos + offY + offSignNeg];
+		dirs[0] << PatientOrientation[offPos + offY + offSignNeg];
 	}
 	else {
-		left << PatientOrientation[offPos + offY + offSignZero];
+		dirs[0] << PatientOrientation[offPos + offY + offSignZero];
 	}
 	// Left Z:
 	if (camOrient[0][1][2] == 1.0) {
-		left << PatientOrientation[offPos + offZ + offSignPos];
+		dirs[0] << PatientOrientation[offPos + offZ + offSignPos];
 	}
 	else if (camOrient[0][1][2] == -1.0) {
-		left << PatientOrientation[offPos + offZ + offSignNeg];
+		dirs[0] << PatientOrientation[offPos + offZ + offSignNeg];
 	}
 	else {
-		left << PatientOrientation[offPos + offZ + offSignZero];
+		dirs[0] << PatientOrientation[offPos + offZ + offSignZero];
 	}
 
 	// Right X:
 	if (camOrient[0][0][0] == 1.0) {
-		right << PatientOrientation[offPos + offX + offSignPos];
+		dirs[1] << PatientOrientation[offPos + offX + offSignPos];
 	}
 	else if (camOrient[0][0][0] == -1.0) {
-		right << PatientOrientation[offPos + offX + offSignNeg];
+		dirs[1] << PatientOrientation[offPos + offX + offSignNeg];
 	}
 	else {
-		right << PatientOrientation[offPos + offX + offSignZero];
+		dirs[1] << PatientOrientation[offPos + offX + offSignZero];
 	}
 	// Right Y:
 	if (camOrient[0][0][1] == 1.0) {
-		right << PatientOrientation[offPos + offY + offSignPos];
+		dirs[1] << PatientOrientation[offPos + offY + offSignPos];
 	}
 	else if (camOrient[0][0][1] == -1.0) {
-		right << PatientOrientation[offPos + offY + offSignNeg];
+		dirs[1] << PatientOrientation[offPos + offY + offSignNeg];
 	}
 	else {
-		right << PatientOrientation[offPos + offY + offSignZero];
+		dirs[1] << PatientOrientation[offPos + offY + offSignZero];
 	}
 	// Right Z:
 	if (camOrient[0][0][2] == 1.0) {
-		right << PatientOrientation[offPos + offZ + offSignPos];
+		dirs[1] << PatientOrientation[offPos + offZ + offSignPos];
 	}
 	else if (camOrient[0][0][2] == -1.0) {
-		right << PatientOrientation[offPos + offZ + offSignNeg];
+		dirs[1] << PatientOrientation[offPos + offZ + offSignNeg];
 	}
 	else {
-		right << PatientOrientation[offPos + offZ + offSignZero];
+		dirs[1] << PatientOrientation[offPos + offZ + offSignZero];
 	}
 
 	// Top X:
 	if (camOrient[1][0][0] == 1.0) {
-		top << PatientOrientation[offPos + offX + offSignPos];
+		dirs[2] << PatientOrientation[offPos + offX + offSignPos];
 	}
 	else if (camOrient[1][0][0] == -1.0) {
-		top << PatientOrientation[offPos + offX + offSignNeg];
+		dirs[2] << PatientOrientation[offPos + offX + offSignNeg];
 	}
 	else {
-		top << PatientOrientation[offPos + offX + offSignZero];
+		dirs[2] << PatientOrientation[offPos + offX + offSignZero];
 	}
 	// Top Y:
 	if (camOrient[1][0][1] == 1.0) {
-		top << PatientOrientation[offPos + offY + offSignPos];
+		dirs[2] << PatientOrientation[offPos + offY + offSignPos];
 	}
 	else if (camOrient[1][0][1] == -1.0) {
-		top << PatientOrientation[offPos + offY + offSignNeg];
+		dirs[2] << PatientOrientation[offPos + offY + offSignNeg];
 	}
 	else {
-		top << PatientOrientation[offPos + offY + offSignZero];
+		dirs[2] << PatientOrientation[offPos + offY + offSignZero];
 	}
 	// Top Z:
 	if (camOrient[1][0][2] == 1.0) {
-		top << PatientOrientation[offPos + offZ + offSignPos];
+		dirs[2] << PatientOrientation[offPos + offZ + offSignPos];
 	}
 	else if (camOrient[1][0][2] == -1.0) {
-		top << PatientOrientation[offPos + offZ + offSignNeg];
+		dirs[2] << PatientOrientation[offPos + offZ + offSignNeg];
 	}
 	else {
-		top << PatientOrientation[offPos + offZ + offSignZero];
+		dirs[2] << PatientOrientation[offPos + offZ + offSignZero];
 	}
 
 	// Bottom X:
 	if (camOrient[1][1][0] == 1.0) {
-		bottom << PatientOrientation[offPos + offX + offSignPos];
+		dirs[3] << PatientOrientation[offPos + offX + offSignPos];
 	}
 	else if (camOrient[1][1][0] == -1.0) {
-		bottom << PatientOrientation[offPos + offX + offSignNeg];
+		dirs[3] << PatientOrientation[offPos + offX + offSignNeg];
 	}
 	else {
-		bottom << PatientOrientation[offPos + offX + offSignZero];
+		dirs[3] << PatientOrientation[offPos + offX + offSignZero];
 	}
 	// Bottom Y:
 	if (camOrient[1][1][1] == 1.0) {
-		bottom << PatientOrientation[offPos + offY + offSignPos];
+		dirs[3] << PatientOrientation[offPos + offY + offSignPos];
 	}
 	else if (camOrient[1][1][1] == -1.0) {
-		bottom << PatientOrientation[offPos + offY + offSignNeg];
+		dirs[3] << PatientOrientation[offPos + offY + offSignNeg];
 	}
 	else {
-		bottom << PatientOrientation[offPos + offY + offSignZero];
+		dirs[3] << PatientOrientation[offPos + offY + offSignZero];
 	}
 	// Bottom Z:
 	if (camOrient[1][1][2] == 1.0) {
-		bottom << PatientOrientation[offPos + offZ + offSignPos];
+		dirs[3] << PatientOrientation[offPos + offZ + offSignPos];
 	}
 	else if (camOrient[1][1][2] == -1.0) {
-		bottom << PatientOrientation[offPos + offZ + offSignNeg];
+		dirs[3] << PatientOrientation[offPos + offZ + offSignNeg];
 	}
 	else {
-		bottom << PatientOrientation[offPos + offZ + offSignZero];
+		dirs[3] << PatientOrientation[offPos + offZ + offSignZero];
 	}
-	pAnotaciones->SetAnotation(OrientationMarks::TP_Top, top.str());
-	pAnotaciones->SetAnotation(OrientationMarks::TP_Right, right.str());
-	pAnotaciones->SetAnotation(OrientationMarks::TP_Bottom, bottom.str());
-	pAnotaciones->SetAnotation(OrientationMarks::TP_Left, left.str());
+
+	// Extended
+	// Back X:
+	if (camOrient[2][1][0] == 1.0) {
+		dirs[4] << PatientOrientation[offPos + offX + offSignPos];
+	}
+	else if (camOrient[2][1][0] == -1.0) {
+		dirs[4] << PatientOrientation[offPos + offX + offSignNeg];
+	}
+	else {
+		dirs[4] << PatientOrientation[offPos + offX + offSignZero];
+	}
+	// Back Y:
+	if (camOrient[2][1][1] == 1.0) {
+		dirs[4] << PatientOrientation[offPos + offY + offSignPos];
+	}
+	else if (camOrient[2][1][1] == -1.0) {
+		dirs[4] << PatientOrientation[offPos + offY + offSignNeg];
+	}
+	else {
+		dirs[4] << PatientOrientation[offPos + offY + offSignZero];
+	}
+	// Back Z:
+	if (camOrient[2][1][2] == 1.0) {
+		dirs[4] << PatientOrientation[offPos + offZ + offSignPos];
+	}
+	else if (camOrient[2][1][2] == -1.0) {
+		dirs[4] << PatientOrientation[offPos + offZ + offSignNeg];
+	}
+	else {
+		dirs[4] << PatientOrientation[offPos + offZ + offSignZero];
+	}
+
+	// Front X:
+	if (camOrient[2][0][0] == 1.0) {
+		dirs[5] << PatientOrientation[offPos + offX + offSignPos];
+	}
+	else if (camOrient[2][0][0] == -1.0) {
+		dirs[5] << PatientOrientation[offPos + offX + offSignNeg];
+	}
+	else {
+		dirs[5] << PatientOrientation[offPos + offX + offSignZero];
+	}
+	// Front Y:
+	if (camOrient[2][0][1] == 1.0) {
+		dirs[5] << PatientOrientation[offPos + offY + offSignPos];
+	}
+	else if (camOrient[2][0][1] == -1.0) {
+		dirs[5] << PatientOrientation[offPos + offY + offSignNeg];
+	}
+	else {
+		dirs[5] << PatientOrientation[offPos + offY + offSignZero];
+	}
+	// Front Z:
+	if (camOrient[2][0][2] == 1.0) {
+		dirs[5] << PatientOrientation[offPos + offZ + offSignPos];
+	}
+	else if (camOrient[2][0][2] == -1.0) {
+		dirs[5] << PatientOrientation[offPos + offZ + offSignNeg];
+	}
+	else {
+		dirs[5] << PatientOrientation[offPos + offZ + offSignZero];
+	}
+
 }
+
 //region "Interfaz especifica"
 
 
@@ -929,11 +998,7 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	GNC::GCS::Vector TamViewPort = ((RectViewport[1] - RectViewport[0]).ValorAbsoluto() * PROPVIEWPORT).Redondear();
 
 	GNC::GCS::Vector TamCajaMaxima = (RectViewport[1] - RectViewport[0]).ValorAbsoluto();
-	//float TamFuente = TAMFUENTE;
-
-
-
-
+	
 	const std::string        TextoAnotacion[WAnotador::TP_NumPosiciones] = {"","","",""};/////////////{ m_pAnnotator->GetTopLeftAnnotation(c), m_pAnnotator->GetTopRightAnnotation(c), m_pAnnotator->GetBottomLeftAnnotation(c), m_pAnnotator->GetBottomRightAnnotation(c) };
 	GNC::GCS::Vector         TamTexto      [WAnotador::TP_NumPosiciones];
 	GNC::GCS::Widgets::HelperTexto::TAlineamiento Alineacion[4] = { GNC::GCS::Widgets::HelperTexto::TA_Izquierda, GNC::GCS::Widgets::HelperTexto::TA_Derecha, GNC::GCS::Widgets::HelperTexto::TA_Izquierda, GNC::GCS::Widgets::HelperTexto::TA_Derecha };
@@ -941,8 +1006,8 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	cairo_font_options_t* options;
 	options = cairo_font_options_create ();
 
-	cairo_select_font_face (c->cr, FUENTE_CAIRO, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
-	cairo_set_font_size(c->cr, std::max(TAMFUENTE * c->RefRelacionMundoPantallaOffscreen().x, (double)8.0f));
+	cairo_select_font_face (c->cr, WIDGETS_TEXT_FONT_FAMILY, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
+	cairo_set_font_size(c->cr, std::max(m_FontSizeProp * c->RefRelacionMundoPantallaOffscreen().x, (double)8.0f));
 	cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
 	cairo_set_font_options(c->cr, options);
 
@@ -950,7 +1015,7 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
 		TamTexto[i].Asignar(0.0f, 0.0f);
 		if (TextoAnotacion[i].size() > 0) {
-			TamTexto[i] = GNC::GCS::Widgets::HelperTexto::calcularBoundingBox(c, TextoAnotacion[i], TamCajaMaxima.x);
+			TamTexto[i] = GNC::GCS::Widgets::HelperTexto::calcularBoundingBox(c, TextoAnotacion[i], ANNOTATION_TEXT_WITH_SHADOW, TamCajaMaxima.x);
 			TamCajaMaxima.AsignarMaximos(TamTexto[i]);
 		}
 	}
@@ -963,7 +1028,7 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	cairo_save(c->cr);
 	cairo_translate(c->cr, pos.x, pos.y );
 
-	TamTexto[TP_TopLeft] = GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, TextoAnotacion[TP_TopLeft], TamCajaMaxima.x, Alineacion[TP_TopLeft]);
+	TamTexto[TP_TopLeft] = GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, TextoAnotacion[TP_TopLeft], ANNOTATION_TEXT_WITH_SHADOW, TamCajaMaxima.x, Alineacion[TP_TopLeft]);
 	cairo_restore(c->cr);
 
 	// Anotacion TP_TopRight
@@ -971,7 +1036,7 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	cairo_save(c->cr);
 	cairo_translate(c->cr, pos.x, pos.y );
 
-	TamTexto[TP_TopRight] = GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, TextoAnotacion[TP_TopRight], TamCajaMaxima.x, Alineacion[TP_TopRight]);
+	TamTexto[TP_TopRight] = GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, TextoAnotacion[TP_TopRight], ANNOTATION_TEXT_WITH_SHADOW, TamCajaMaxima.x, Alineacion[TP_TopRight]);
 	cairo_restore(c->cr);
 
 	// Anotacion TP_BottomLeft
@@ -979,7 +1044,7 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	cairo_save(c->cr);
 	cairo_translate(c->cr, pos.x, pos.y );
 
-	TamTexto[TP_BottomLeft] = GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, TextoAnotacion[TP_BottomLeft], TamCajaMaxima.x, Alineacion[TP_BottomLeft]);
+	TamTexto[TP_BottomLeft] = GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, TextoAnotacion[TP_BottomLeft], ANNOTATION_TEXT_WITH_SHADOW, TamCajaMaxima.x, Alineacion[TP_BottomLeft]);
 	cairo_restore(c->cr);
 
 	// Anotacion TP_BottomRight
@@ -987,7 +1052,7 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	cairo_save(c->cr);
 	cairo_translate(c->cr, pos.x, pos.y );
 
-	TamTexto[TP_BottomRight] = GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, TextoAnotacion[TP_BottomRight], TamCajaMaxima.x, Alineacion[TP_BottomRight]);
+	TamTexto[TP_BottomRight] = GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, TextoAnotacion[TP_BottomRight], ANNOTATION_TEXT_WITH_SHADOW, TamCajaMaxima.x, Alineacion[TP_BottomRight]);
 	cairo_restore(c->cr);
 
 
