@@ -19,7 +19,6 @@
 #include <list>
 #include "openglhelper.h"
 
-#define TAMFUENTE 12.0f
 #define TAMFUENTE_MIN 10.0f
 #define PROPVIEWPORT 0.40f // Proporcion maxima del viewport, tanto de ancho como de alto. (25%)
 
@@ -66,6 +65,8 @@ namespace GNC {
 				
 				virtual void RecalcularPosicion(OrientationMarks* pAnotaciones, GNC::GCS::Contexto3D* c);
 
+				virtual void ComputeOrientation(GNC::GCS::Contexto3D* c, std::ostringstream* dirs);
+
 			//endregion
 
 				//----------------------------------------------------------------------------------------------------
@@ -107,6 +108,7 @@ namespace GNC {
 			};
 			//endregion
 
+
 			/**
 			* Gets the orientation index given string. Default is zero.
 			* strPos: The patient position string (HFS, HFP...)
