@@ -109,7 +109,7 @@ void GNC::GCS::Widgets::WBrightnessContrastBuilder::Render(GNC::GCS::Contexto3D*
 
 	{
 		// Dibujado de la regla		
-		glLineWidth(WIDGET_GROSOR_LINEA);
+		glLineWidth(m_LineWidthProp);
 
 		wAplicarColor(false, false, false);
 		glBegin(GL_LINES);
@@ -120,7 +120,7 @@ void GNC::GCS::Widgets::WBrightnessContrastBuilder::Render(GNC::GCS::Contexto3D*
 		glEnd();
 
 		wAplicarColor(true, true, false);
-		glLineWidth(WIDGET_GROSOR_LINEA * 0.5f);
+		glLineWidth(m_LineWidthProp * 0.5f);
 		glBegin(GL_LINES);
 			glVertex2d(m_Start.x, m_Start.y);
 			glVertex2d(m_Stop.x, m_Start.y);
