@@ -46,6 +46,8 @@ namespace GNC {
 				//region "Helpers"
 
 				bool         m_Dentro;
+				bool         m_Changed;
+				TVector      m_Start;
 				//endregion
 
 
