@@ -222,7 +222,7 @@ void GNC::GCS::Widgets::WChromaComplejoBuilder::DibujarVarita(GNC::GCS::Contexto
 
 	wColorSombra.Aplicar();
 
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 	// cruz
 	DibujaAspa(m_Nodo, radioCruz,true,fsombrax,fsombray);
 
@@ -233,7 +233,7 @@ void GNC::GCS::Widgets::WChromaComplejoBuilder::DibujarVarita(GNC::GCS::Contexto
 	glEnd();
 
 	// Cuerpo
-	glLineWidth(WIDGET_GROSOR_LINEA_ARRASTRE);
+	glLineWidth(m_DraggingLineWidthProp);
 	wAplicarColor(m_Nodo.m_Iluminado, m_MouseDown, m_Nodo.m_Seleccionado);
 
 	// Cruz
@@ -255,7 +255,7 @@ void GNC::GCS::Widgets::WChromaComplejoBuilder::Render(GNC::GCS::Contexto3D* c)
 		float radioCruz = WRADIO_CRUZ * escala.x;
 
 		//se pinta la linea:
-		glLineWidth(WIDGET_GROSOR_LINEA);
+		glLineWidth(m_LineWidthProp);
 		wAplicarColor(false, false, false);
 		glEnable(GL_LINE_STIPPLE);
 		glLineStipple(3, 0xAAAA);
@@ -267,7 +267,7 @@ void GNC::GCS::Widgets::WChromaComplejoBuilder::Render(GNC::GCS::Contexto3D* c)
 		glDisable(GL_LINE_STIPPLE);
 
 		wAplicarColor(true, false, true);
-		glLineWidth(WIDGET_GROSOR_LINEA);
+		glLineWidth(m_LineWidthProp);
 		//se pintan los nodos representativos
 		if(m_ListaNodos.size()<= (unsigned int)m_numeroPuntos)
 		{
@@ -385,7 +385,7 @@ void GNC::GCS::Widgets::WChromaComplejo::Render(GNC::GCS::Contexto3D* c)
 
 	//se pinta la linea:
 	wAplicarColor(false, false, false);
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 	glEnable(GL_LINE_STIPPLE);
 	glLineStipple(3, 0xAAAA);
 	glBegin(GL_LINE_STRIP);
@@ -397,7 +397,7 @@ void GNC::GCS::Widgets::WChromaComplejo::Render(GNC::GCS::Contexto3D* c)
 
 	//se pintan los nodos representativos
 	wAplicarColor(true, false, true);
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 	TListaNodos puntos = GetListaNodos();
 	for(TListaNodos::iterator it = puntos.begin(); it!=puntos.end(); ++it)
 	{
