@@ -565,7 +565,7 @@ void GNC::GCS::Widgets::WElipse::Render(GNC::GCS::Contexto3D* c)
 
 	GNC::GCS::Vector escala = c->RelacionImagenPantalla();
 
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 
 	// Sombras
 	float fsombrax, fsombray;
@@ -783,7 +783,7 @@ void GNC::GCS::Widgets::WElipse::OffscreenRender(GNC::GCS::Contexto3D* c)
 		Nodos[i] = c->Reproyectar(m_Nodos[i]) * c->factorReescalado;
 	}
 
-	cairo_set_line_width(c->cr, WIDGET_GROSOR_LINEA);
+	cairo_set_line_width(c->cr, m_LineWidthProp);
 
 	// Color del cuerpo
 	wColorNormal.AplicarCairo(c->cr);
