@@ -661,7 +661,7 @@ void GNC::GCS::Widgets::WLupa::Render(GNC::GCS::Contexto3D* c)
 
 	// Dibujado del outline de iluminacion/seleccion
 
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 	if (m_Seleccionado || m_Iluminado) {
 		wAplicarColor(m_Iluminado, m_MouseDown, m_Seleccionado);
 	}
