@@ -18,6 +18,7 @@
 #include <api/iwidgetsrenderer.h>
 #include <api/ievento.h>
 #include "main/managers/widgetsmanager.h"
+#include <api/controllers/icontroladorpermisos.h>
 
 #include <iterator>
 #include <vtkgl.h>
@@ -40,6 +41,8 @@ GNC::GCS::Widgets::WMarcadoAreaBuilder::WMarcadoAreaBuilder(ModoMarcado modo, vt
 	m_pPoligonoCreado = NULL;
 	m_pImageData = NULL;
 	m_Modo = modo;
+	m_LineWidthProp = GNC::GCS::IControladorPermisos::Instance()->Get("style", "widgets.lineWidth").ObtenerValor<float>();
+	m_DraggingLineWidthProp = GNC::GCS::IControladorPermisos::Instance()->Get("style", "widgets.draggingLineWidth").ObtenerValor<float>();
 }
 
 GNC::GCS::Widgets::WMarcadoAreaBuilder::~WMarcadoAreaBuilder()
@@ -150,7 +153,7 @@ void GNC::GCS::Widgets::WMarcadoAreaBuilder::Render(GNC::GCS::Contexto3D* /*c*/)
 		return;
 	}
 
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 	wColorNormal.Aplicar();
 
 	VerticesPoligono::iterator prev = m_Vertices.begin();
@@ -403,7 +406,7 @@ void GNC::GCS::Widgets::WMarcadoArea::Render(GNC::GCS::Contexto3D* c)
 	}
 
 	GNC::GCS::Vector escala = c->RelacionImagenPantalla();
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 
 	glBegin(GL_POINTS);
 	for (VerticesPoligono::iterator it = m_Vertices.begin(); it != m_Vertices.end(); ++it) {
