@@ -14,7 +14,9 @@
 #include <api/globals.h>
 #include "wpan.h"
 #include <main/managers/widgetsmanager.h>
+
 #include <api/iwidgetsrenderer.h>
+#include <api/westilo.h>
 #include <vtkgl.h>
 #include <vtkSmartPointer.h>
 
@@ -33,6 +35,7 @@ GNC::GCS::Widgets::WPanBuilder::WPanBuilder(TWidgetsManager* pManager, const GNC
 	m_MouseDown = false;
 	m_Estado = WBS_Ninguno;
 	m_Dentro = true;
+	m_Changed = false;
 }
 
 GNC::GCS::Widgets::WPanBuilder::~WPanBuilder()
@@ -54,10 +57,15 @@ void GNC::GCS::Widgets::WPanBuilder::OnMouseEvents(GNC::GCS::Events::EventoRaton
 		vtkSmartPointer<vtkRenderWindowInteractor> rwi = evento.c->pRenderer->m_pImageViewer->GetRenderWindowInteractor();
 		vtkSmartPointer<GinkgoInteractorStyleImage2D> is = dynamic_cast<GinkgoInteractorStyleImage2D*> (rwi->GetInteractorStyle());
 
+		
 		if (is != NULL) {
 			is->EndPan();
 		}
 
+		if (m_Changed) {
+			ConsumirEvento();
+		}
+
 		m_Estado = WBS_Ninguno;
 		//m_pManager->Modificado();
 		//no se consume el evento para poder mostrar las propiedades de un widget
@@ -66,7 +74,9 @@ void GNC::GCS::Widgets::WPanBuilder::OnMouseEvents(GNC::GCS::Events::EventoRaton
 		if (m_Estado != WBS_Ninguno) {
 			return;
 		}
-		m_MouseDown = true;
+		m_Start = evento.iP;
+		m_Changed = false;
+		m_MouseDown = true;		
 
 		vtkSmartPointer<vtkRenderWindowInteractor> rwi = evento.c->pRenderer->m_pImageViewer->GetRenderWindowInteractor();
 		vtkSmartPointer<GinkgoInteractorStyleImage2D> is = dynamic_cast<GinkgoInteractorStyleImage2D*> (rwi->GetInteractorStyle());
@@ -74,9 +84,8 @@ void GNC::GCS::Widgets::WPanBuilder::OnMouseEvents(GNC::GCS::Events::EventoRaton
 		if (is != NULL) {
 			is->StartPan();
 		}
-
 		m_Estado = WBS_Creando;
-		evento.Skip(false);
+		ConsumirEvento();
 	}
 	else if (evento.Dragging() && m_MouseDown) {
 		if (m_Estado != WBS_Creando) {
@@ -88,10 +97,13 @@ void GNC::GCS::Widgets::WPanBuilder::OnMouseEvents(GNC::GCS::Events::EventoRaton
 		if (is != NULL) {
 			is->Pan();
 			is->PropagateCameraFocalAndPosition();
+			if (m_Start.DistanciaEuclideaCuadrado(evento.iP) > TVector::EpsilonDeReales()) {
+				m_Changed = true;
+			}
 		}
 		
 		//m_pManager->Modificado();
-		evento.Skip(false);
+		ConsumirEvento();
 	}
 	else if( evento.Moving() ){
 		GTRACE("Moviendose");
@@ -148,7 +160,7 @@ void GNC::GCS::Widgets::WPanBuilder::Render(GNC::GCS::Contexto3D* /*c*/)
 
 GNC::GCS::Widgets::TipoCursor GNC::GCS::Widgets::WPanBuilder::GetCursor()
 {
-	if (m_Estado == WBS_Creando) {
+	if (m_Estado == WBS_Creando && m_Changed) {
 		return GNC::GCS::Widgets::CUR_MANO_CERRADA;
 	} else {
 		return GNC::GCS::Widgets::CUR_MANO_ABIERTA;
