@@ -51,7 +51,9 @@ namespace GNC {
 
 
 			protected:
-				TVector   m_NodoMoviendose;  // Cursor				
+				TVector   m_Start;
+				bool      m_Changed;
+				TVector   m_NodoMoviendose;  // Cursor	
 				
 				bool      m_MouseDown;
 				Estado    m_Estado;
