@@ -25,6 +25,7 @@
 #include <wx/menu.h>
 #include <wx/xml/xml.h>
 #include "wrule.h"
+#include "wtextbox.h"
 
 #include <main/managers/widgetsmanager.h>
 #include <vtkgl.h>
@@ -66,7 +67,7 @@ void GNC::GCS::Widgets::WRuleBuilder::OnMouseEvents(GNC::GCS::Events::EventoRato
 		m_MouseDown = false;
 		if (m_pReglaTemp != NULL) {
 			m_pReglaTemp->m_Vertices[1] = evento.iP;;
-			m_pReglaTemp->Recalcular(evento.c->GetRenderer());
+			m_pReglaTemp->Recalcular(evento.c->GetRenderer(), true);
 			//como mínimo 2 pixels imagen
 			if (std::abs(m_pReglaTemp->Distancia()) > GNC::GCS::Vector::EpsilonDeReales() ) {
 				ConsumirEvento();
@@ -94,7 +95,7 @@ void GNC::GCS::Widgets::WRuleBuilder::OnMouseEvents(GNC::GCS::Events::EventoRato
 	} else if (evento.Dragging() && m_MouseDown) {
 		if (m_pReglaTemp != NULL) {
 			m_pReglaTemp->m_Vertices[1] = evento.iP;
-			m_pReglaTemp->Recalcular(evento.c->GetRenderer());
+			m_pReglaTemp->Recalcular(evento.c->GetRenderer(), true);
 			//std::cout << "linea (moving): " << m_Vertices[0].m_wX << ", " << m_Vertices[0].m_wY << " -> " << m_Vertices[1].m_wX << ", " << m_Vertices[1].m_wY << std::endl;
 			m_pManager->Modificado();
 		}
@@ -143,16 +144,19 @@ GNC::GCS::Widgets::WRule::WRule(IWidgetsManager* pManager, long vid, GNC::GCS::N
 {
 	m_Vertices[0] = nodos[0];
 	m_Vertices[1] = nodos[1];
-
-	m_ReservaRecursos = true;
 	m_Oculto = false;
 
 	GNC::GCS::Events::EventoModificacionImagen evt1(m_pManager->GetVista());
 	GNC::GCS::IEventsController::Instance()->Registrar(this, evt1);
+
+	m_pTextBox = new GNC::GCS::Widgets::WTextBox(m_pManager, m_VID, m_Vertices[1], GNC::GCS::Widgets::WTextBox::TNM_Dynamic, "ruleBox", "");
+	m_pTextBox->SetTexto("0");
+	m_pManager->InsertarWidget(m_pTextBox);
 }
 
 GNC::GCS::Widgets::WRule::~WRule()
 {
+	m_pManager->EliminarWidget(m_pTextBox, false);
 	LanzarEventoDestruccion();
 }
 
@@ -177,10 +181,13 @@ GNC::GCS::Widgets::WRule::WRule(IWidgetsManager* pManager, long vid, wxXmlNode*
 	}
 
 	m_MouseDown = false;
-	m_ReservaRecursos = true;
 
 	GNC::GCS::Events::EventoModificacionImagen evt1(m_pManager->GetVista());
 	GNC::GCS::IEventsController::Instance()->Registrar(this, evt1);
+
+	m_pTextBox = new GNC::GCS::Widgets::WTextBox(m_pManager, m_VID, m_Vertices[1], GNC::GCS::Widgets::WTextBox::TNM_Dynamic, "ruleBox", "");
+	m_pTextBox->SetTexto("0");
+	m_pManager->InsertarWidget(m_pTextBox);
 }
 
 wxXmlNode* GNC::GCS::Widgets::WRule::Serializar(const std::string& nombreMedico)
@@ -230,7 +237,7 @@ void GNC::GCS::Widgets::WRule::OnMouseEvents(GNC::GCS::Events::EventoRaton& even
 				m_Vertices[1] += delta;
 			}
 			LanzarEventoModificacion();
-			Recalcular(evento.c->GetRenderer());
+			Recalcular(evento.c->GetRenderer(), false);
 			ConsumirEvento();
 		}
 	}
@@ -247,7 +254,6 @@ void GNC::GCS::Widgets::WRule::OnMouseEvents(GNC::GCS::Events::EventoRaton& even
 
 		bool dentro = false;
 
-
 		m_StartPointMov = evento.iP;
 
 		const GNC::GCS::Vector& factor = evento.c->RelacionImagenPantalla();
@@ -376,7 +382,6 @@ void GNC::GCS::Widgets::WRule::OnKeyEvents(GNC::GCS::Events::EventoTeclado& even
 	}
 }
 
-
 bool GNC::GCS::Widgets::WRule::HitTest(float x, float y, const GNC::GCS::Vector& rel)
 {
 	bool hits = false;
@@ -408,9 +413,8 @@ void GNC::GCS::Widgets::WRule::Render(GNC::GCS::Contexto3D* c)
 	}
 
 	GNC::GCS::Vector escala = c->RelacionImagenPantalla();
-
 	
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 
 	// Highlights sobre nodos activos
 	if (m_Vertices[0].m_Iluminado) {
@@ -460,7 +464,6 @@ void GNC::GCS::Widgets::WRule::Render(GNC::GCS::Contexto3D* c)
 		ortogonal *= WIDGET_INCREMENTO_DETALLE_SELECCIONADO;
 	}
 
-
 	TVector f00 = m_Vertices[0] + ortogonal;
 	TVector f01 = m_Vertices[0] - ortogonal;
 	TVector f10 = puntoMedio + ortogonal;
@@ -486,74 +489,37 @@ void GNC::GCS::Widgets::WRule::Render(GNC::GCS::Contexto3D* c)
 		glVertex2d(f21.x + fsombra.x, f21.y - fsombra.y);
 	glEnd();
 
-	// Marca derecha
+	// Right mark
 	glBegin(GL_LINES);
 		glVertex2d(f20.x + fsombra.x, f20.y - fsombra.y);
 		glVertex2d(f21.x + fsombra.x, f21.y - fsombra.y);
 	glEnd();
 
-	//-- Marca izquierda
+	//-- Left mark
 	wAplicarColor(m_Iluminado || m_Vertices[0].m_Iluminado, m_MouseDown, m_Seleccionado);
 	glBegin(GL_LINES);
 		glVertex2d(f00.x, f00.y);
 		glVertex2d(f01.x, f01.y);
 	glEnd();
 
-	//-- Marca central
+	//-- Central mark
 	wAplicarColor(m_Iluminado, m_MouseDown, m_Seleccionado);
 	glBegin(GL_LINES);
 		glVertex2d(f10.x, f10.y);
 		glVertex2d(puntoMedio.x, puntoMedio.y);
 	glEnd();
 
-	// Marca derecha
+	// Right mark
 	wAplicarColor(m_Iluminado || m_Vertices[1].m_Iluminado, m_MouseDown, m_Seleccionado);
 	glBegin(GL_LINES);
 		glVertex2d(f20.x, f20.y);
 		glVertex2d(f21.x, f21.y);
 	glEnd();
 
-	//------------------------------------------------------------------------------------------
-	// Dibujado del texto de la medida
-	TexturaRegla* tr = GetTextura(c->GetRenderer());
-	if(tr->texto != m_Texto) {
-		Recalcular(c->GetRenderer());
-	}
-	GNC::GCS::TexturaCairo* tc = tr->m_textura;
-
-	if (!tc->contextoCreado) {
-		//std::cerr << "Error: Contexto no creado" << std::endl;
-		return;
-	}
-	if (!tc->texturaCargada) {
-		tc->Cargar();
-	}
-	if (tc->texturaModificada) {
-
-		tc->Actualizar();
-	}
-	//std::cout << "Dibujando..." << std::endl;
-
-	// Dibujado del texto.
-
-	// Compute display pos
-	GNC::GCS::Vector3D planePos(puntoMedio.x, puntoMedio.y, (double)c->pRenderer->m_pImageViewer->GetTindex());
-	GNC::GCS::Vector3D worldPos;
-	GNC::GCS::Vector3D displayPos;
-
-	c->pRenderer->m_pImageViewer->UnProyect2D(planePos.v, worldPos.v);
-	c->pRenderer->WorldToDisplay(worldPos.v, displayPos.v);
-
-	// Alineamiento
-
-	GNC::GCS::Vector alineacion = GNC::GCS::Vector(-m_TamTexto.x / 2.0f, (m_TamTexto.y / 2.0f) - 8.0f);
-
-	wDibujarTexturaTexto2D(c, *tc, (GNC::GCS::Vector(displayPos.x, displayPos.y) + alineacion).Redondear());
-
 	//------------------------------------------------------------------------------------------
 	// Dibujado de la linea punteada de arrastre
 	if (m_MouseDown) {
-		glLineWidth(WIDGET_GROSOR_LINEA_ARRASTRE);
+		glLineWidth(m_DraggingLineWidthProp);
 		glEnable(GL_LINE_STIPPLE);
 		wColorLineaArrastre.Aplicar();
 		glLineStipple(3, 0xAAAA);
@@ -582,41 +548,6 @@ void GNC::GCS::Widgets::WRule::Render(GNC::GCS::Contexto3D* c)
 
 		glDisable(GL_LINE_STIPPLE);
 	}
-
-	#if 0 // DEBUG
-
-	glLineWidth(WIDGET_GROSOR_LINEA);
-	glColor4d(1.0, 0.0, 0.0, 1.0);
-	GNC::GCS::Vector ddiff = m_Vertices[1] - m_Vertices[0];
-	glBegin(GL_LINES);
-		glVertex2d(0.0, 0.0);
-		glVertex2d(ddiff.x, ddiff.y);
-	glEnd();
-	
-	GNC::GCS::Vector vr = (ddiff / escala).VectorOrtonormal() * 10.0;
-
-	glColor4d(0.0, 1.0, 1.0, 1.0);
-
-	GNC::GCS::Vector inter = GNC::GCS::Vector::InterseccionEntreRectas(m_PosCursor, m_PosCursor + (vr * escala), m_Vertices[0], m_Vertices[1]);
-	
-	glBegin(GL_LINES);
-		glVertex2d(m_PosCursor.x, m_PosCursor.y);
-		glVertex2d(inter.x, inter.y);
-	glEnd();
-
-	glColor4d(0.0, 0.0, 1.0, 1.0);
-
-	glBegin(GL_LINES);
-		glVertex2d(0.0, 0.0);	
-		glVertex2d(vr.x * escala.x, vr.y * escala.y);
-	glEnd();
-
-	glBegin(GL_LINES);
-		glVertex2d(m_Vertices[0].x, m_Vertices[0].y);	
-		glVertex2d(m_Vertices[0].x + vr.x * escala.x, m_Vertices[0].y + vr.y * escala.y);
-	glEnd();
-
-	#endif
 	
 }
 
@@ -641,17 +572,7 @@ bool GNC::GCS::Widgets::WRule::GetMenuContextual(wxMenu* menuContextual, wxWindo
 	}
 }
 
-GNC::GCS::Widgets::WRule::TexturaRegla* GNC::GCS::Widgets::WRule::GetTextura(GNC::GCS::IWidgetsRenderer* renderer)
-{
-	if(m_mapaRecursos.find(renderer) == m_mapaRecursos.end()) {
-		TexturaRegla* pTextura = new TexturaRegla();
-		m_mapaRecursos[renderer] = pTextura;
-		Recalcular(renderer);
-	}
-	return m_mapaRecursos[renderer];
-}
-
-void GNC::GCS::Widgets::WRule::Recalcular(GNC::GCS::IWidgetsRenderer* renderer)
+void GNC::GCS::Widgets::WRule::Recalcular(GNC::GCS::IWidgetsRenderer* renderer, bool building)
 {
 	GNC::GCS::Vector3D worldPosition0, worldPosition1, wDiff;
 	GNC::GCS::Vector iDiff;
@@ -664,7 +585,6 @@ void GNC::GCS::Widgets::WRule::Recalcular(GNC::GCS::IWidgetsRenderer* renderer)
 		renderer->m_pImageViewer->CoordenadasImagenACoordenadasMundo(imagePosition0, worldPosition0.v);
 		renderer->m_pImageViewer->CoordenadasImagenACoordenadasMundo(imagePosition1, worldPosition1.v);
 	}
-		
 
 	//std::cout << "--- Recalculando... " << std::endl;
 	m_Modificado = true;
@@ -703,62 +623,14 @@ void GNC::GCS::Widgets::WRule::Recalcular(GNC::GCS::IWidgetsRenderer* renderer)
 
 	std::string medida = os.str();
 
-	if (renderer != NULL) {
-
-		TexturaRegla* tr = GetTextura(renderer);
-		if (m_Texto != medida || tr->texto != medida) {
-			tr->texto = medida;
-			m_Texto = medida;
-			//std::cout << "distancia = " << m_Texto << std::endl;
-			GNC::GCS::TexturaCairo* tc = tr->m_textura;
-
-			if (!tc->contextoCreado) {
-				tc->Redimensionar(2, 2);
-			}
-
-			cairo_font_options_t* options;
-			options = cairo_font_options_create ();
-
-			cairo_select_font_face (tc->cr, "Arial", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-			cairo_set_font_size(tc->cr, WIDGET_SIZE_FUENTE);
-			cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
-			cairo_set_font_options(tc->cr, options);
-
-			m_TamTexto = GNC::GCS::GLHelper::calcularBoundingBox((*tc), m_Texto, m_AnchoMaximo); // Tamaño de la region en pixels
-
-			tc->Redimensionar(std::ceil(m_TamTexto.x), std::ceil(m_TamTexto.y));
-			m_TamTexto.Asignar(tc->ancho, tc->alto);
-
-			cairo_select_font_face (tc->cr, "Arial", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-			cairo_set_font_size(tc->cr, WIDGET_SIZE_FUENTE);
-			cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
-			cairo_set_font_options(tc->cr, options);
-
-			cairo_set_operator(tc->cr, CAIRO_OPERATOR_SOURCE);
-			cairo_set_source_rgba(tc->cr, 0.0f, 0.0f, 0.0f, 0.0f);
-			cairo_paint(tc->cr);
-
-			cairo_font_options_destroy(options);
-			options = NULL;
-
-			cairo_set_source_rgba (tc->cr, 1.0f, 1.0f, 1.0f, 1.0f);
-			GNC::GCS::GLHelper::dibujarTexto((*tc), m_Texto, m_AnchoMaximo);
-		}
-	}
-}
-
-void GNC::GCS::Widgets::WRule::LiberarRecursos(GNC::GCS::IWidgetsRenderer* renderer)
-{
-	TMapaRecursos::iterator it = m_mapaRecursos.find(renderer);
-	if(it!=m_mapaRecursos.end()) {
-		delete (*it).second;
-		m_mapaRecursos.erase(it);
+	m_pTextBox->SetTexto(medida);
+	if (building) {
+		m_pTextBox->SetPosition(m_Vertices[0].PuntoMedio(m_Vertices[1]));
 	}
 }
 
 //region Interfaz de eventos ginkgo
 
-
 //endregion
 void GNC::GCS::Widgets::WRule::InsertarPropiedades(TListaMapasPropiedades &listaMapaPropiedades)
 {
@@ -808,41 +680,11 @@ void GNC::GCS::Widgets::WRule::InsertarPropiedades(TListaMapasPropiedades &lista
 
 void GNC::GCS::Widgets::WRule::OffscreenRender(GNC::GCS::Contexto3D* c)
 {
-	GNC::GCS::Vector Diff = m_Vertices[1] - m_Vertices[0];
-	GNC::GCS::Vector TamTexto;
-
-	std::stringstream os;
-	os.setf(ios::floatfield, ios::fixed );
-	os.precision(2);
-	os.fill('0');
-
-	double spacing[3] = {0.0, 0.0, 0.0};
-	bool hasSpacing = m_pManager->GetVista()->GetEstudio()->GetSpacingActive(spacing[0], spacing[1], spacing[2]);
-	float metricaDistancia = m_Distancia;
-	if (hasSpacing) {
-		if (metricaDistancia > 1000.0f) {
-			os << metricaDistancia / 1000.0f << " m.";
-		}
-		else if (metricaDistancia > 10.0f) {
-			os << metricaDistancia / 10.0f << " cm.";
-		}
-		else if (metricaDistancia < 1.0f) {
-				os << metricaDistancia * 1000.0f << " µm.";
-			}
-		else {
-			os << metricaDistancia << " mm.";
-		}
-	} else {
-		os << metricaDistancia << " px.";
-	}
-
-	std::string medida = os.str();
-
 	const GNC::GCS::Vector& escala = c->RefRelacionMundoPantallaOffscreen();
 
 	GNC::GCS::Vector vert[2] = {c->Reproyectar(m_Vertices[0]) * c->factorReescalado, c->Reproyectar(m_Vertices[1]) * c->factorReescalado };
 
-	glLineWidth(WIDGET_GROSOR_LINEA);
+	glLineWidth(m_LineWidthProp);
 
 	// Dibujado de la regla
 	wColorNormal.AplicarCairo(c->cr);
@@ -881,36 +723,10 @@ void GNC::GCS::Widgets::WRule::OffscreenRender(GNC::GCS::Contexto3D* c)
 	cairo_line_to(c->cr, f21.x , f21.y );
 	cairo_stroke(c->cr);
 
-	//------------------------------------------------------------------------------------------
-	//// Dibujado del texto de la medida
-	cairo_font_options_t* options;
-	options = cairo_font_options_create ();
-
-	cairo_select_font_face (c->cr, "Arial", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-	cairo_set_font_size(c->cr, std::max(WIDGET_SIZE_FUENTE * escala.x, (double)8.0f));
-	cairo_font_options_set_antialias (options, CAIRO_ANTIALIAS_NONE);
-	cairo_set_font_options(c->cr, options);
-
-	TamTexto = GNC::GCS::Widgets::HelperTexto::calcularBoundingBox(c, medida, m_AnchoMaximo * escala.x); // Tamaño de la region en pixels
-
-	cairo_set_source_rgba (c->cr, 1.0f, 1.0f, 1.0f, 1.0f);
-	cairo_save(c->cr);
-	GNC::GCS::Vector puntoTexto( puntoMedio.x - (TamTexto.x / 2.0f), puntoMedio.y - TamTexto.y);
-	puntoTexto.Redondear();
-	cairo_translate(c->cr, puntoTexto.x, puntoTexto.y);
-	GNC::GCS::Widgets::HelperTexto::dibujarTexto(c, medida, m_AnchoMaximo * escala.x);
-	cairo_restore(c->cr);
-
-	cairo_font_options_destroy(options);
-
 }
 
 void GNC::GCS::Widgets::WRule::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
 {
-	if (EstaOculto())
-	{
-		return;
-	}
 	if (evt->GetCodigoEvento() == ginkgoEVT_Core_ModificacionImagen)
 	{
 		GNC::GCS::Events::EventoModificacionImagen* pEvt = dynamic_cast<GNC::GCS::Events::EventoModificacionImagen*>(evt);
@@ -920,7 +736,7 @@ void GNC::GCS::Widgets::WRule::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
 		}
 		if(pEvt->GetTipo() == GNC::GCS::Events::EventoModificacionImagen::ImagenRecalibrada)
 		{
-			Recalcular(m_pManager->GetRendererActivo());
+			Recalcular(m_pManager->GetRendererActivo(), false);
 		}
 	}
 }
