@@ -124,7 +124,7 @@ void GNC::GCS::Widgets::WStaticRule::Render(GNC::GCS::Contexto3D* c)
 		GNC::GCS::Vector ruleFragments(10.0, 10.0);
 		
 		// Dibujado de la regla		
-		glLineWidth(WIDGET_GROSOR_LINEA);
+		glLineWidth(m_LineWidthProp);
 
 		const double ruleMeasureScreen[2] = {ruleMeasure.x / screenToWorld.x, ruleMeasure.y / screenToWorld.y};
 		const double xLimitsRule[2] = {(viewport[2]/2)-(0.5*ruleMeasureScreen[0]), (viewport[2]/2)+(0.5*ruleMeasureScreen[0])};
