@@ -30,6 +30,7 @@ GNC::GCS::Widgets::WZoomBuilder::WZoomBuilder(TWidgetsManager* pManager, const G
 	m_Estado = WBS_Ninguno;
 	m_Dentro = true;
 	m_Start = 0.0;
+	m_Changed = false;
 	m_Stop = 0.0;
 }
 
@@ -58,12 +59,15 @@ void GNC::GCS::Widgets::WZoomBuilder::OnMouseEvents(GNC::GCS::Events::EventoRato
 		}
 
 		m_Estado = WBS_Ninguno;
-		ConsumirEvento();
+		if (m_Changed) {
+			ConsumirEvento();
+		}
 	}
 	else if (evento.ButtonDown(m_ButtonMask)) {
 		if (m_Estado != WBS_Ninguno) {
 			return;
 		}
+		m_Changed = false;
 		m_MouseDown = true;
 		
 		m_Start = evento.sY;
@@ -81,8 +85,8 @@ void GNC::GCS::Widgets::WZoomBuilder::OnMouseEvents(GNC::GCS::Events::EventoRato
 		
 		double delta = (m_Start - m_Stop) / 1.0;
 		
-		
 		if (delta != 0.0) {
+			m_Changed = true;
 			int steps = 0;
 			if (delta > 0.0)  {
 				steps = (int)std::floor(delta);
