@@ -1589,7 +1589,7 @@ bool wxThumbnailItem::DrawBackground(wxDC& dc, wxThumbnailCtrl* ctrl, const wxRe
     if (!filename.IsEmpty())
     {
         wxString file, name, ext;
-        wxSplitPath(filename, & file, & name, & ext);
+        wxFileName::SplitPath(filename, &file, &name, &ext);
         if (!ext.IsEmpty() && (ctrl->GetWindowStyle() & wxTH_EXTENSION_LABEL))
         {
             ext.MakeUpper();
