@@ -24,6 +24,7 @@
 ////@end includes
 
 #include <wx/dir.h>
+#include <wx/filename.h>
 #include "thumbnailwidget.h"
 // #include "thumbnailitem.h"
 // #include "utils.h"
@@ -160,7 +161,7 @@ bool wxThumbnailWidget::ShowToolTips()
 }
 
 /*!
- * wxEVT_COMMAND_TREE_SEL_CHANGED event handler for ID_IMAGE_BROWSER_DIRCTRL
+ * wxEVT_COMMAND_TREELIST_SELECTION_CHANGED event handler for ID_IMAGE_BROWSER_DIRCTRL
  */
 
 void wxThumbnailWidget::OnImageBrowserDirctrlSelChanged( wxTreeEvent& event )
@@ -176,7 +177,7 @@ void wxThumbnailWidget::OnImageBrowserDirctrlSelChanged( wxTreeEvent& event )
         return;
     }
 
-    wxTreeItemId id = event.GetItem();
+	wxTreeItemId id = event.GetItem();
     if (id)
     {
         wxDirItemData* data = (wxDirItemData*) m_dirCtrl->GetTreeCtrl()->GetItemData(id);
@@ -294,7 +295,7 @@ static int DetermineImageType(const wxString& filename)
 {
     wxString path, name, ext;
 
-    wxSplitPath(filename, & path, & name, & ext);
+    wxFileName::SplitPath(filename, &path, &name, &ext);
 
     ext.MakeLower();
     if (ext == wxT("jpg") || ext == wxT("jpeg"))
