@@ -19,6 +19,7 @@
 #include "visualizatorcontroller.h"
 
 #include <visualizator/tools/overlaystool.h>
+#include <visualizator/tools/ecgruletool.h>
 
 #include <visualizator/dialogos/contenedorherramientas.h>
 #include <main/gui/import/generaldata.h>
@@ -110,7 +111,7 @@ GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::G
 
 	//registrar herramientas
 	GNC::GCS::IToolsRegistry::Instance()->RegisterTool(new GNKVisualizator::OverlaysTool());
-
+	GNC::GCS::IToolsRegistry::Instance()->RegisterTool(new GNKVisualizator::ECGRuleTool());
 }
 
 GNKVisualizator::ControladorAtencionPrimaria::~ControladorAtencionPrimaria()
@@ -162,6 +163,7 @@ void GNKVisualizator::ControladorAtencionPrimaria::RegistrarVistas()
 	listaModalidades.push_back(std::string("GM")); //General Microscopy
 	listaModalidades.push_back(std::string("SM")); //Slide Microscopy
 	listaModalidades.push_back(std::string("XC")); //External-camera Photography
+	listaModalidades.push_back(std::string("DOC")); //DOCUMENT (PDF, WORD...)
 	listaModalidades.push_back(std::string("PR")); //Presentation State
 	//listaModalidades.push_back(std::string("SR")); //SR Document
 	listaModalidades.push_back(std::string("IVUS")); //Intravascular Ultrasound
@@ -189,6 +191,7 @@ void GNKVisualizator::ControladorAtencionPrimaria::RegistrarVistas()
 
 	listaModalidades.clear();
 	listaModalidades.push_back(std::string("ECG")); //Electrocardiography
+	listaModalidades.push_back(std::string("EC")); //Electrocardiography
 	listaModalidades.push_back(std::string("HD")); //Hemodynamic Waveform
 
 	listaUIDsImportacion.clear();
