@@ -408,7 +408,7 @@ void GNKVisualizator::ECGStudy::InitializeContext(long pkSeries)
 		rutas.push_back((*itFile).real_path);
 	}
 
-	GNC::GCS::IStudyContext::InitializeContext(rutas);
+	GNC::GCS::IStudyContext::DoInitiallizeContext(rutas);
 
 	for (int i = 0; i < (int)rutas.size(); ++i) {
 		ECGFiles.push_back(NULL);
@@ -497,6 +497,33 @@ const std::string& GNKVisualizator::ECGStudy::GetDiagnosis()
 	return ECGFiles[ActiveFileIndex]->GetDiagnosis();
 }
 
+std::string GNKVisualizator::ECGStudy::getMeasureText(bool isVertical, float measure)
+{
+	std::ostringstream ostr;
+	ostr.setf(ios::floatfield, ios::fixed );
+	ostr.precision(2);
+	ostr.fill('0');
+
+	TListChannelInfo& chanelInfo = GetListOfChannels();
+	if (!chanelInfo.empty())
+	{
+		//ChannelInfo& frontValue = chanelInfo.front();
+		if (isVertical)
+		{
+			ostr << (measure /10) << " mV";
+		}
+		else
+		{
+			//siempre esta a 25 mm/s
+			ostr << (measure /(  25 )) << " s";
+		}
+	} else {
+		LOG_ERROR("ECGStudy", "Error getting measure");
+	}
+
+	return ostr.str();
+}
+
 void GNKVisualizator::ECGStudy::LoadChannels()
 {
 	if (!ECGFiles[ActiveFileIndex].IsValid()) 
