@@ -28,7 +28,7 @@ namespace GNKVisualizator {
 		VisualizatorStudy();
 		~VisualizatorStudy();
 
-		virtual void InitializeContext(long seriesPk);
+		void InitializeContext(long seriesPk);
 
 		//overlays...
 		bool TieneOverlaysImagenActiva();
