@@ -21,13 +21,11 @@ namespace AtencionPrimaria {
 		{
 		public:
 			typedef enum {
-				Play,
-				Stop,
 				Scroll,
 				Dessincronizar
 			} TipoSincronizacion;
 
-			EventoSincronizacion(GNC::GCS::IVista* pVista, TipoSincronizacion  tipo = Play, int posicion = 0, bool relativa = true) : GNC::GCS::Events::IEvent(ginkgoEVT_GNKVisualizator_EventoSincronizacion, ginkgoAmbitoAtencionPrimaria, 100, pVista)
+			EventoSincronizacion(GNC::GCS::IVista* pVista, TipoSincronizacion  tipo = Scroll, int posicion = 0, bool relativa = true) : GNC::GCS::Events::IEvent(ginkgoEVT_GNKVisualizator_EventoSincronizacion, ginkgoAmbitoAtencionPrimaria, 100, pVista)
 			{
 				m_posicion = posicion;
 				m_relativa = relativa;
@@ -49,12 +47,6 @@ namespace AtencionPrimaria {
 			virtual void pushInfo(std::ostream& out) const {
 				out << "Tipo = ";
 				switch (m_tipo) {
-					case Play:
-						out << "Play";
-						break;
-					case Stop:
-						out << "Stop";
-						break;
 					case Scroll:
 						out << "Scroll";
 						break;
