@@ -70,6 +70,7 @@ GNKVisualizator::WaveFormView::WaveFormView(const GNC::GCS::Ptr<GNKVisualizator:
 
 GNKVisualizator::WaveFormView::~WaveFormView()
 {
+	DetenerPipeline();
 }
 
 //----------------------------------------------------------------------------------------------------
@@ -82,9 +83,8 @@ void GNKVisualizator::WaveFormView::OnCargaIniciada()
 }
 
 // Paso 1: Cargar los ficheros en memoria. Metodo NO sincrono con la interfaz.
-void GNKVisualizator::WaveFormView::CargarEstudio(GNC::GCS::IComando* pCmdInvocador)
+void GNKVisualizator::WaveFormView::CargarEstudio(GNC::GCS::IComando* /*pCmdInvocador*/)
 {
-	
 }
 
 // Finalizacion de la carga. Metodo sincrono con la interfaz.
