@@ -29,6 +29,8 @@
 #include <api/dicom/imodelodicom.h>
 #include <api/westilo.h>
 
+#include <api/controllers/icontroladorpermisos.h>
+
 #include <eventos/modificacionimagen.h>
 
 #include <main/entorno.h>
@@ -52,13 +54,16 @@
 
 // Propiedades visuales
 
-#define COLOR_FONDO 0.99, 0.99, 0.99, 1.0
+#define COLOR_FONDO 0.9f, 0.9f, 0.9f, 1.0f
 
 // Num de pixels pantalla minimo para que aparezca la rejilla
 #define GRID_1MM_NEAR_THRESHOLD 0.7
 #define GRID_5MM_FAR_THRESHOLD 0.7
 #define GRAPH_FAR_THRESHOLD 0.7
 
+//greater that this text wont be shown
+#define TEXT_FAR_THRESHOLD 1.2
+
 #define GRID_1MM_LINE_WIDTH 0.25f
 #define GRID_1MM_LINE_COLOR 1.0f, 0.0f, 0.0f, 0.3f
 
@@ -75,6 +80,8 @@
 
 #define LEAD_TEXT_COLOR 1.0f, 0.1f, 0.1f, 1.0f
 
+#define REFERENCE_WIDTH 0.4f //0.4 seconds
+
 
 static GNC::GCS::Vector WinMarginRel[2] = {
 	GNC::GCS::Vector(0.0, 0.0), GNC::GCS::Vector(1.0, 1.0)
@@ -178,18 +185,16 @@ namespace GNKVisualizator {
 
 		TexturasCanalECG::TexturasCanalECG() {
 			tl = new GNC::GCS::TexturaCairo();
-			tu = new GNC::GCS::TexturaCairo();
+			tl->Redimensionar(2, 2);
 		}
 
 		TexturasCanalECG::~TexturasCanalECG() {
 			delete tl;
-			delete tu;
 		}
 
 		void TexturasCanalECG::Destruir()
 		{
 			tl->Destruir();
-			tu->Destruir();
 		}
 
 		class Channel {
@@ -209,21 +214,23 @@ namespace GNKVisualizator {
 			{
 			}
 			
-			void Plot(GNC::GCS::Contexto3D* c, GNC::GCS::TexturaCairo* tl, GNC::GCS::TexturaCairo* /*tu*/) {
+			void Plot(GNC::GCS::Contexto3D* c, GNC::GCS::TexturaCairo* tl) {
 				
 				GNC::GCS::Vector sample;
 				GNC::GCS::Vector textSize;
 
+				
 				if (!tl->EsValida() || TamTitle.EsNulo()) {
-					#define m_AnchoMaximo 100.0f
-					std::string Title = Info.GetTitle();
-					textSize = GNC::GCS::GLHelper::calcularBoundingBox((*tl), Title, m_AnchoMaximo); // Tamao de la region en pixels
-
+					const std::string Title = Info.GetTitle();
+					tl->SetFontBold(WIDGETS_TEXT_FONT_FAMILY, GNC::GCS::IControladorPermisos::Instance()->Get("style", "ecg.label.fontSize").ObtenerValor<float>());
+					textSize = GNC::GCS::GLHelper::calcularBoundingBox((*tl), Title, false, 300.0f); // Tamao de la region en pixels
 					tl->Redimensionar(std::ceil(textSize.x), std::ceil(textSize.y));
 					textSize.Asignar(tl->ancho, tl->alto);
 					
+					tl->SetFontBold(WIDGETS_TEXT_FONT_FAMILY, GNC::GCS::IControladorPermisos::Instance()->Get("style", "ecg.label.fontSize").ObtenerValor<float>());
+					textSize = GNC::GCS::GLHelper::calcularBoundingBox((*tl), Title, false, 300.0f); // Tamao de la region en pixels
 					GNC::GCS::GLHelper::TColor col(LEAD_TEXT_COLOR);
-					TamTitle = GNC::GCS::GLHelper::dibujarTexto(*tl, Title, col);
+					TamTitle = GNC::GCS::GLHelper::dibujarTexto(*tl, Title, col, false);
 				}
 
 				if (!tl->texturaCargada) {
@@ -231,49 +238,25 @@ namespace GNKVisualizator {
 				}
 				if (tl->texturaModificada) {
 					tl->Actualizar();
-				}				
-				
-				GNC::GCS::Vector quad[4];
-				
-				GNC::GCS::Vector pl;
-				GNC::GCS::Vector tSize;
-				
-				pl = Pos - (GNC::GCS::Vector(-10, TamTitle.y) * c->RefRelacionImagenPantalla());
+				}	
 
-				/*
-				 * Posicion del Quad
-				 *  q3   q2
-				 *  q0   q1
-				 * */
+				if (c->RefRelacionImagenPantalla().x < TEXT_FAR_THRESHOLD ) {
+					//compute display position...if it's too far labels doesn't show well
+					GNC::GCS::Vector planePos;
+					planePos = Pos;
+					GNC::GCS::Vector3D worldPos;
+					GNC::GCS::Vector3D displayPos;
 
-				GNC::GCS::Matriz matrizRotacion = GNC::GCS::Matriz::MatrizRotacion(c->rotacion);
-				
-				tSize = (GNC::GCS::Vector(tl->ancho, tl->alto)) * c->RefRelacionImagenPantalla();
+					c->pRenderer->m_pImageViewer->UnProyect2D(planePos.v, worldPos.v);
+					c->pRenderer->WorldToDisplay(worldPos.v, displayPos.v);
 
-				quad[0] = pl + ( matrizRotacion.ProductoMatricial(GNC::GCS::Vector( 0.0,     0.0     ) ) );
-				quad[1] = pl + ( matrizRotacion.ProductoMatricial(GNC::GCS::Vector( tSize.x, 0.0     ) ) );
-				quad[2] = pl + ( matrizRotacion.ProductoMatricial(GNC::GCS::Vector( tSize.x, tSize.y ) ) );
-				quad[3] = pl + ( matrizRotacion.ProductoMatricial(GNC::GCS::Vector( 0.0,     tSize.y ) ) );
+					//ensure label is shown...
+					displayPos.x = std::max(0.0, displayPos.x);
+					displayPos.y = std::max(0.0, displayPos.y);
 
-				tl->Render(quad, c->flipHorizontal, c->flipVertical, c->rotacion);
-
-				/*
-
-				pl = Pos + GNC::GCS::Vector( 600.0, 0.0) - (GNC::GCS::Vector(0.0, TamTitle.y / 2.0) * c->RefRelacionImagenPantalla());
-				//
-				// Posicion del Quad
-				//  q3   q2
-				//  q0   q1
-				//
-				tSize = (GNC::GCS::Vector(tu->ancho, tu->alto)) * c->RefRelacionImagenPantalla();
-
-				quad[0] = pl + ( matrizRotacion.ProductoMatricial(GNC::GCS::Vector( 0.0,     0.0     ) ) );
-				quad[1] = pl + ( matrizRotacion.ProductoMatricial(GNC::GCS::Vector( tSize.x, 0.0     ) ) );
-				quad[2] = pl + ( matrizRotacion.ProductoMatricial(GNC::GCS::Vector( tSize.x, tSize.y ) ) );
-				quad[3] = pl + ( matrizRotacion.ProductoMatricial(GNC::GCS::Vector( 0.0,     tSize.y ) ) );
-
-				tu->Render(quad, c->flipHorizontal, c->flipVertical, c->rotacion);
-				*/
+					wDibujarTexturaTexto2D(c, *tl, displayPos.v);
+				}
+								
 
 				if (c->RefRelacionImagenPantalla().x > GRAPH_FAR_THRESHOLD ) {
 					glColor4d(GRAPH_LINE_COLOR_FAR);
@@ -284,8 +267,31 @@ namespace GNKVisualizator {
 					glLineWidth(GRAPH_LINE_WIDTH);
 				}
 
-				glBegin(GL_LINE_STRIP);
+				//draw reference...
 				int i = 0;
+				{
+					//2 squares of 0.2 sec
+					float referenceWidth = Info.SamplingFrecuency * REFERENCE_WIDTH;
+					if (!Info.Samples.empty())
+					{
+						glBegin(GL_LINE_STRIP);
+						do
+						{
+							if ((i < referenceWidth/4) || (i >3*referenceWidth/4))
+							{
+								sample = Pos + (GNC::GCS::Vector(i, 0) * Rel);
+							}	
+							else
+							{
+								sample = Pos + (GNC::GCS::Vector(i, -(1000) * Info.Multiplier * Info.Sensitivity * Info.SensitivityCorrectionFactor) * Rel);
+							}
+							glVertex3d( sample.x, sample.y, 0.0);
+						} while (++i < referenceWidth);
+						glEnd();
+					}
+				}
+
+				glBegin(GL_LINE_STRIP);
 				for (GNKVisualizator::ChannelInfo::TVectorSamples::const_iterator it = Info.Samples.begin(); it != Info.Samples.end(); ++it, ++i)
 				{
 					sample = Pos + (GNC::GCS::Vector(i, -(*it) * Info.Multiplier * Info.Sensitivity * Info.SensitivityCorrectionFactor) * Rel);
@@ -324,13 +330,14 @@ namespace GNKVisualizator {
 				if (listInfoChannels.size() == 0) {
 					return;
 				}
-
-				NumSamples = listInfoChannels.front().NumSamples;
 				NumChannels = listInfoChannels.size();
 				SamplingFreq = listInfoChannels.front().SamplingFrecuency;
+				//we have to add reference width (0.4 seconds)
+				const float referenceWidth = SamplingFreq*REFERENCE_WIDTH;
+				NumSamples = listInfoChannels.front().NumSamples + referenceWidth;
 				
 				GNC::GCS::Vector WinMargin[2] = {ImageSize * WinMarginRel[0], ImageSize * WinMarginRel[1]};
-				GNC::GCS::Vector WinSize = WinMargin[1] - WinMargin[0];				
+				GNC::GCS::Vector WinSize = WinMargin[1] - WinMargin[0];	
 				
 				GNC::GCS::Vector CSize ( WinSize.x / (double) NumSamples, WinSize.y / (double) NumChannels);
 				GNC::GCS::Vector COff(WinMargin[0].x, WinMargin[0].y  + (0.5 * CSize.y));
@@ -351,7 +358,7 @@ namespace GNKVisualizator {
 				for (iterator it = begin(); it != end(); ++it, i++)
 				{
 					Channel& c = *it;
-					c.Plot(ct, rec->Texturas[i]->tl, rec->Texturas[i]->tu);
+					c.Plot(ct, rec->Texturas[i]->tl);
 				}
 			}
 
@@ -590,7 +597,7 @@ void GNKVisualizator::Widgets::WECG::Ocultar(bool oculto)
 void GNKVisualizator::Widgets::WECG::LiberarRecursos(GNC::GCS::IWidgetsRenderer* pKey)
 {
 	TMapaRecursos::iterator it = m_mapaRecursos.find(pKey);
-	if(it!=m_mapaRecursos.end()) {
+	if(it != m_mapaRecursos.end()) {
 		RecursosECG* rec = (*it).second;
 		rec->Dealloc();
 		delete rec;
