@@ -373,24 +373,21 @@ inline bool my_isnan(float x)
 }
 
 //region "Interfaz de impresion de overlays de widgets"
-void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Contexto3D* c, GNC::GCS::Vector& /*boundingBox*/)
+std::string GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, vtkGinkgoImageViewer* /*pViewer*/)
 {
 	if (!w->EsMarcador()) {
-		return;
+		return "";
 	}
-	
-	const GNC::GCS::Vector& escala = c->RelacionImagenPantalla();
 
 	GNC::GCS::TexturaCairo tc;
 
-	double posMundo[3] = {0.0f,0.0f,0.0f};
+	double posMundo[4] = {0.0, 0.0, 0.0, 1.0};
 	GNC::GCS::Vector            posimagen;
 	GNC::GCS::Vector            puntoAnclaje;
 	GNC::GCS::Vector            bBox[2];
 
 	GNC::GCS::Vector            tamTexto;
 
-	std::string                 texto;
 	std::ostringstream          os;
 
 	os.setf(ios::floatfield, ios::fixed );
@@ -403,11 +400,10 @@ void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Cont
 
 	w->GetPosicion(posimagen);
 	{
-		double arrIm[2] = {posimagen.x, posimagen.y};
+		double arrIm[3] = {posimagen.x, posimagen.y, 0.0};
 		ViewImage2D->CoordenadasImagenACoordenadasMundo(arrIm, posMundo);
 	}
 
-	w->GetPuntoAnclaje(puntoAnclaje, escala);
 	w->GetBoundingBox(bBox[0], bBox[1]);
 	//el bounding box hay que cambiarlo a coordenadas pixel
 	{
@@ -519,7 +515,7 @@ void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Cont
 
 				for (; it != recorrido.end(); ++it) {
 					double arrIm[3] = {(*it).x, (*it).y, 0.0};
-					double mundoTmp[3];
+					double mundoTmp[4];
 					ViewImage2D->CoordenadasImagenACoordenadasMundo(arrIm, mundoTmp);
 					os << " -> " << mundoTmp[0] << ", " << mundoTmp[1] << ", " << mundoTmp[2];
 				}
@@ -608,69 +604,9 @@ void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Cont
 		os.clear();
 	}
 
-
-	texto = os.str();
-	if(texto.size()>0){
-
-		const float anchoMaximo = -1.0f;
-		const float tamFuente = 12.0f;
-
-		tc.Redimensionar(2, 2);
-
-		tc.SetFontNormal("Arial", tamFuente);
-			
-
-		tamTexto = GNC::GCS::GLHelper::calcularBoundingBox(tc, texto, anchoMaximo); // Tamaño de la region en pixels
-
-		tc.Redimensionar(std::ceil(tamTexto.x), std::ceil(tamTexto.y));
-		tamTexto.Asignar(tc.ancho, tc.alto);
-
-
-		tc.SetFontNormal("Arial", tamFuente);
-
-		tc.SetSourceColor(1.0f, 1.0f, 1.0f, 1.0f);
-		GNC::GCS::GLHelper::dibujarTexto(tc, texto, anchoMaximo);
-
-		tc.Cargar();
-
-		GNC::GCS::Vector quad[4];
-
-		// Dibujado del texto.
-
-		// Alineamiento
-		GNC::GCS::Vector offset = GNC::GCS::Vector(10.0f, -10.0f) * escala;
-
-		/*
-		 * Posicion del Quad
-		 *  q3   q2
-		 *  q0   q1
-		 * */
-
-		quad[0].Asignar(0,0);
-		quad[2] = tamTexto * escala;
-
-		quad[1].Asignar(quad[2].x, quad[0].y);
-		quad[3].Asignar(quad[0].x, quad[2].y);
-
-		// Rotacion y translacion
-
-		GNC::GCS::Matriz mRot = GNC::GCS::Matriz::MatrizRotacion(c->rotacion);
-
-		quad[0] = mRot.ProductoMatricial(quad[0]) + puntoAnclaje;
-		quad[1] = mRot.ProductoMatricial(quad[1]) + puntoAnclaje;
-		quad[2] = mRot.ProductoMatricial(quad[2]) + puntoAnclaje;
-		quad[3] = mRot.ProductoMatricial(quad[3]) + puntoAnclaje;
-
-		wDibujarTexturaTextoDecorada(tc, quad, escala, c->flipHorizontal, c->flipVertical, c->rotacion);
-
-		tc.Descargar();
-	}
+	return os.str();
 }
 
-void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidgetBuilder* /*wb*/, GNC::GCS::Contexto3D* /*c*/, GNC::GCS::Vector& /*boundingBox*/)
-{
-	//std::cout << "GVistaPASI::ImprimirOverlay() " << wb << std::endl;
-}
 //endregion
 
 
