@@ -35,15 +35,16 @@
 
 #include <resources/visualizatorresourcesmanager.h>
 #include <export/tools/iherramientascore.h>
+#include <visualizator/export/tools/ivisualizatortools.h>
 #include <export/contracts/iwidgetscontract.h>
 #include <export/contracts/irulecontract.h>
 #include <api/toolsystem/itoolcontroller.h>
 #include <api/toolsystem/itool.h>
 
-#define ANNOTATOR_TEXT_COLOR 0.1f, 0.1f, 0.1f, 1.0f
 
 #define ID_BUTTON_METADATA 0
 #define ID_BUTTON_CORNER_ANNOTATIONS 1
+#define CUSTOM_ANNOTATOR_TEXT_COLOR 0.1f, 0.1f, 0.1f, 1.0f
 
 namespace GNKVisualizator 
 {
@@ -58,14 +59,7 @@ namespace GNKVisualizator
 			~GWaveformViewDelegate()
 			{
 			}
-
-			//contrato widgets
-			vtkGinkgoImageViewer* GetViewerActivo()
-			{
-				return GView->ViewImage2D;
-			}
-
-
+			
 			GNC::GCS::IWidgetsManager* GetManager()
 			{ 
 				return GView->m_pManager; 
@@ -147,7 +141,7 @@ namespace GNKVisualizator
 			pToolBar->AddTool(HCore_Zoom, (GNC::GCS::IWidgetsContract*) Delegate);
 			pToolBar->AddTool(HCore_Pan, (GNC::GCS::IWidgetsContract*) Delegate);
 			pToolBar->AddTool(HCore_Angulo, (GNC::GCS::IWidgetsContract*) Delegate);
-			pToolBar->AddTool(HCore_Rule, (GNC::GCS::IRuleContract*) Delegate);
+			pToolBar->AddTool(HGNKVisualizator_ECGRule, (GNC::GCS::IWidgetsContract*) Delegate);
 			pToolBar->AddTool(HCore_Nota, (GNC::GCS::IWidgetsContract*) Delegate);
 			pToolBar->AddTool(HCore_Marcado, (GNC::GCS::IWidgetsContract*) Delegate);
 			//view menu...
@@ -159,6 +153,7 @@ namespace GNKVisualizator
 			pToolBar->AddTool(HCore_Reset, (GNC::GCS::IWidgetsContract*) Delegate);
 
 			pToolBar->AddTool(HCore_SecondaryCapture, (GNC::GCS::IWidgetsContract*) Delegate);
+			pToolBar->AddTool(HCore_ImageExport, (GNC::GCS::IWidgetsContract*) Delegate);
 			//tools
 			pToolBar->AddTool(HCore_ShowDicomTags, (GNC::GCS::IViewContract*) View);
 			pToolBar->AddTool(HCore_ShowHistory, (GNC::GCS::IViewContract*) View);
@@ -270,7 +265,7 @@ namespace GNKVisualizator
 						if (w->GetVID() == -1) {
 							GNC::GCS::Widgets::WAnotador* wac = dynamic_cast<GNC::GCS::Widgets::WAnotador*> (w);
 							if (wac != NULL) {
-								wac->SetTextColor(GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR));
+								wac->SetTextColor(GNC::GCS::GLHelper::TColor(CUSTOM_ANNOTATOR_TEXT_COLOR));
 							}
 						}
 					}
@@ -280,24 +275,23 @@ namespace GNKVisualizator
 
 		void GWaveformView::StopPipeline()
 		{
-			m_pManager->OcultarTodosLosWidgets(true, 666);
-			m_pManager->DisableAnimation();
-			m_pManager->Render();
+			View->GetToolController()->SaveStatus("viewer.waveform");
+			if (m_pManager != NULL) {
+				m_pManager->OcultarTodosLosWidgets(true, 666);
+				m_pManager->DisableAnimation();
+				m_pManager->Render();
+			}
 		}
 
 		void GWaveformView::OnFinishLoad()
 		{
 			View->GetToolController()->InitializeToolController();
+			View->GetToolController()->LoadStatus("viewer.waveform");
 			m_pManager->OcultarTodosLosWidgets(true, 666);
 			m_pManager->DisableAnimation();
 			m_pManager->Render();
 		}
-
-		vtkGinkgoImageViewer* GWaveformView::GetViewerActivo()
-		{
-			return ViewImage2D;
-		}
-		
+				
 		GNC::GCS::IWidgetsManager* GWaveformView::GetManager()
 		{ 
 			return m_pManager; 
