@@ -201,7 +201,7 @@ void GNKVisualizator::GUI::PreviewPanelVisualizator::LoadModel()
 	GNC::GCS::Ptr<GNC::GCS::IStudyContext>& pStudy = m_pView->GetEstudio();
 	GVistaCompleja* GView = dynamic_cast<GVistaCompleja*>(GetParent());
 
-	pRoot = new GNKVisualizator::GUI::IPreviewNodeVisualizator(std::string(wxString::Format(_("%d series"), pStudy->OpenedSeries.size()).ToUTF8()));
+	pRoot = new GNKVisualizator::GUI::IPreviewNodeVisualizator(std::string(wxString::Format(_("%d series"), (int) (pStudy->OpenedSeries.size())).ToUTF8()));
 	for (std::vector<long>::iterator it = pStudy->OpenedSeries.begin(); it != pStudy->OpenedSeries.end(); ++it)
 	{
 		GNC::GCS::IHistoryController::SeriesModel seriesModel = GNC::GCS::IHistoryController::Instance()->GetSeriesModel((*it));
